Class: DaytonaApiClient::AdminApi
- Inherits:
-
Object
- Object
- DaytonaApiClient::AdminApi
- Defined in:
- lib/daytona_api_client/api/admin_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#admin_can_cleanup_image(image_name, opts = {}) ⇒ Boolean
Check if an image can be cleaned up.
-
#admin_can_cleanup_image_with_http_info(image_name, opts = {}) ⇒ Array<(Boolean, Integer, Hash)>
Check if an image can be cleaned up.
-
#admin_create_runner(admin_create_runner, opts = {}) ⇒ CreateRunnerResponse
Create runner.
-
#admin_create_runner_with_http_info(admin_create_runner, opts = {}) ⇒ Array<(CreateRunnerResponse, Integer, Hash)>
Create runner.
-
#admin_create_user(create_user, opts = {}) ⇒ nil
Create user.
-
#admin_create_user_with_http_info(create_user, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Create user.
-
#admin_delete_runner(id, opts = {}) ⇒ nil
Delete runner.
-
#admin_delete_runner_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete runner.
-
#admin_get_all_audit_logs(opts = {}) ⇒ PaginatedAuditLogs
Get all audit logs.
-
#admin_get_all_audit_logs_with_http_info(opts = {}) ⇒ Array<(PaginatedAuditLogs, Integer, Hash)>
Get all audit logs.
-
#admin_get_message_attempts(organization_id, message_id, opts = {}) ⇒ Array<Object>
Get delivery attempts for a webhook message.
-
#admin_get_message_attempts_with_http_info(organization_id, message_id, opts = {}) ⇒ Array<(Array<Object>, Integer, Hash)>
Get delivery attempts for a webhook message.
-
#admin_get_runner_by_id(id, opts = {}) ⇒ RunnerFull
Get runner by ID.
-
#admin_get_runner_by_id_with_http_info(id, opts = {}) ⇒ Array<(RunnerFull, Integer, Hash)>
Get runner by ID.
-
#admin_get_user(id, opts = {}) ⇒ User
Get user by ID.
-
#admin_get_user_with_http_info(id, opts = {}) ⇒ Array<(User, Integer, Hash)>
Get user by ID.
-
#admin_get_webhook_status(opts = {}) ⇒ AdminGetWebhookStatus200Response
Get webhook service status.
-
#admin_get_webhook_status_with_http_info(opts = {}) ⇒ Array<(AdminGetWebhookStatus200Response, Integer, Hash)>
Get webhook service status.
-
#admin_initialize_webhooks(organization_id, opts = {}) ⇒ nil
Initialize webhooks for an organization.
-
#admin_initialize_webhooks_with_http_info(organization_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Initialize webhooks for an organization.
-
#admin_list_runners(opts = {}) ⇒ Array<RunnerFull>
List all runners.
-
#admin_list_runners_with_http_info(opts = {}) ⇒ Array<(Array<RunnerFull>, Integer, Hash)>
List all runners.
-
#admin_list_users(opts = {}) ⇒ nil
List all users.
-
#admin_list_users_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
List all users.
-
#admin_recover_sandbox(sandbox_id, opts = {}) ⇒ Sandbox
Recover sandbox from error state as an admin.
-
#admin_recover_sandbox_with_http_info(sandbox_id, opts = {}) ⇒ Array<(Sandbox, Integer, Hash)>
Recover sandbox from error state as an admin.
-
#admin_regenerate_key_pair(id, opts = {}) ⇒ nil
Regenerate user key pair.
-
#admin_regenerate_key_pair_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Regenerate user key pair.
-
#admin_send_webhook(organization_id, send_webhook_dto, opts = {}) ⇒ nil
Send a webhook message to an organization.
-
#admin_send_webhook_with_http_info(organization_id, send_webhook_dto, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Send a webhook message to an organization.
-
#admin_set_default_registry(id, opts = {}) ⇒ DockerRegistry
Set default registry.
-
#admin_set_default_registry_with_http_info(id, opts = {}) ⇒ Array<(DockerRegistry, Integer, Hash)>
Set default registry.
-
#admin_set_snapshot_general_status(id, set_snapshot_general_status_dto, opts = {}) ⇒ SnapshotDto
Set snapshot general status.
-
#admin_set_snapshot_general_status_with_http_info(id, set_snapshot_general_status_dto, opts = {}) ⇒ Array<(SnapshotDto, Integer, Hash)>
Set snapshot general status.
-
#admin_update_runner_scheduling(id, opts = {}) ⇒ nil
Update runner scheduling status.
-
#admin_update_runner_scheduling_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update runner scheduling status.
-
#initialize(api_client = ApiClient.default) ⇒ AdminApi
constructor
A new instance of AdminApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#admin_can_cleanup_image(image_name, opts = {}) ⇒ Boolean
Check if an image can be cleaned up
26 27 28 29 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 26 def admin_can_cleanup_image(image_name, opts = {}) data, _status_code, _headers = admin_can_cleanup_image_with_http_info(image_name, opts) data end |
#admin_can_cleanup_image_with_http_info(image_name, opts = {}) ⇒ Array<(Boolean, Integer, Hash)>
Check if an image can be cleaned up
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 35 def admin_can_cleanup_image_with_http_info(image_name, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_can_cleanup_image ...' end # verify the required parameter 'image_name' is set if @api_client.config.client_side_validation && image_name.nil? fail ArgumentError, "Missing the required parameter 'image_name' when calling AdminApi.admin_can_cleanup_image" end # resource path local_var_path = '/admin/snapshots/can-cleanup-image' # query parameters query_params = opts[:query_params] || {} query_params[:'imageName'] = image_name # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Boolean' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_can_cleanup_image", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_can_cleanup_image\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_create_runner(admin_create_runner, opts = {}) ⇒ CreateRunnerResponse
Create runner
88 89 90 91 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 88 def admin_create_runner(admin_create_runner, opts = {}) data, _status_code, _headers = admin_create_runner_with_http_info(admin_create_runner, opts) data end |
#admin_create_runner_with_http_info(admin_create_runner, opts = {}) ⇒ Array<(CreateRunnerResponse, Integer, Hash)>
Create runner
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 97 def admin_create_runner_with_http_info(admin_create_runner, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_create_runner ...' end # verify the required parameter 'admin_create_runner' is set if @api_client.config.client_side_validation && admin_create_runner.nil? fail ArgumentError, "Missing the required parameter 'admin_create_runner' when calling AdminApi.admin_create_runner" end # resource path local_var_path = '/admin/runners' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(admin_create_runner) # return_type return_type = opts[:debug_return_type] || 'CreateRunnerResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_create_runner", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_create_runner\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_create_user(create_user, opts = {}) ⇒ nil
Create user
154 155 156 157 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 154 def admin_create_user(create_user, opts = {}) admin_create_user_with_http_info(create_user, opts) nil end |
#admin_create_user_with_http_info(create_user, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Create user
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 163 def admin_create_user_with_http_info(create_user, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_create_user ...' end # verify the required parameter 'create_user' is set if @api_client.config.client_side_validation && create_user.nil? fail ArgumentError, "Missing the required parameter 'create_user' when calling AdminApi.admin_create_user" end # resource path local_var_path = '/admin/users' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_user) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_create_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_create_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_delete_runner(id, opts = {}) ⇒ nil
Delete runner
218 219 220 221 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 218 def admin_delete_runner(id, opts = {}) admin_delete_runner_with_http_info(id, opts) nil end |
#admin_delete_runner_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete runner
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 227 def admin_delete_runner_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_delete_runner ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AdminApi.admin_delete_runner" end # resource path local_var_path = '/admin/runners/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_delete_runner", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_delete_runner\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_get_all_audit_logs(opts = {}) ⇒ PaginatedAuditLogs
Get all audit logs
281 282 283 284 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 281 def admin_get_all_audit_logs(opts = {}) data, _status_code, _headers = admin_get_all_audit_logs_with_http_info(opts) data end |
#admin_get_all_audit_logs_with_http_info(opts = {}) ⇒ Array<(PaginatedAuditLogs, Integer, Hash)>
Get all audit logs
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 294 def admin_get_all_audit_logs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_get_all_audit_logs ...' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling AdminApi.admin_get_all_audit_logs, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 200 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AdminApi.admin_get_all_audit_logs, must be smaller than or equal to 200.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AdminApi.admin_get_all_audit_logs, must be greater than or equal to 1.' end # resource path local_var_path = '/admin/audit' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'from'] = opts[:'from'] if !opts[:'from'].nil? query_params[:'to'] = opts[:'to'] if !opts[:'to'].nil? query_params[:'nextToken'] = opts[:'next_token'] if !opts[:'next_token'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedAuditLogs' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_get_all_audit_logs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_get_all_audit_logs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_get_message_attempts(organization_id, message_id, opts = {}) ⇒ Array<Object>
Get delivery attempts for a webhook message
360 361 362 363 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 360 def (organization_id, , opts = {}) data, _status_code, _headers = (organization_id, , opts) data end |
#admin_get_message_attempts_with_http_info(organization_id, message_id, opts = {}) ⇒ Array<(Array<Object>, Integer, Hash)>
Get delivery attempts for a webhook message
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 370 def (organization_id, , opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_get_message_attempts ...' end # verify the required parameter 'organization_id' is set if @api_client.config.client_side_validation && organization_id.nil? fail ArgumentError, "Missing the required parameter 'organization_id' when calling AdminApi.admin_get_message_attempts" end # verify the required parameter 'message_id' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'message_id' when calling AdminApi.admin_get_message_attempts" end # resource path local_var_path = '/admin/webhooks/organizations/{organizationId}/messages/{messageId}/attempts'.sub('{' + 'organizationId' + '}', CGI.escape(organization_id.to_s)).sub('{' + 'messageId' + '}', CGI.escape(.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_get_message_attempts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_get_message_attempts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_get_runner_by_id(id, opts = {}) ⇒ RunnerFull
Get runner by ID
426 427 428 429 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 426 def admin_get_runner_by_id(id, opts = {}) data, _status_code, _headers = admin_get_runner_by_id_with_http_info(id, opts) data end |
#admin_get_runner_by_id_with_http_info(id, opts = {}) ⇒ Array<(RunnerFull, Integer, Hash)>
Get runner by ID
435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 435 def admin_get_runner_by_id_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_get_runner_by_id ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AdminApi.admin_get_runner_by_id" end # resource path local_var_path = '/admin/runners/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RunnerFull' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_get_runner_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_get_runner_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_get_user(id, opts = {}) ⇒ User
Get user by ID
487 488 489 490 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 487 def admin_get_user(id, opts = {}) data, _status_code, _headers = admin_get_user_with_http_info(id, opts) data end |
#admin_get_user_with_http_info(id, opts = {}) ⇒ Array<(User, Integer, Hash)>
Get user by ID
496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 496 def admin_get_user_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_get_user ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AdminApi.admin_get_user" end # resource path local_var_path = '/admin/users/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'User' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_get_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_get_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_get_webhook_status(opts = {}) ⇒ AdminGetWebhookStatus200Response
Get webhook service status
547 548 549 550 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 547 def admin_get_webhook_status(opts = {}) data, _status_code, _headers = admin_get_webhook_status_with_http_info(opts) data end |
#admin_get_webhook_status_with_http_info(opts = {}) ⇒ Array<(AdminGetWebhookStatus200Response, Integer, Hash)>
Get webhook service status
555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 555 def admin_get_webhook_status_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_get_webhook_status ...' end # resource path local_var_path = '/admin/webhooks/status' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AdminGetWebhookStatus200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_get_webhook_status", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_get_webhook_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_initialize_webhooks(organization_id, opts = {}) ⇒ nil
Initialize webhooks for an organization
603 604 605 606 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 603 def admin_initialize_webhooks(organization_id, opts = {}) admin_initialize_webhooks_with_http_info(organization_id, opts) nil end |
#admin_initialize_webhooks_with_http_info(organization_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Initialize webhooks for an organization
612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 612 def admin_initialize_webhooks_with_http_info(organization_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_initialize_webhooks ...' end # verify the required parameter 'organization_id' is set if @api_client.config.client_side_validation && organization_id.nil? fail ArgumentError, "Missing the required parameter 'organization_id' when calling AdminApi.admin_initialize_webhooks" end # resource path local_var_path = '/admin/webhooks/organizations/{organizationId}/initialize'.sub('{' + 'organizationId' + '}', CGI.escape(organization_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_initialize_webhooks", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_initialize_webhooks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_list_runners(opts = {}) ⇒ Array<RunnerFull>
List all runners
662 663 664 665 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 662 def admin_list_runners(opts = {}) data, _status_code, _headers = admin_list_runners_with_http_info(opts) data end |
#admin_list_runners_with_http_info(opts = {}) ⇒ Array<(Array<RunnerFull>, Integer, Hash)>
List all runners
671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 671 def admin_list_runners_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_list_runners ...' end # resource path local_var_path = '/admin/runners' # query parameters query_params = opts[:query_params] || {} query_params[:'regionId'] = opts[:'region_id'] if !opts[:'region_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<RunnerFull>' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_list_runners", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_list_runners\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_list_users(opts = {}) ⇒ nil
List all users
719 720 721 722 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 719 def admin_list_users(opts = {}) admin_list_users_with_http_info(opts) nil end |
#admin_list_users_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
List all users
727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 727 def admin_list_users_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_list_users ...' end # resource path local_var_path = '/admin/users' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_list_users", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_list_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_recover_sandbox(sandbox_id, opts = {}) ⇒ Sandbox
Recover sandbox from error state as an admin
773 774 775 776 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 773 def admin_recover_sandbox(sandbox_id, opts = {}) data, _status_code, _headers = admin_recover_sandbox_with_http_info(sandbox_id, opts) data end |
#admin_recover_sandbox_with_http_info(sandbox_id, opts = {}) ⇒ Array<(Sandbox, Integer, Hash)>
Recover sandbox from error state as an admin
782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 782 def admin_recover_sandbox_with_http_info(sandbox_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_recover_sandbox ...' end # verify the required parameter 'sandbox_id' is set if @api_client.config.client_side_validation && sandbox_id.nil? fail ArgumentError, "Missing the required parameter 'sandbox_id' when calling AdminApi.admin_recover_sandbox" end # resource path local_var_path = '/admin/sandbox/{sandboxId}/recover'.sub('{' + 'sandboxId' + '}', CGI.escape(sandbox_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Sandbox' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_recover_sandbox", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_recover_sandbox\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_regenerate_key_pair(id, opts = {}) ⇒ nil
Regenerate user key pair
834 835 836 837 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 834 def admin_regenerate_key_pair(id, opts = {}) admin_regenerate_key_pair_with_http_info(id, opts) nil end |
#admin_regenerate_key_pair_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Regenerate user key pair
843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 843 def admin_regenerate_key_pair_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_regenerate_key_pair ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AdminApi.admin_regenerate_key_pair" end # resource path local_var_path = '/admin/users/{id}/regenerate-key-pair'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_regenerate_key_pair", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_regenerate_key_pair\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_send_webhook(organization_id, send_webhook_dto, opts = {}) ⇒ nil
Send a webhook message to an organization
894 895 896 897 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 894 def admin_send_webhook(organization_id, send_webhook_dto, opts = {}) admin_send_webhook_with_http_info(organization_id, send_webhook_dto, opts) nil end |
#admin_send_webhook_with_http_info(organization_id, send_webhook_dto, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Send a webhook message to an organization
904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 904 def admin_send_webhook_with_http_info(organization_id, send_webhook_dto, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_send_webhook ...' end # verify the required parameter 'organization_id' is set if @api_client.config.client_side_validation && organization_id.nil? fail ArgumentError, "Missing the required parameter 'organization_id' when calling AdminApi.admin_send_webhook" end # verify the required parameter 'send_webhook_dto' is set if @api_client.config.client_side_validation && send_webhook_dto.nil? fail ArgumentError, "Missing the required parameter 'send_webhook_dto' when calling AdminApi.admin_send_webhook" end # resource path local_var_path = '/admin/webhooks/organizations/{organizationId}/send'.sub('{' + 'organizationId' + '}', CGI.escape(organization_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(send_webhook_dto) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_send_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_send_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_set_default_registry(id, opts = {}) ⇒ DockerRegistry
Set default registry
963 964 965 966 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 963 def admin_set_default_registry(id, opts = {}) data, _status_code, _headers = admin_set_default_registry_with_http_info(id, opts) data end |
#admin_set_default_registry_with_http_info(id, opts = {}) ⇒ Array<(DockerRegistry, Integer, Hash)>
Set default registry
972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 972 def admin_set_default_registry_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_set_default_registry ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AdminApi.admin_set_default_registry" end # resource path local_var_path = '/admin/docker-registry/{id}/set-default'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DockerRegistry' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_set_default_registry", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_set_default_registry\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_set_snapshot_general_status(id, set_snapshot_general_status_dto, opts = {}) ⇒ SnapshotDto
Set snapshot general status
1025 1026 1027 1028 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 1025 def admin_set_snapshot_general_status(id, set_snapshot_general_status_dto, opts = {}) data, _status_code, _headers = admin_set_snapshot_general_status_with_http_info(id, set_snapshot_general_status_dto, opts) data end |
#admin_set_snapshot_general_status_with_http_info(id, set_snapshot_general_status_dto, opts = {}) ⇒ Array<(SnapshotDto, Integer, Hash)>
Set snapshot general status
1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 1035 def admin_set_snapshot_general_status_with_http_info(id, set_snapshot_general_status_dto, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_set_snapshot_general_status ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AdminApi.admin_set_snapshot_general_status" end # verify the required parameter 'set_snapshot_general_status_dto' is set if @api_client.config.client_side_validation && set_snapshot_general_status_dto.nil? fail ArgumentError, "Missing the required parameter 'set_snapshot_general_status_dto' when calling AdminApi.admin_set_snapshot_general_status" end # resource path local_var_path = '/admin/snapshots/{id}/general'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(set_snapshot_general_status_dto) # return_type return_type = opts[:debug_return_type] || 'SnapshotDto' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_set_snapshot_general_status", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_set_snapshot_general_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_update_runner_scheduling(id, opts = {}) ⇒ nil
Update runner scheduling status
1096 1097 1098 1099 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 1096 def admin_update_runner_scheduling(id, opts = {}) admin_update_runner_scheduling_with_http_info(id, opts) nil end |
#admin_update_runner_scheduling_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update runner scheduling status
1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 |
# File 'lib/daytona_api_client/api/admin_api.rb', line 1105 def admin_update_runner_scheduling_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_update_runner_scheduling ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AdminApi.admin_update_runner_scheduling" end # resource path local_var_path = '/admin/runners/{id}/scheduling'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AdminApi.admin_update_runner_scheduling", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_update_runner_scheduling\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |