Class: DaytonaApiClient::AdminCreateRunner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::AdminCreateRunner
- Defined in:
- lib/daytona_api_client/models/admin_create_runner.rb
Instance Attribute Summary collapse
-
#api_key ⇒ Object
Returns the value of attribute api_key.
-
#api_url ⇒ Object
The API URL of the runner.
-
#api_version ⇒ Object
The api version of the runner to create.
-
#cpu ⇒ Object
The CPU capacity of the runner.
-
#disk_gi_b ⇒ Object
The disk capacity of the runner in GiB.
-
#domain ⇒ Object
The domain of the runner.
-
#memory_gi_b ⇒ Object
The memory capacity of the runner in GiB.
-
#name ⇒ Object
Returns the value of attribute name.
-
#proxy_url ⇒ Object
The proxy URL of the runner.
-
#region_id ⇒ Object
Returns the value of attribute region_id.
-
#tags ⇒ Object
Tags to associate with the runner.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdminCreateRunner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdminCreateRunner
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::AdminCreateRunner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::AdminCreateRunner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'region_id') self.region_id = attributes[:'region_id'] else self.region_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'api_key') self.api_key = attributes[:'api_key'] else self.api_key = nil end if attributes.key?(:'api_version') self.api_version = attributes[:'api_version'] else self.api_version = nil end if attributes.key?(:'domain') self.domain = attributes[:'domain'] end if attributes.key?(:'api_url') self.api_url = attributes[:'api_url'] end if attributes.key?(:'proxy_url') self.proxy_url = attributes[:'proxy_url'] end if attributes.key?(:'cpu') self.cpu = attributes[:'cpu'] end if attributes.key?(:'memory_gi_b') self.memory_gi_b = attributes[:'memory_gi_b'] end if attributes.key?(:'disk_gi_b') self.disk_gi_b = attributes[:'disk_gi_b'] end end |
Instance Attribute Details
#api_key ⇒ Object
Returns the value of attribute api_key.
25 26 27 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 25 def api_key @api_key end |
#api_url ⇒ Object
The API URL of the runner
34 35 36 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 34 def api_url @api_url end |
#api_version ⇒ Object
The api version of the runner to create
28 29 30 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 28 def api_version @api_version end |
#cpu ⇒ Object
The CPU capacity of the runner
40 41 42 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 40 def cpu @cpu end |
#disk_gi_b ⇒ Object
The disk capacity of the runner in GiB
46 47 48 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 46 def disk_gi_b @disk_gi_b end |
#domain ⇒ Object
The domain of the runner
31 32 33 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 31 def domain @domain end |
#memory_gi_b ⇒ Object
The memory capacity of the runner in GiB
43 44 45 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 43 def memory_gi_b @memory_gi_b end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 20 def name @name end |
#proxy_url ⇒ Object
The proxy URL of the runner
37 38 39 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 37 def proxy_url @proxy_url end |
#region_id ⇒ Object
Returns the value of attribute region_id.
18 19 20 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 18 def region_id @region_id end |
#tags ⇒ Object
Tags to associate with the runner
23 24 25 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 23 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 49 def self.attribute_map { :'region_id' => :'regionId', :'name' => :'name', :'tags' => :'tags', :'api_key' => :'apiKey', :'api_version' => :'apiVersion', :'domain' => :'domain', :'api_url' => :'apiUrl', :'proxy_url' => :'proxyUrl', :'cpu' => :'cpu', :'memory_gi_b' => :'memoryGiB', :'disk_gi_b' => :'diskGiB' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 288 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 76 def self.openapi_types { :'region_id' => :'String', :'name' => :'String', :'tags' => :'Array<String>', :'api_key' => :'String', :'api_version' => :'String', :'domain' => :'String', :'api_url' => :'String', :'proxy_url' => :'String', :'cpu' => :'Float', :'memory_gi_b' => :'Float', :'disk_gi_b' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 257 def ==(o) return true if self.equal?(o) self.class == o.class && region_id == o.region_id && name == o.name && == o. && api_key == o.api_key && api_version == o.api_version && domain == o.domain && api_url == o.api_url && proxy_url == o.proxy_url && cpu == o.cpu && memory_gi_b == o.memory_gi_b && disk_gi_b == o.disk_gi_b end |
#eql?(o) ⇒ Boolean
275 276 277 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 275 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
281 282 283 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 281 def hash [region_id, name, , api_key, api_version, domain, api_url, proxy_url, cpu, memory_gi_b, disk_gi_b].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 171 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @region_id.nil? invalid_properties.push('invalid value for "region_id", region_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @api_key.nil? invalid_properties.push('invalid value for "api_key", api_key cannot be nil.') end if @api_version.nil? invalid_properties.push('invalid value for "api_version", api_version cannot be nil.') end pattern = Regexp.new(/^(0|2)$/) if @api_version !~ pattern invalid_properties.push("invalid value for \"api_version\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
200 201 202 203 204 205 206 207 208 |
# File 'lib/daytona_api_client/models/admin_create_runner.rb', line 200 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @region_id.nil? return false if @name.nil? return false if @api_key.nil? return false if @api_version.nil? return false if @api_version !~ Regexp.new(/^(0|2)$/) true end |