Class: DaytonaApiClient::ApiKeyList

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/api_key_list.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApiKeyList

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/daytona_api_client/models/api_key_list.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::ApiKeyList` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::ApiKeyList`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'permissions')
    if (value = attributes[:'permissions']).is_a?(Array)
      self.permissions = value
    end
  else
    self.permissions = nil
  end

  if attributes.key?(:'last_used_at')
    self.last_used_at = attributes[:'last_used_at']
  else
    self.last_used_at = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  else
    self.user_id = nil
  end
end

Instance Attribute Details

#created_atObject

When the API key was created



25
26
27
# File 'lib/daytona_api_client/models/api_key_list.rb', line 25

def created_at
  @created_at
end

#expires_atObject

When the API key expires



34
35
36
# File 'lib/daytona_api_client/models/api_key_list.rb', line 34

def expires_at
  @expires_at
end

#last_used_atObject

When the API key was last used



31
32
33
# File 'lib/daytona_api_client/models/api_key_list.rb', line 31

def last_used_at
  @last_used_at
end

#nameObject

The name of the API key



19
20
21
# File 'lib/daytona_api_client/models/api_key_list.rb', line 19

def name
  @name
end

#permissionsObject

The list of organization resource permissions assigned to the API key



28
29
30
# File 'lib/daytona_api_client/models/api_key_list.rb', line 28

def permissions
  @permissions
end

#user_idObject

The user ID of the user who created the API key



37
38
39
# File 'lib/daytona_api_client/models/api_key_list.rb', line 37

def user_id
  @user_id
end

#valueObject

The masked API key value



22
23
24
# File 'lib/daytona_api_client/models/api_key_list.rb', line 22

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/daytona_api_client/models/api_key_list.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/daytona_api_client/models/api_key_list.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/daytona_api_client/models/api_key_list.rb', line 62

def self.attribute_map
  {
    :'name' => :'name',
    :'value' => :'value',
    :'created_at' => :'createdAt',
    :'permissions' => :'permissions',
    :'last_used_at' => :'lastUsedAt',
    :'expires_at' => :'expiresAt',
    :'user_id' => :'userId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/daytona_api_client/models/api_key_list.rb', line 275

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
102
103
# File 'lib/daytona_api_client/models/api_key_list.rb', line 98

def self.openapi_nullable
  Set.new([
    :'last_used_at',
    :'expires_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/daytona_api_client/models/api_key_list.rb', line 85

def self.openapi_types
  {
    :'name' => :'String',
    :'value' => :'String',
    :'created_at' => :'Time',
    :'permissions' => :'Array<String>',
    :'last_used_at' => :'Time',
    :'expires_at' => :'Time',
    :'user_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



248
249
250
251
252
253
254
255
256
257
258
# File 'lib/daytona_api_client/models/api_key_list.rb', line 248

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      value == o.value &&
      created_at == o.created_at &&
      permissions == o.permissions &&
      last_used_at == o.last_used_at &&
      expires_at == o.expires_at &&
      user_id == o.user_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/daytona_api_client/models/api_key_list.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/daytona_api_client/models/api_key_list.rb', line 268

def hash
  [name, value, created_at, permissions, last_used_at, expires_at, user_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/daytona_api_client/models/api_key_list.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @permissions.nil?
    invalid_properties.push('invalid value for "permissions", permissions cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/daytona_api_client/models/api_key_list.rb', line 297

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



196
197
198
199
200
201
202
203
204
# File 'lib/daytona_api_client/models/api_key_list.rb', line 196

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @value.nil?
  return false if @created_at.nil?
  return false if @permissions.nil?
  return false if @user_id.nil?
  true
end