Class: DaytonaApiClient::AuditApi

Inherits:
Object
  • Object
show all
Defined in:
lib/daytona_api_client/api/audit_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AuditApi

Returns a new instance of AuditApi.



19
20
21
# File 'lib/daytona_api_client/api/audit_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/daytona_api_client/api/audit_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_audit_scenarios(opts = {}) ⇒ AuditScenarios

Get supported audit log scenarios Returns the supported audit log actions grouped by target type. The list is derived at runtime from the audited routes and system events, so it always reflects what can actually appear in the audit log.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



26
27
28
29
# File 'lib/daytona_api_client/api/audit_api.rb', line 26

def get_audit_scenarios(opts = {})
  data, _status_code, _headers = get_audit_scenarios_with_http_info(opts)
  data
end

#get_audit_scenarios_with_http_info(opts = {}) ⇒ Array<(AuditScenarios, Integer, Hash)>

Get supported audit log scenarios Returns the supported audit log actions grouped by target type. The list is derived at runtime from the audited routes and system events, so it always reflects what can actually appear in the audit log.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AuditScenarios, Integer, Hash)>)

    AuditScenarios data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/daytona_api_client/api/audit_api.rb', line 35

def get_audit_scenarios_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuditApi.get_audit_scenarios ...'
  end
  # resource path
  local_var_path = '/audit/scenarios'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AuditScenarios'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AuditApi.get_audit_scenarios",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuditApi#get_audit_scenarios\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_organization_audit_logs(organization_id, opts = {}) ⇒ PaginatedAuditLogs

Get audit logs for organization

Parameters:

  • organization_id (String)

    Organization ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Float)

    Page number of the results (default to 1)

  • :limit (Float)

    Number of results per page (default to 100)

  • :from (Time)

    Deprecated alias for `createdAt`. From date (ISO 8601 format).

  • :to (Time)

    Deprecated alias for `createdAt`. To date (ISO 8601 format).

  • :next_token (String)

    Token for cursor-based pagination. When provided, takes precedence over page parameter.

  • :id (StringFilter)

    Filter by audit log ID.

  • :actor_id (StringFilter)

    Filter by actor user ID.

  • :actor_email (StringFilter)

    Filter by actor email.

  • :actor_api_key_prefix (StringFilter)

    Filter by actor API key prefix.

  • :actor_api_key_suffix (StringFilter)

    Filter by actor API key suffix.

  • :action (StringFilter)

    Filter by action.

  • :target_type (StringFilter)

    Filter by target type.

  • :target_id (StringFilter)

    Filter by target ID.

  • :status_code (IntFilter)

    Filter by HTTP status code.

  • :created_at (DateFilter)

    Filter by creation timestamp.

Returns:



98
99
100
101
# File 'lib/daytona_api_client/api/audit_api.rb', line 98

def get_organization_audit_logs(organization_id, opts = {})
  data, _status_code, _headers = get_organization_audit_logs_with_http_info(organization_id, opts)
  data
end

#get_organization_audit_logs_with_http_info(organization_id, opts = {}) ⇒ Array<(PaginatedAuditLogs, Integer, Hash)>

Get audit logs for organization

Parameters:

  • organization_id (String)

    Organization ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Float)

    Page number of the results (default to 1)

  • :limit (Float)

    Number of results per page (default to 100)

  • :from (Time)

    Deprecated alias for `createdAt`. From date (ISO 8601 format).

  • :to (Time)

    Deprecated alias for `createdAt`. To date (ISO 8601 format).

  • :next_token (String)

    Token for cursor-based pagination. When provided, takes precedence over page parameter.

  • :id (StringFilter)

    Filter by audit log ID.

  • :actor_id (StringFilter)

    Filter by actor user ID.

  • :actor_email (StringFilter)

    Filter by actor email.

  • :actor_api_key_prefix (StringFilter)

    Filter by actor API key prefix.

  • :actor_api_key_suffix (StringFilter)

    Filter by actor API key suffix.

  • :action (StringFilter)

    Filter by action.

  • :target_type (StringFilter)

    Filter by target type.

  • :target_id (StringFilter)

    Filter by target ID.

  • :status_code (IntFilter)

    Filter by HTTP status code.

  • :created_at (DateFilter)

    Filter by creation timestamp.

Returns:

  • (Array<(PaginatedAuditLogs, Integer, Hash)>)

    PaginatedAuditLogs data, response status code and response headers



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/daytona_api_client/api/audit_api.rb', line 122

def get_organization_audit_logs_with_http_info(organization_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuditApi.get_organization_audit_logs ...'
  end
  # verify the required parameter 'organization_id' is set
  if @api_client.config.client_side_validation && organization_id.nil?
    fail ArgumentError, "Missing the required parameter 'organization_id' when calling AuditApi.get_organization_audit_logs"
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling AuditApi.get_organization_audit_logs, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 200
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AuditApi.get_organization_audit_logs, must be smaller than or equal to 200.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AuditApi.get_organization_audit_logs, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/audit/organizations/{organizationId}'.sub('{' + 'organizationId' + '}', CGI.escape(organization_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'from'] = opts[:'from'] if !opts[:'from'].nil?
  query_params[:'to'] = opts[:'to'] if !opts[:'to'].nil?
  query_params[:'nextToken'] = opts[:'next_token'] if !opts[:'next_token'].nil?
  query_params[:'id'] = opts[:'id'] if !opts[:'id'].nil?
  query_params[:'actorId'] = opts[:'actor_id'] if !opts[:'actor_id'].nil?
  query_params[:'actorEmail'] = opts[:'actor_email'] if !opts[:'actor_email'].nil?
  query_params[:'actorApiKeyPrefix'] = opts[:'actor_api_key_prefix'] if !opts[:'actor_api_key_prefix'].nil?
  query_params[:'actorApiKeySuffix'] = opts[:'actor_api_key_suffix'] if !opts[:'actor_api_key_suffix'].nil?
  query_params[:'action'] = opts[:'action'] if !opts[:'action'].nil?
  query_params[:'targetType'] = opts[:'target_type'] if !opts[:'target_type'].nil?
  query_params[:'targetId'] = opts[:'target_id'] if !opts[:'target_id'].nil?
  query_params[:'statusCode'] = opts[:'status_code'] if !opts[:'status_code'].nil?
  query_params[:'createdAt'] = opts[:'created_at'] if !opts[:'created_at'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedAuditLogs'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2']

  new_options = opts.merge(
    :operation => :"AuditApi.get_organization_audit_logs",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuditApi#get_organization_audit_logs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end