Class: DaytonaApiClient::BuildInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::BuildInfo
- Defined in:
- lib/daytona_api_client/models/build_info.rb
Instance Attribute Summary collapse
-
#context_hashes ⇒ Object
The context hashes used for the build.
-
#created_at ⇒ Object
The creation timestamp.
-
#dockerfile_content ⇒ Object
The Dockerfile content used for the build.
-
#snapshot_ref ⇒ Object
The snapshot reference.
-
#updated_at ⇒ Object
The last update timestamp.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BuildInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BuildInfo
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/daytona_api_client/models/build_info.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::BuildInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::BuildInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'dockerfile_content') self.dockerfile_content = attributes[:'dockerfile_content'] end if attributes.key?(:'context_hashes') if (value = attributes[:'context_hashes']).is_a?(Array) self.context_hashes = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end if attributes.key?(:'snapshot_ref') self.snapshot_ref = attributes[:'snapshot_ref'] else self.snapshot_ref = nil end end |
Instance Attribute Details
#context_hashes ⇒ Object
The context hashes used for the build
22 23 24 |
# File 'lib/daytona_api_client/models/build_info.rb', line 22 def context_hashes @context_hashes end |
#created_at ⇒ Object
The creation timestamp
25 26 27 |
# File 'lib/daytona_api_client/models/build_info.rb', line 25 def created_at @created_at end |
#dockerfile_content ⇒ Object
The Dockerfile content used for the build
19 20 21 |
# File 'lib/daytona_api_client/models/build_info.rb', line 19 def dockerfile_content @dockerfile_content end |
#snapshot_ref ⇒ Object
The snapshot reference
31 32 33 |
# File 'lib/daytona_api_client/models/build_info.rb', line 31 def snapshot_ref @snapshot_ref end |
#updated_at ⇒ Object
The last update timestamp
28 29 30 |
# File 'lib/daytona_api_client/models/build_info.rb', line 28 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/daytona_api_client/models/build_info.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/daytona_api_client/models/build_info.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/daytona_api_client/models/build_info.rb', line 34 def self.attribute_map { :'dockerfile_content' => :'dockerfileContent', :'context_hashes' => :'contextHashes', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt', :'snapshot_ref' => :'snapshotRef' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/daytona_api_client/models/build_info.rb', line 203 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/daytona_api_client/models/build_info.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/daytona_api_client/models/build_info.rb', line 55 def self.openapi_types { :'dockerfile_content' => :'String', :'context_hashes' => :'Array<String>', :'created_at' => :'Time', :'updated_at' => :'Time', :'snapshot_ref' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 |
# File 'lib/daytona_api_client/models/build_info.rb', line 178 def ==(o) return true if self.equal?(o) self.class == o.class && dockerfile_content == o.dockerfile_content && context_hashes == o.context_hashes && created_at == o.created_at && updated_at == o.updated_at && snapshot_ref == o.snapshot_ref end |
#eql?(o) ⇒ Boolean
190 191 192 |
# File 'lib/daytona_api_client/models/build_info.rb', line 190 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/daytona_api_client/models/build_info.rb', line 196 def hash [dockerfile_content, context_hashes, created_at, updated_at, snapshot_ref].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/daytona_api_client/models/build_info.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end if @snapshot_ref.nil? invalid_properties.push('invalid value for "snapshot_ref", snapshot_ref cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/daytona_api_client/models/build_info.rb', line 225 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 142 143 144 |
# File 'lib/daytona_api_client/models/build_info.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @created_at.nil? return false if @updated_at.nil? return false if @snapshot_ref.nil? true end |