Class: DaytonaApiClient::CreateOrganizationQuota
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::CreateOrganizationQuota
- Defined in:
- lib/daytona_api_client/models/create_organization_quota.rb
Instance Attribute Summary collapse
-
#max_concurrent_snapshot_processing ⇒ Object
Maximum number of snapshots an organization can process (building or pulling) concurrently.
-
#max_cpu_per_sandbox ⇒ Object
Returns the value of attribute max_cpu_per_sandbox.
-
#max_disk_per_sandbox ⇒ Object
Returns the value of attribute max_disk_per_sandbox.
-
#max_memory_per_sandbox ⇒ Object
Returns the value of attribute max_memory_per_sandbox.
-
#max_snapshot_size ⇒ Object
Returns the value of attribute max_snapshot_size.
-
#snapshot_quota ⇒ Object
Returns the value of attribute snapshot_quota.
-
#total_cpu_quota ⇒ Object
Returns the value of attribute total_cpu_quota.
-
#total_disk_quota ⇒ Object
Returns the value of attribute total_disk_quota.
-
#total_memory_quota ⇒ Object
Returns the value of attribute total_memory_quota.
-
#volume_quota ⇒ Object
Returns the value of attribute volume_quota.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateOrganizationQuota
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateOrganizationQuota
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::CreateOrganizationQuota` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::CreateOrganizationQuota`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'total_cpu_quota') self.total_cpu_quota = attributes[:'total_cpu_quota'] end if attributes.key?(:'total_memory_quota') self.total_memory_quota = attributes[:'total_memory_quota'] end if attributes.key?(:'total_disk_quota') self.total_disk_quota = attributes[:'total_disk_quota'] end if attributes.key?(:'max_cpu_per_sandbox') self.max_cpu_per_sandbox = attributes[:'max_cpu_per_sandbox'] end if attributes.key?(:'max_memory_per_sandbox') self.max_memory_per_sandbox = attributes[:'max_memory_per_sandbox'] end if attributes.key?(:'max_disk_per_sandbox') self.max_disk_per_sandbox = attributes[:'max_disk_per_sandbox'] end if attributes.key?(:'snapshot_quota') self.snapshot_quota = attributes[:'snapshot_quota'] end if attributes.key?(:'max_snapshot_size') self.max_snapshot_size = attributes[:'max_snapshot_size'] end if attributes.key?(:'volume_quota') self.volume_quota = attributes[:'volume_quota'] end if attributes.key?(:'max_concurrent_snapshot_processing') self.max_concurrent_snapshot_processing = attributes[:'max_concurrent_snapshot_processing'] end end |
Instance Attribute Details
#max_concurrent_snapshot_processing ⇒ Object
Maximum number of snapshots an organization can process (building or pulling) concurrently. Excess are queued. <= 0 means unlimited.
37 38 39 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 37 def max_concurrent_snapshot_processing @max_concurrent_snapshot_processing end |
#max_cpu_per_sandbox ⇒ Object
Returns the value of attribute max_cpu_per_sandbox.
24 25 26 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 24 def max_cpu_per_sandbox @max_cpu_per_sandbox end |
#max_disk_per_sandbox ⇒ Object
Returns the value of attribute max_disk_per_sandbox.
28 29 30 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 28 def max_disk_per_sandbox @max_disk_per_sandbox end |
#max_memory_per_sandbox ⇒ Object
Returns the value of attribute max_memory_per_sandbox.
26 27 28 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 26 def max_memory_per_sandbox @max_memory_per_sandbox end |
#max_snapshot_size ⇒ Object
Returns the value of attribute max_snapshot_size.
32 33 34 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 32 def max_snapshot_size @max_snapshot_size end |
#snapshot_quota ⇒ Object
Returns the value of attribute snapshot_quota.
30 31 32 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 30 def snapshot_quota @snapshot_quota end |
#total_cpu_quota ⇒ Object
Returns the value of attribute total_cpu_quota.
18 19 20 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 18 def total_cpu_quota @total_cpu_quota end |
#total_disk_quota ⇒ Object
Returns the value of attribute total_disk_quota.
22 23 24 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 22 def total_disk_quota @total_disk_quota end |
#total_memory_quota ⇒ Object
Returns the value of attribute total_memory_quota.
20 21 22 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 20 def total_memory_quota @total_memory_quota end |
#volume_quota ⇒ Object
Returns the value of attribute volume_quota.
34 35 36 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 34 def volume_quota @volume_quota end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 40 def self.attribute_map { :'total_cpu_quota' => :'totalCpuQuota', :'total_memory_quota' => :'totalMemoryQuota', :'total_disk_quota' => :'totalDiskQuota', :'max_cpu_per_sandbox' => :'maxCpuPerSandbox', :'max_memory_per_sandbox' => :'maxMemoryPerSandbox', :'max_disk_per_sandbox' => :'maxDiskPerSandbox', :'snapshot_quota' => :'snapshotQuota', :'max_snapshot_size' => :'maxSnapshotSize', :'volume_quota' => :'volumeQuota', :'max_concurrent_snapshot_processing' => :'maxConcurrentSnapshotProcessing' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 66 def self.openapi_types { :'total_cpu_quota' => :'Float', :'total_memory_quota' => :'Float', :'total_disk_quota' => :'Float', :'max_cpu_per_sandbox' => :'Float', :'max_memory_per_sandbox' => :'Float', :'max_disk_per_sandbox' => :'Float', :'snapshot_quota' => :'Float', :'max_snapshot_size' => :'Float', :'volume_quota' => :'Float', :'max_concurrent_snapshot_processing' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && total_cpu_quota == o.total_cpu_quota && total_memory_quota == o.total_memory_quota && total_disk_quota == o.total_disk_quota && max_cpu_per_sandbox == o.max_cpu_per_sandbox && max_memory_per_sandbox == o.max_memory_per_sandbox && max_disk_per_sandbox == o.max_disk_per_sandbox && snapshot_quota == o.snapshot_quota && max_snapshot_size == o.max_snapshot_size && volume_quota == o.volume_quota && max_concurrent_snapshot_processing == o.max_concurrent_snapshot_processing end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 184 def hash [total_cpu_quota, total_memory_quota, total_disk_quota, max_cpu_per_sandbox, max_memory_per_sandbox, max_disk_per_sandbox, snapshot_quota, max_snapshot_size, volume_quota, max_concurrent_snapshot_processing].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 |
# File 'lib/daytona_api_client/models/create_organization_quota.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |