Class: DaytonaApiClient::CreateRegion

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/create_region.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateRegion

Initializes the object



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/daytona_api_client/models/create_region.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::CreateRegion` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::CreateRegion`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'proxy_url')
    self.proxy_url = attributes[:'proxy_url']
  end

  if attributes.key?(:'ssh_gateway_url')
    self.ssh_gateway_url = attributes[:'ssh_gateway_url']
  end

  if attributes.key?(:'snapshot_manager_url')
    self.snapshot_manager_url = attributes[:'snapshot_manager_url']
  end

  if attributes.key?(:'otel_endpoint')
    self.otel_endpoint = attributes[:'otel_endpoint']
  end
end

Instance Attribute Details

#nameObject

Region name



19
20
21
# File 'lib/daytona_api_client/models/create_region.rb', line 19

def name
  @name
end

#otel_endpointObject

OTel collector endpoint for sandboxes created in this region. When set, sandbox OTel data is sent to this endpoint instead of the Daytona-hosted collector and will not be available in the Daytona analytics API or dashboard.



31
32
33
# File 'lib/daytona_api_client/models/create_region.rb', line 31

def otel_endpoint
  @otel_endpoint
end

#proxy_urlObject

Proxy URL for the region



22
23
24
# File 'lib/daytona_api_client/models/create_region.rb', line 22

def proxy_url
  @proxy_url
end

#snapshot_manager_urlObject

Snapshot Manager URL for the region



28
29
30
# File 'lib/daytona_api_client/models/create_region.rb', line 28

def snapshot_manager_url
  @snapshot_manager_url
end

#ssh_gateway_urlObject

SSH Gateway URL for the region



25
26
27
# File 'lib/daytona_api_client/models/create_region.rb', line 25

def ssh_gateway_url
  @ssh_gateway_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/daytona_api_client/models/create_region.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/daytona_api_client/models/create_region.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/daytona_api_client/models/create_region.rb', line 34

def self.attribute_map
  {
    :'name' => :'name',
    :'proxy_url' => :'proxyUrl',
    :'ssh_gateway_url' => :'sshGatewayUrl',
    :'snapshot_manager_url' => :'snapshotManagerUrl',
    :'otel_endpoint' => :'otelEndpoint'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/daytona_api_client/models/create_region.rb', line 171

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
70
71
72
73
# File 'lib/daytona_api_client/models/create_region.rb', line 66

def self.openapi_nullable
  Set.new([
    :'proxy_url',
    :'ssh_gateway_url',
    :'snapshot_manager_url',
    :'otel_endpoint'
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/daytona_api_client/models/create_region.rb', line 55

def self.openapi_types
  {
    :'name' => :'String',
    :'proxy_url' => :'String',
    :'ssh_gateway_url' => :'String',
    :'snapshot_manager_url' => :'String',
    :'otel_endpoint' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



146
147
148
149
150
151
152
153
154
# File 'lib/daytona_api_client/models/create_region.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      proxy_url == o.proxy_url &&
      ssh_gateway_url == o.ssh_gateway_url &&
      snapshot_manager_url == o.snapshot_manager_url &&
      otel_endpoint == o.otel_endpoint
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


158
159
160
# File 'lib/daytona_api_client/models/create_region.rb', line 158

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



164
165
166
# File 'lib/daytona_api_client/models/create_region.rb', line 164

def hash
  [name, proxy_url, ssh_gateway_url, snapshot_manager_url, otel_endpoint].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



116
117
118
119
120
121
122
123
124
# File 'lib/daytona_api_client/models/create_region.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/daytona_api_client/models/create_region.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



128
129
130
131
132
# File 'lib/daytona_api_client/models/create_region.rb', line 128

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end