Class: DaytonaApiClient::CreateWarmPool
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::CreateWarmPool
- Defined in:
- lib/daytona_api_client/models/create_warm_pool.rb
Instance Attribute Summary collapse
-
#pool ⇒ Object
Number of warm sandboxes to keep ready (capped by the organization quota).
-
#snapshot ⇒ Object
The snapshot (id or name) to keep warm sandboxes for.
-
#target ⇒ Object
Target region for the warm pool.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateWarmPool
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateWarmPool
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::CreateWarmPool` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::CreateWarmPool`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'snapshot') self.snapshot = attributes[:'snapshot'] else self.snapshot = nil end if attributes.key?(:'pool') self.pool = attributes[:'pool'] else self.pool = nil end if attributes.key?(:'target') self.target = attributes[:'target'] end end |
Instance Attribute Details
#pool ⇒ Object
Number of warm sandboxes to keep ready (capped by the organization quota)
22 23 24 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 22 def pool @pool end |
#snapshot ⇒ Object
The snapshot (id or name) to keep warm sandboxes for. A pool only serves sandbox creates that use this snapshot with the default OS user and no custom env, volumes or secrets.
19 20 21 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 19 def snapshot @snapshot end |
#target ⇒ Object
Target region for the warm pool. Defaults to the organization default region.
25 26 27 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 25 def target @target end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 28 def self.attribute_map { :'snapshot' => :'snapshot', :'pool' => :'pool', :'target' => :'target' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 173 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 47 def self.openapi_types { :'snapshot' => :'String', :'pool' => :'Float', :'target' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && snapshot == o.snapshot && pool == o.pool && target == o.target end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 166 def hash [snapshot, pool, target].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 96 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @snapshot.nil? invalid_properties.push('invalid value for "snapshot", snapshot cannot be nil.') end if @pool.nil? invalid_properties.push('invalid value for "pool", pool cannot be nil.') end if @pool < 1 invalid_properties.push('invalid value for "pool", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
116 117 118 119 120 121 122 |
# File 'lib/daytona_api_client/models/create_warm_pool.rb', line 116 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @snapshot.nil? return false if @pool.nil? return false if @pool < 1 true end |