Class: DaytonaApiClient::CreateWorkspace

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/create_workspace.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateWorkspace

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/daytona_api_client/models/create_workspace.rb', line 140

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::CreateWorkspace` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::CreateWorkspace`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'image')
    self.image = attributes[:'image']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'env')
    if (value = attributes[:'env']).is_a?(Hash)
      self.env = value
    end
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Hash)
      self.labels = value
    end
  end

  if attributes.key?(:'public')
    self.public = attributes[:'public']
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end

  if attributes.key?(:'cpu')
    self.cpu = attributes[:'cpu']
  end

  if attributes.key?(:'gpu')
    self.gpu = attributes[:'gpu']
  end

  if attributes.key?(:'memory')
    self.memory = attributes[:'memory']
  end

  if attributes.key?(:'disk')
    self.disk = attributes[:'disk']
  end

  if attributes.key?(:'auto_stop_interval')
    self.auto_stop_interval = attributes[:'auto_stop_interval']
  end

  if attributes.key?(:'auto_archive_interval')
    self.auto_archive_interval = attributes[:'auto_archive_interval']
  end

  if attributes.key?(:'volumes')
    if (value = attributes[:'volumes']).is_a?(Array)
      self.volumes = value
    end
  end

  if attributes.key?(:'build_info')
    self.build_info = attributes[:'build_info']
  end
end

Instance Attribute Details

#auto_archive_intervalObject

Auto-archive interval in minutes (0 means the maximum interval will be used)



52
53
54
# File 'lib/daytona_api_client/models/create_workspace.rb', line 52

def auto_archive_interval
  @auto_archive_interval
end

#auto_stop_intervalObject

Auto-stop interval in minutes (0 means disabled)



49
50
51
# File 'lib/daytona_api_client/models/create_workspace.rb', line 49

def auto_stop_interval
  @auto_stop_interval
end

#build_infoObject

Build information for the workspace



58
59
60
# File 'lib/daytona_api_client/models/create_workspace.rb', line 58

def build_info
  @build_info
end

#cpuObject

CPU cores allocated to the workspace



37
38
39
# File 'lib/daytona_api_client/models/create_workspace.rb', line 37

def cpu
  @cpu
end

#diskObject

Disk space allocated to the workspace in GB



46
47
48
# File 'lib/daytona_api_client/models/create_workspace.rb', line 46

def disk
  @disk
end

#envObject

Environment variables for the workspace



25
26
27
# File 'lib/daytona_api_client/models/create_workspace.rb', line 25

def env
  @env
end

#gpuObject

GPU units allocated to the workspace



40
41
42
# File 'lib/daytona_api_client/models/create_workspace.rb', line 40

def gpu
  @gpu
end

#imageObject

The image used for the workspace



19
20
21
# File 'lib/daytona_api_client/models/create_workspace.rb', line 19

def image
  @image
end

#labelsObject

Labels for the workspace



28
29
30
# File 'lib/daytona_api_client/models/create_workspace.rb', line 28

def labels
  @labels
end

#memoryObject

Memory allocated to the workspace in GB



43
44
45
# File 'lib/daytona_api_client/models/create_workspace.rb', line 43

def memory
  @memory
end

#publicObject

Whether the workspace http preview is publicly accessible



31
32
33
# File 'lib/daytona_api_client/models/create_workspace.rb', line 31

def public
  @public
end

#targetObject

The target (region) where the workspace will be created



34
35
36
# File 'lib/daytona_api_client/models/create_workspace.rb', line 34

def target
  @target
end

#userObject

The user associated with the project



22
23
24
# File 'lib/daytona_api_client/models/create_workspace.rb', line 22

def user
  @user
end

#volumesObject

Array of volumes to attach to the workspace



55
56
57
# File 'lib/daytona_api_client/models/create_workspace.rb', line 55

def volumes
  @volumes
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



103
104
105
# File 'lib/daytona_api_client/models/create_workspace.rb', line 103

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



108
109
110
# File 'lib/daytona_api_client/models/create_workspace.rb', line 108

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/daytona_api_client/models/create_workspace.rb', line 83

def self.attribute_map
  {
    :'image' => :'image',
    :'user' => :'user',
    :'env' => :'env',
    :'labels' => :'labels',
    :'public' => :'public',
    :'target' => :'target',
    :'cpu' => :'cpu',
    :'gpu' => :'gpu',
    :'memory' => :'memory',
    :'disk' => :'disk',
    :'auto_stop_interval' => :'autoStopInterval',
    :'auto_archive_interval' => :'autoArchiveInterval',
    :'volumes' => :'volumes',
    :'build_info' => :'buildInfo'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/daytona_api_client/models/create_workspace.rb', line 280

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



133
134
135
136
# File 'lib/daytona_api_client/models/create_workspace.rb', line 133

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/daytona_api_client/models/create_workspace.rb', line 113

def self.openapi_types
  {
    :'image' => :'String',
    :'user' => :'String',
    :'env' => :'Hash<String, String>',
    :'labels' => :'Hash<String, String>',
    :'public' => :'Boolean',
    :'target' => :'String',
    :'cpu' => :'Integer',
    :'gpu' => :'Integer',
    :'memory' => :'Integer',
    :'disk' => :'Integer',
    :'auto_stop_interval' => :'Integer',
    :'auto_archive_interval' => :'Integer',
    :'volumes' => :'Array<SandboxVolume>',
    :'build_info' => :'CreateBuildInfo'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/daytona_api_client/models/create_workspace.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      image == o.image &&
      user == o.user &&
      env == o.env &&
      labels == o.labels &&
      public == o.public &&
      target == o.target &&
      cpu == o.cpu &&
      gpu == o.gpu &&
      memory == o.memory &&
      disk == o.disk &&
      auto_stop_interval == o.auto_stop_interval &&
      auto_archive_interval == o.auto_archive_interval &&
      volumes == o.volumes &&
      build_info == o.build_info
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


267
268
269
# File 'lib/daytona_api_client/models/create_workspace.rb', line 267

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



273
274
275
# File 'lib/daytona_api_client/models/create_workspace.rb', line 273

def hash
  [image, user, env, labels, public, target, cpu, gpu, memory, disk, auto_stop_interval, auto_archive_interval, volumes, build_info].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



219
220
221
222
223
# File 'lib/daytona_api_client/models/create_workspace.rb', line 219

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/daytona_api_client/models/create_workspace.rb', line 302

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



227
228
229
230
231
232
# File 'lib/daytona_api_client/models/create_workspace.rb', line 227

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  target_validator = EnumAttributeValidator.new('String', ["eu", "us", "asia", "unknown_default_open_api"])
  return false unless target_validator.valid?(@target)
  true
end