Class: DaytonaApiClient::IdentityProvider
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::IdentityProvider
- Defined in:
- lib/daytona_api_client/models/identity_provider.rb
Instance Attribute Summary collapse
-
#allow_any_domain ⇒ Object
Whether the IdP accepts any email domain returned by the external provider.
-
#created_at ⇒ Object
Creation timestamp.
-
#default_assigned_role_ids ⇒ Object
Organization role IDs assigned to users who join via SSO through this identity provider.
-
#email_domains ⇒ Object
Email domains used for IdP discovery on the login form.
-
#enabled ⇒ Object
Whether the identity provider is enabled.
-
#id ⇒ Object
Unique identifier.
-
#name ⇒ Object
Display name for the identity provider.
-
#oidc_config ⇒ Object
OIDC configuration (secret redacted).
-
#organization_id ⇒ Object
Organization ID.
-
#trust_email_verified ⇒ Object
Whether the
email_verifiedclaim check is skipped on SSO logins through this identity provider. -
#updated_at ⇒ Object
Last update timestamp.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IdentityProvider
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IdentityProvider
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::IdentityProvider` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::IdentityProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] else self.organization_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'oidc_config') self.oidc_config = attributes[:'oidc_config'] else self.oidc_config = nil end if attributes.key?(:'email_domains') if (value = attributes[:'email_domains']).is_a?(Array) self.email_domains = value end else self.email_domains = nil end if attributes.key?(:'allow_any_domain') self.allow_any_domain = attributes[:'allow_any_domain'] else self.allow_any_domain = nil end if attributes.key?(:'trust_email_verified') self.trust_email_verified = attributes[:'trust_email_verified'] else self.trust_email_verified = nil end if attributes.key?(:'default_assigned_role_ids') if (value = attributes[:'default_assigned_role_ids']).is_a?(Array) self.default_assigned_role_ids = value end else self.default_assigned_role_ids = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#allow_any_domain ⇒ Object
Whether the IdP accepts any email domain returned by the external provider
34 35 36 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 34 def allow_any_domain @allow_any_domain end |
#created_at ⇒ Object
Creation timestamp
46 47 48 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 46 def created_at @created_at end |
#default_assigned_role_ids ⇒ Object
Organization role IDs assigned to users who join via SSO through this identity provider
40 41 42 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 40 def default_assigned_role_ids @default_assigned_role_ids end |
#email_domains ⇒ Object
Email domains used for IdP discovery on the login form. May be empty when allowAnyDomain is true.
31 32 33 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 31 def email_domains @email_domains end |
#enabled ⇒ Object
Whether the identity provider is enabled
43 44 45 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 43 def enabled @enabled end |
#id ⇒ Object
Unique identifier
19 20 21 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 19 def id @id end |
#name ⇒ Object
Display name for the identity provider
25 26 27 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 25 def name @name end |
#oidc_config ⇒ Object
OIDC configuration (secret redacted)
28 29 30 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 28 def oidc_config @oidc_config end |
#organization_id ⇒ Object
Organization ID
22 23 24 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 22 def organization_id @organization_id end |
#trust_email_verified ⇒ Object
Whether the email_verified claim check is skipped on SSO logins through this identity provider
37 38 39 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 37 def trust_email_verified @trust_email_verified end |
#updated_at ⇒ Object
Last update timestamp
49 50 51 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 49 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 52 def self.attribute_map { :'id' => :'id', :'organization_id' => :'organizationId', :'name' => :'name', :'oidc_config' => :'oidcConfig', :'email_domains' => :'emailDomains', :'allow_any_domain' => :'allowAnyDomain', :'trust_email_verified' => :'trustEmailVerified', :'default_assigned_role_ids' => :'defaultAssignedRoleIds', :'enabled' => :'enabled', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 401 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 79 def self.openapi_types { :'id' => :'String', :'organization_id' => :'String', :'name' => :'String', :'oidc_config' => :'OidcIdPConfigResponse', :'email_domains' => :'Array<String>', :'allow_any_domain' => :'Boolean', :'trust_email_verified' => :'Boolean', :'default_assigned_role_ids' => :'Array<String>', :'enabled' => :'Boolean', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 370 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && organization_id == o.organization_id && name == o.name && oidc_config == o.oidc_config && email_domains == o.email_domains && allow_any_domain == o.allow_any_domain && trust_email_verified == o.trust_email_verified && default_assigned_role_ids == o.default_assigned_role_ids && enabled == o.enabled && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
388 389 390 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 388 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
394 395 396 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 394 def hash [id, organization_id, name, oidc_config, email_domains, allow_any_domain, trust_email_verified, default_assigned_role_ids, enabled, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 190 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @organization_id.nil? invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @oidc_config.nil? invalid_properties.push('invalid value for "oidc_config", oidc_config cannot be nil.') end if @email_domains.nil? invalid_properties.push('invalid value for "email_domains", email_domains cannot be nil.') end if @allow_any_domain.nil? invalid_properties.push('invalid value for "allow_any_domain", allow_any_domain cannot be nil.') end if @trust_email_verified.nil? invalid_properties.push('invalid value for "trust_email_verified", trust_email_verified cannot be nil.') end if @default_assigned_role_ids.nil? invalid_properties.push('invalid value for "default_assigned_role_ids", default_assigned_role_ids cannot be nil.') end if @enabled.nil? invalid_properties.push('invalid value for "enabled", enabled cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 423 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/daytona_api_client/models/identity_provider.rb', line 242 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @organization_id.nil? return false if @name.nil? return false if @oidc_config.nil? return false if @email_domains.nil? return false if @allow_any_domain.nil? return false if @trust_email_verified.nil? return false if @default_assigned_role_ids.nil? return false if @enabled.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |