Class: DaytonaApiClient::Job
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::Job
- Defined in:
- lib/daytona_api_client/models/job.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
The creation timestamp of the job.
-
#error_message ⇒ Object
Error message if the job failed.
-
#id ⇒ Object
The ID of the job.
-
#payload ⇒ Object
Job-specific JSON-encoded payload data (operational metadata).
-
#resource_id ⇒ Object
The ID of the resource this job operates on (sandboxId, snapshotRef, etc.).
-
#resource_type ⇒ Object
The type of resource this job operates on.
-
#status ⇒ Object
The status of the job.
-
#trace_context ⇒ Object
OpenTelemetry trace context for distributed tracing (W3C Trace Context format).
-
#type ⇒ Object
The type of the job.
-
#updated_at ⇒ Object
The last update timestamp of the job.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Job
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Job
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/daytona_api_client/models/job.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::Job` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::Job`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] else self.resource_type = nil end if attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] else self.resource_id = nil end if attributes.key?(:'payload') self.payload = attributes[:'payload'] end if attributes.key?(:'trace_context') if (value = attributes[:'trace_context']).is_a?(Hash) self.trace_context = value end end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#created_at ⇒ Object
The creation timestamp of the job
43 44 45 |
# File 'lib/daytona_api_client/models/job.rb', line 43 def created_at @created_at end |
#error_message ⇒ Object
Error message if the job failed
40 41 42 |
# File 'lib/daytona_api_client/models/job.rb', line 40 def @error_message end |
#id ⇒ Object
The ID of the job
19 20 21 |
# File 'lib/daytona_api_client/models/job.rb', line 19 def id @id end |
#payload ⇒ Object
Job-specific JSON-encoded payload data (operational metadata)
34 35 36 |
# File 'lib/daytona_api_client/models/job.rb', line 34 def payload @payload end |
#resource_id ⇒ Object
The ID of the resource this job operates on (sandboxId, snapshotRef, etc.)
31 32 33 |
# File 'lib/daytona_api_client/models/job.rb', line 31 def resource_id @resource_id end |
#resource_type ⇒ Object
The type of resource this job operates on
28 29 30 |
# File 'lib/daytona_api_client/models/job.rb', line 28 def resource_type @resource_type end |
#status ⇒ Object
The status of the job
25 26 27 |
# File 'lib/daytona_api_client/models/job.rb', line 25 def status @status end |
#trace_context ⇒ Object
OpenTelemetry trace context for distributed tracing (W3C Trace Context format)
37 38 39 |
# File 'lib/daytona_api_client/models/job.rb', line 37 def trace_context @trace_context end |
#type ⇒ Object
The type of the job
22 23 24 |
# File 'lib/daytona_api_client/models/job.rb', line 22 def type @type end |
#updated_at ⇒ Object
The last update timestamp of the job
46 47 48 |
# File 'lib/daytona_api_client/models/job.rb', line 46 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
87 88 89 |
# File 'lib/daytona_api_client/models/job.rb', line 87 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/daytona_api_client/models/job.rb', line 92 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/daytona_api_client/models/job.rb', line 71 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'status' => :'status', :'resource_type' => :'resourceType', :'resource_id' => :'resourceId', :'payload' => :'payload', :'trace_context' => :'traceContext', :'error_message' => :'errorMessage', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/daytona_api_client/models/job.rb', line 328 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 |
# File 'lib/daytona_api_client/models/job.rb', line 113 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/daytona_api_client/models/job.rb', line 97 def self.openapi_types { :'id' => :'String', :'type' => :'JobType', :'status' => :'JobStatus', :'resource_type' => :'String', :'resource_id' => :'String', :'payload' => :'String', :'trace_context' => :'Hash<String, Object>', :'error_message' => :'String', :'created_at' => :'String', :'updated_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/daytona_api_client/models/job.rb', line 298 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && status == o.status && resource_type == o.resource_type && resource_id == o.resource_id && payload == o.payload && trace_context == o.trace_context && == o. && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
315 316 317 |
# File 'lib/daytona_api_client/models/job.rb', line 315 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
321 322 323 |
# File 'lib/daytona_api_client/models/job.rb', line 321 def hash [id, type, status, resource_type, resource_id, payload, trace_context, , created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/daytona_api_client/models/job.rb', line 191 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @resource_type.nil? invalid_properties.push('invalid value for "resource_type", resource_type cannot be nil.') end if @resource_id.nil? invalid_properties.push('invalid value for "resource_id", resource_id cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/daytona_api_client/models/job.rb', line 350 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/daytona_api_client/models/job.rb', line 223 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? return false if @status.nil? return false if @resource_type.nil? resource_type_validator = EnumAttributeValidator.new('String', ["SANDBOX", "SNAPSHOT", "BACKUP", "unknown_default_open_api"]) return false unless resource_type_validator.valid?(@resource_type) return false if @resource_id.nil? return false if @created_at.nil? true end |