Class: DaytonaApiClient::Organization

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/organization.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Organization

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/daytona_api_client/models/organization.rb', line 200

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::Organization` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::Organization`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  else
    self.created_by = nil
  end

  if attributes.key?(:'personal')
    self.personal = attributes[:'personal']
  else
    self.personal = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'suspended')
    self.suspended = attributes[:'suspended']
  else
    self.suspended = nil
  end

  if attributes.key?(:'suspended_at')
    self.suspended_at = attributes[:'suspended_at']
  else
    self.suspended_at = nil
  end

  if attributes.key?(:'suspension_reason')
    self.suspension_reason = attributes[:'suspension_reason']
  else
    self.suspension_reason = nil
  end

  if attributes.key?(:'suspended_until')
    self.suspended_until = attributes[:'suspended_until']
  else
    self.suspended_until = nil
  end

  if attributes.key?(:'suspension_cleanup_grace_period_hours')
    self.suspension_cleanup_grace_period_hours = attributes[:'suspension_cleanup_grace_period_hours']
  else
    self.suspension_cleanup_grace_period_hours = nil
  end

  if attributes.key?(:'max_cpu_per_sandbox')
    self.max_cpu_per_sandbox = attributes[:'max_cpu_per_sandbox']
  else
    self.max_cpu_per_sandbox = nil
  end

  if attributes.key?(:'max_memory_per_sandbox')
    self.max_memory_per_sandbox = attributes[:'max_memory_per_sandbox']
  else
    self.max_memory_per_sandbox = nil
  end

  if attributes.key?(:'max_disk_per_sandbox')
    self.max_disk_per_sandbox = attributes[:'max_disk_per_sandbox']
  else
    self.max_disk_per_sandbox = nil
  end

  if attributes.key?(:'secret_quota')
    self.secret_quota = attributes[:'secret_quota']
  else
    self.secret_quota = nil
  end

  if attributes.key?(:'max_secrets_per_sandbox')
    self.max_secrets_per_sandbox = attributes[:'max_secrets_per_sandbox']
  else
    self.max_secrets_per_sandbox = nil
  end

  if attributes.key?(:'snapshot_deactivation_timeout_minutes')
    self.snapshot_deactivation_timeout_minutes = attributes[:'snapshot_deactivation_timeout_minutes']
  else
    self.snapshot_deactivation_timeout_minutes = 20160
  end

  if attributes.key?(:'sandbox_limited_network_egress')
    self.sandbox_limited_network_egress = attributes[:'sandbox_limited_network_egress']
  else
    self.sandbox_limited_network_egress = nil
  end

  if attributes.key?(:'preview_warning_enabled')
    self.preview_warning_enabled = attributes[:'preview_warning_enabled']
  else
    self.preview_warning_enabled = nil
  end

  if attributes.key?(:'sso_enabled')
    self.sso_enabled = attributes[:'sso_enabled']
  else
    self.sso_enabled = nil
  end

  if attributes.key?(:'default_region_id')
    self.default_region_id = attributes[:'default_region_id']
  end

  if attributes.key?(:'authenticated_rate_limit')
    self.authenticated_rate_limit = attributes[:'authenticated_rate_limit']
  else
    self.authenticated_rate_limit = nil
  end

  if attributes.key?(:'sandbox_create_rate_limit')
    self.sandbox_create_rate_limit = attributes[:'sandbox_create_rate_limit']
  else
    self.sandbox_create_rate_limit = nil
  end

  if attributes.key?(:'sandbox_lifecycle_rate_limit')
    self.sandbox_lifecycle_rate_limit = attributes[:'sandbox_lifecycle_rate_limit']
  else
    self.sandbox_lifecycle_rate_limit = nil
  end

  if attributes.key?(:'experimental_config')
    self.experimental_config = attributes[:'experimental_config']
  else
    self.experimental_config = nil
  end

  if attributes.key?(:'otel_config')
    self.otel_config = attributes[:'otel_config']
  else
    self.otel_config = nil
  end

  if attributes.key?(:'authenticated_rate_limit_ttl_seconds')
    self.authenticated_rate_limit_ttl_seconds = attributes[:'authenticated_rate_limit_ttl_seconds']
  else
    self.authenticated_rate_limit_ttl_seconds = nil
  end

  if attributes.key?(:'sandbox_create_rate_limit_ttl_seconds')
    self.sandbox_create_rate_limit_ttl_seconds = attributes[:'sandbox_create_rate_limit_ttl_seconds']
  else
    self.sandbox_create_rate_limit_ttl_seconds = nil
  end

  if attributes.key?(:'sandbox_lifecycle_rate_limit_ttl_seconds')
    self.sandbox_lifecycle_rate_limit_ttl_seconds = attributes[:'sandbox_lifecycle_rate_limit_ttl_seconds']
  else
    self.sandbox_lifecycle_rate_limit_ttl_seconds = nil
  end
end

Instance Attribute Details

#authenticated_rate_limitObject

Authenticated rate limit per minute



82
83
84
# File 'lib/daytona_api_client/models/organization.rb', line 82

def authenticated_rate_limit
  @authenticated_rate_limit
end

#authenticated_rate_limit_ttl_secondsObject

Authenticated rate limit TTL in seconds



97
98
99
# File 'lib/daytona_api_client/models/organization.rb', line 97

def authenticated_rate_limit_ttl_seconds
  @authenticated_rate_limit_ttl_seconds
end

#created_atObject

Creation timestamp



31
32
33
# File 'lib/daytona_api_client/models/organization.rb', line 31

def created_at
  @created_at
end

#created_byObject

User ID of the organization creator



25
26
27
# File 'lib/daytona_api_client/models/organization.rb', line 25

def created_by
  @created_by
end

#default_region_idObject

Default region ID



79
80
81
# File 'lib/daytona_api_client/models/organization.rb', line 79

def default_region_id
  @default_region_id
end

#experimental_configObject

Experimental configuration



91
92
93
# File 'lib/daytona_api_client/models/organization.rb', line 91

def experimental_config
  @experimental_config
end

#idObject

Organization ID



19
20
21
# File 'lib/daytona_api_client/models/organization.rb', line 19

def id
  @id
end

#max_cpu_per_sandboxObject

Max CPU per sandbox



52
53
54
# File 'lib/daytona_api_client/models/organization.rb', line 52

def max_cpu_per_sandbox
  @max_cpu_per_sandbox
end

#max_disk_per_sandboxObject

Max disk per sandbox



58
59
60
# File 'lib/daytona_api_client/models/organization.rb', line 58

def max_disk_per_sandbox
  @max_disk_per_sandbox
end

#max_memory_per_sandboxObject

Max memory per sandbox



55
56
57
# File 'lib/daytona_api_client/models/organization.rb', line 55

def max_memory_per_sandbox
  @max_memory_per_sandbox
end

#max_secrets_per_sandboxObject

Maximum number of secrets that can be mounted to a single sandbox



64
65
66
# File 'lib/daytona_api_client/models/organization.rb', line 64

def max_secrets_per_sandbox
  @max_secrets_per_sandbox
end

#nameObject

Organization name



22
23
24
# File 'lib/daytona_api_client/models/organization.rb', line 22

def name
  @name
end

#otel_configObject

OpenTelemetry collection configuration



94
95
96
# File 'lib/daytona_api_client/models/organization.rb', line 94

def otel_config
  @otel_config
end

#personalObject

Personal organization flag



28
29
30
# File 'lib/daytona_api_client/models/organization.rb', line 28

def personal
  @personal
end

#preview_warning_enabledObject

Whether the proxy shows the preview URL warning page for this organization



73
74
75
# File 'lib/daytona_api_client/models/organization.rb', line 73

def preview_warning_enabled
  @preview_warning_enabled
end

#sandbox_create_rate_limitObject

Sandbox create rate limit per minute



85
86
87
# File 'lib/daytona_api_client/models/organization.rb', line 85

def sandbox_create_rate_limit
  @sandbox_create_rate_limit
end

#sandbox_create_rate_limit_ttl_secondsObject

Sandbox create rate limit TTL in seconds



100
101
102
# File 'lib/daytona_api_client/models/organization.rb', line 100

def sandbox_create_rate_limit_ttl_seconds
  @sandbox_create_rate_limit_ttl_seconds
end

#sandbox_lifecycle_rate_limitObject

Sandbox lifecycle rate limit per minute



88
89
90
# File 'lib/daytona_api_client/models/organization.rb', line 88

def sandbox_lifecycle_rate_limit
  @sandbox_lifecycle_rate_limit
end

#sandbox_lifecycle_rate_limit_ttl_secondsObject

Sandbox lifecycle rate limit TTL in seconds



103
104
105
# File 'lib/daytona_api_client/models/organization.rb', line 103

def sandbox_lifecycle_rate_limit_ttl_seconds
  @sandbox_lifecycle_rate_limit_ttl_seconds
end

#sandbox_limited_network_egressObject

Sandbox default network block all



70
71
72
# File 'lib/daytona_api_client/models/organization.rb', line 70

def sandbox_limited_network_egress
  @sandbox_limited_network_egress
end

#secret_quotaObject

Maximum number of secrets



61
62
63
# File 'lib/daytona_api_client/models/organization.rb', line 61

def secret_quota
  @secret_quota
end

#snapshot_deactivation_timeout_minutesObject

Time in minutes before an unused snapshot is deactivated



67
68
69
# File 'lib/daytona_api_client/models/organization.rb', line 67

def snapshot_deactivation_timeout_minutes
  @snapshot_deactivation_timeout_minutes
end

#sso_enabledObject

Whether this organization may configure SSO identity providers



76
77
78
# File 'lib/daytona_api_client/models/organization.rb', line 76

def sso_enabled
  @sso_enabled
end

#suspendedObject

Suspended flag



37
38
39
# File 'lib/daytona_api_client/models/organization.rb', line 37

def suspended
  @suspended
end

#suspended_atObject

Suspended at



40
41
42
# File 'lib/daytona_api_client/models/organization.rb', line 40

def suspended_at
  @suspended_at
end

#suspended_untilObject

Suspended until



46
47
48
# File 'lib/daytona_api_client/models/organization.rb', line 46

def suspended_until
  @suspended_until
end

#suspension_cleanup_grace_period_hoursObject

Suspension cleanup grace period hours



49
50
51
# File 'lib/daytona_api_client/models/organization.rb', line 49

def suspension_cleanup_grace_period_hours
  @suspension_cleanup_grace_period_hours
end

#suspension_reasonObject

Suspended reason



43
44
45
# File 'lib/daytona_api_client/models/organization.rb', line 43

def suspension_reason
  @suspension_reason
end

#updated_atObject

Last update timestamp



34
35
36
# File 'lib/daytona_api_client/models/organization.rb', line 34

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



141
142
143
# File 'lib/daytona_api_client/models/organization.rb', line 141

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



146
147
148
# File 'lib/daytona_api_client/models/organization.rb', line 146

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/daytona_api_client/models/organization.rb', line 106

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'created_by' => :'createdBy',
    :'personal' => :'personal',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'suspended' => :'suspended',
    :'suspended_at' => :'suspendedAt',
    :'suspension_reason' => :'suspensionReason',
    :'suspended_until' => :'suspendedUntil',
    :'suspension_cleanup_grace_period_hours' => :'suspensionCleanupGracePeriodHours',
    :'max_cpu_per_sandbox' => :'maxCpuPerSandbox',
    :'max_memory_per_sandbox' => :'maxMemoryPerSandbox',
    :'max_disk_per_sandbox' => :'maxDiskPerSandbox',
    :'secret_quota' => :'secretQuota',
    :'max_secrets_per_sandbox' => :'maxSecretsPerSandbox',
    :'snapshot_deactivation_timeout_minutes' => :'snapshotDeactivationTimeoutMinutes',
    :'sandbox_limited_network_egress' => :'sandboxLimitedNetworkEgress',
    :'preview_warning_enabled' => :'previewWarningEnabled',
    :'sso_enabled' => :'ssoEnabled',
    :'default_region_id' => :'defaultRegionId',
    :'authenticated_rate_limit' => :'authenticatedRateLimit',
    :'sandbox_create_rate_limit' => :'sandboxCreateRateLimit',
    :'sandbox_lifecycle_rate_limit' => :'sandboxLifecycleRateLimit',
    :'experimental_config' => :'experimentalConfig',
    :'otel_config' => :'otelConfig',
    :'authenticated_rate_limit_ttl_seconds' => :'authenticatedRateLimitTtlSeconds',
    :'sandbox_create_rate_limit_ttl_seconds' => :'sandboxCreateRateLimitTtlSeconds',
    :'sandbox_lifecycle_rate_limit_ttl_seconds' => :'sandboxLifecycleRateLimitTtlSeconds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
# File 'lib/daytona_api_client/models/organization.rb', line 768

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



186
187
188
189
190
191
192
193
194
195
196
# File 'lib/daytona_api_client/models/organization.rb', line 186

def self.openapi_nullable
  Set.new([
    :'authenticated_rate_limit',
    :'sandbox_create_rate_limit',
    :'sandbox_lifecycle_rate_limit',
    :'otel_config',
    :'authenticated_rate_limit_ttl_seconds',
    :'sandbox_create_rate_limit_ttl_seconds',
    :'sandbox_lifecycle_rate_limit_ttl_seconds'
  ])
end

.openapi_typesObject

Attribute type mapping.



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/daytona_api_client/models/organization.rb', line 151

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'created_by' => :'String',
    :'personal' => :'Boolean',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'suspended' => :'Boolean',
    :'suspended_at' => :'Time',
    :'suspension_reason' => :'String',
    :'suspended_until' => :'Time',
    :'suspension_cleanup_grace_period_hours' => :'Float',
    :'max_cpu_per_sandbox' => :'Float',
    :'max_memory_per_sandbox' => :'Float',
    :'max_disk_per_sandbox' => :'Float',
    :'secret_quota' => :'Float',
    :'max_secrets_per_sandbox' => :'Float',
    :'snapshot_deactivation_timeout_minutes' => :'Float',
    :'sandbox_limited_network_egress' => :'Boolean',
    :'preview_warning_enabled' => :'Boolean',
    :'sso_enabled' => :'Boolean',
    :'default_region_id' => :'String',
    :'authenticated_rate_limit' => :'Float',
    :'sandbox_create_rate_limit' => :'Float',
    :'sandbox_lifecycle_rate_limit' => :'Float',
    :'experimental_config' => :'Object',
    :'otel_config' => :'OtelConfig',
    :'authenticated_rate_limit_ttl_seconds' => :'Float',
    :'sandbox_create_rate_limit_ttl_seconds' => :'Float',
    :'sandbox_lifecycle_rate_limit_ttl_seconds' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
# File 'lib/daytona_api_client/models/organization.rb', line 719

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      created_by == o.created_by &&
      personal == o.personal &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      suspended == o.suspended &&
      suspended_at == o.suspended_at &&
      suspension_reason == o.suspension_reason &&
      suspended_until == o.suspended_until &&
      suspension_cleanup_grace_period_hours == o.suspension_cleanup_grace_period_hours &&
      max_cpu_per_sandbox == o.max_cpu_per_sandbox &&
      max_memory_per_sandbox == o.max_memory_per_sandbox &&
      max_disk_per_sandbox == o.max_disk_per_sandbox &&
      secret_quota == o.secret_quota &&
      max_secrets_per_sandbox == o.max_secrets_per_sandbox &&
      snapshot_deactivation_timeout_minutes == o.snapshot_deactivation_timeout_minutes &&
      sandbox_limited_network_egress == o.sandbox_limited_network_egress &&
      preview_warning_enabled == o.preview_warning_enabled &&
      sso_enabled == o.sso_enabled &&
      default_region_id == o.default_region_id &&
      authenticated_rate_limit == o.authenticated_rate_limit &&
      sandbox_create_rate_limit == o.sandbox_create_rate_limit &&
      sandbox_lifecycle_rate_limit == o.sandbox_lifecycle_rate_limit &&
      experimental_config == o.experimental_config &&
      otel_config == o.otel_config &&
      authenticated_rate_limit_ttl_seconds == o.authenticated_rate_limit_ttl_seconds &&
      sandbox_create_rate_limit_ttl_seconds == o.sandbox_create_rate_limit_ttl_seconds &&
      sandbox_lifecycle_rate_limit_ttl_seconds == o.sandbox_lifecycle_rate_limit_ttl_seconds
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


755
756
757
# File 'lib/daytona_api_client/models/organization.rb', line 755

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



761
762
763
# File 'lib/daytona_api_client/models/organization.rb', line 761

def hash
  [id, name, created_by, personal, created_at, updated_at, suspended, suspended_at, suspension_reason, suspended_until, suspension_cleanup_grace_period_hours, max_cpu_per_sandbox, max_memory_per_sandbox, max_disk_per_sandbox, secret_quota, max_secrets_per_sandbox, snapshot_deactivation_timeout_minutes, sandbox_limited_network_egress, preview_warning_enabled, sso_enabled, default_region_id, authenticated_rate_limit, sandbox_create_rate_limit, sandbox_lifecycle_rate_limit, experimental_config, otel_config, authenticated_rate_limit_ttl_seconds, sandbox_create_rate_limit_ttl_seconds, sandbox_lifecycle_rate_limit_ttl_seconds].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/daytona_api_client/models/organization.rb', line 389

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @personal.nil?
    invalid_properties.push('invalid value for "personal", personal cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @suspended.nil?
    invalid_properties.push('invalid value for "suspended", suspended cannot be nil.')
  end

  if @suspended_at.nil?
    invalid_properties.push('invalid value for "suspended_at", suspended_at cannot be nil.')
  end

  if @suspension_reason.nil?
    invalid_properties.push('invalid value for "suspension_reason", suspension_reason cannot be nil.')
  end

  if @suspended_until.nil?
    invalid_properties.push('invalid value for "suspended_until", suspended_until cannot be nil.')
  end

  if @suspension_cleanup_grace_period_hours.nil?
    invalid_properties.push('invalid value for "suspension_cleanup_grace_period_hours", suspension_cleanup_grace_period_hours cannot be nil.')
  end

  if @max_cpu_per_sandbox.nil?
    invalid_properties.push('invalid value for "max_cpu_per_sandbox", max_cpu_per_sandbox cannot be nil.')
  end

  if @max_memory_per_sandbox.nil?
    invalid_properties.push('invalid value for "max_memory_per_sandbox", max_memory_per_sandbox cannot be nil.')
  end

  if @max_disk_per_sandbox.nil?
    invalid_properties.push('invalid value for "max_disk_per_sandbox", max_disk_per_sandbox cannot be nil.')
  end

  if @secret_quota.nil?
    invalid_properties.push('invalid value for "secret_quota", secret_quota cannot be nil.')
  end

  if @max_secrets_per_sandbox.nil?
    invalid_properties.push('invalid value for "max_secrets_per_sandbox", max_secrets_per_sandbox cannot be nil.')
  end

  if @snapshot_deactivation_timeout_minutes.nil?
    invalid_properties.push('invalid value for "snapshot_deactivation_timeout_minutes", snapshot_deactivation_timeout_minutes cannot be nil.')
  end

  if @sandbox_limited_network_egress.nil?
    invalid_properties.push('invalid value for "sandbox_limited_network_egress", sandbox_limited_network_egress cannot be nil.')
  end

  if @preview_warning_enabled.nil?
    invalid_properties.push('invalid value for "preview_warning_enabled", preview_warning_enabled cannot be nil.')
  end

  if @sso_enabled.nil?
    invalid_properties.push('invalid value for "sso_enabled", sso_enabled cannot be nil.')
  end

  if @experimental_config.nil?
    invalid_properties.push('invalid value for "experimental_config", experimental_config cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



790
791
792
793
794
795
796
797
798
799
800
801
802
# File 'lib/daytona_api_client/models/organization.rb', line 790

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/daytona_api_client/models/organization.rb', line 481

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @created_by.nil?
  return false if @personal.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if @suspended.nil?
  return false if @suspended_at.nil?
  return false if @suspension_reason.nil?
  return false if @suspended_until.nil?
  return false if @suspension_cleanup_grace_period_hours.nil?
  return false if @max_cpu_per_sandbox.nil?
  return false if @max_memory_per_sandbox.nil?
  return false if @max_disk_per_sandbox.nil?
  return false if @secret_quota.nil?
  return false if @max_secrets_per_sandbox.nil?
  return false if @snapshot_deactivation_timeout_minutes.nil?
  return false if @sandbox_limited_network_egress.nil?
  return false if @preview_warning_enabled.nil?
  return false if @sso_enabled.nil?
  return false if @experimental_config.nil?
  true
end