Class: DaytonaApiClient::OrganizationUsageOverview

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/daytona_api_client/models/organization_usage_overview.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrganizationUsageOverview

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::OrganizationUsageOverview` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::OrganizationUsageOverview`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'region_usage')
    if (value = attributes[:'region_usage']).is_a?(Array)
      self.region_usage = value
    end
  else
    self.region_usage = nil
  end

  if attributes.key?(:'total_snapshot_quota')
    self.total_snapshot_quota = attributes[:'total_snapshot_quota']
  else
    self.total_snapshot_quota = nil
  end

  if attributes.key?(:'current_snapshot_usage')
    self.current_snapshot_usage = attributes[:'current_snapshot_usage']
  else
    self.current_snapshot_usage = nil
  end

  if attributes.key?(:'total_volume_quota')
    self.total_volume_quota = attributes[:'total_volume_quota']
  else
    self.total_volume_quota = nil
  end

  if attributes.key?(:'current_volume_usage')
    self.current_volume_usage = attributes[:'current_volume_usage']
  else
    self.current_volume_usage = nil
  end
end

Instance Attribute Details

#current_snapshot_usageObject

Returns the value of attribute current_snapshot_usage.



22
23
24
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 22

def current_snapshot_usage
  @current_snapshot_usage
end

#current_volume_usageObject

Returns the value of attribute current_volume_usage.



26
27
28
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 26

def current_volume_usage
  @current_volume_usage
end

#region_usageObject

Returns the value of attribute region_usage.



18
19
20
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 18

def region_usage
  @region_usage
end

#total_snapshot_quotaObject

Returns the value of attribute total_snapshot_quota.



20
21
22
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 20

def total_snapshot_quota
  @total_snapshot_quota
end

#total_volume_quotaObject

Returns the value of attribute total_volume_quota.



24
25
26
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 24

def total_volume_quota
  @total_volume_quota
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 29

def self.attribute_map
  {
    :'region_usage' => :'regionUsage',
    :'total_snapshot_quota' => :'totalSnapshotQuota',
    :'current_snapshot_usage' => :'currentSnapshotUsage',
    :'total_volume_quota' => :'totalVolumeQuota',
    :'current_volume_usage' => :'currentVolumeUsage'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 232

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 50

def self.openapi_types
  {
    :'region_usage' => :'Array<RegionUsageOverview>',
    :'total_snapshot_quota' => :'Float',
    :'current_snapshot_usage' => :'Float',
    :'total_volume_quota' => :'Float',
    :'current_volume_usage' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



207
208
209
210
211
212
213
214
215
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 207

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      region_usage == o.region_usage &&
      total_snapshot_quota == o.total_snapshot_quota &&
      current_snapshot_usage == o.current_snapshot_usage &&
      total_volume_quota == o.total_volume_quota &&
      current_volume_usage == o.current_volume_usage
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 219

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



225
226
227
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 225

def hash
  [region_usage, total_snapshot_quota, current_snapshot_usage, total_volume_quota, current_volume_usage].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @region_usage.nil?
    invalid_properties.push('invalid value for "region_usage", region_usage cannot be nil.')
  end

  if @total_snapshot_quota.nil?
    invalid_properties.push('invalid value for "total_snapshot_quota", total_snapshot_quota cannot be nil.')
  end

  if @current_snapshot_usage.nil?
    invalid_properties.push('invalid value for "current_snapshot_usage", current_snapshot_usage cannot be nil.')
  end

  if @total_volume_quota.nil?
    invalid_properties.push('invalid value for "total_volume_quota", total_volume_quota cannot be nil.')
  end

  if @current_volume_usage.nil?
    invalid_properties.push('invalid value for "current_volume_usage", current_volume_usage cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 254

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
150
151
152
153
# File 'lib/daytona_api_client/models/organization_usage_overview.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @region_usage.nil?
  return false if @total_snapshot_quota.nil?
  return false if @current_snapshot_usage.nil?
  return false if @total_volume_quota.nil?
  return false if @current_volume_usage.nil?
  true
end