Class: DaytonaApiClient::PreviewApi
- Inherits:
-
Object
- Object
- DaytonaApiClient::PreviewApi
- Defined in:
- lib/daytona_api_client/api/preview_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_sandbox_id_from_signed_preview_url_token(signed_preview_token, port, opts = {}) ⇒ String
Get sandbox ID from signed preview URL token.
-
#get_sandbox_id_from_signed_preview_url_token_with_http_info(signed_preview_token, port, opts = {}) ⇒ Array<(String, Integer, Hash)>
Get sandbox ID from signed preview URL token.
-
#get_signing_key(sandbox_id, opts = {}) ⇒ String
Get the signing key for a sandbox.
-
#get_signing_key_with_http_info(sandbox_id, opts = {}) ⇒ Array<(String, Integer, Hash)>
Get the signing key for a sandbox.
-
#has_sandbox_access(sandbox_id, opts = {}) ⇒ Boolean
Check if user has access to the sandbox.
-
#has_sandbox_access_with_http_info(sandbox_id, opts = {}) ⇒ Array<(Boolean, Integer, Hash)>
Check if user has access to the sandbox.
-
#initialize(api_client = ApiClient.default) ⇒ PreviewApi
constructor
A new instance of PreviewApi.
-
#is_preview_warning_enabled(sandbox_id, opts = {}) ⇒ PreviewWarning
Check if the preview warning page is enabled for the sandbox.
-
#is_preview_warning_enabled_with_http_info(sandbox_id, opts = {}) ⇒ Array<(PreviewWarning, Integer, Hash)>
Check if the preview warning page is enabled for the sandbox.
-
#is_sandbox_public(sandbox_id, opts = {}) ⇒ Boolean
Check if sandbox is public.
-
#is_sandbox_public_with_http_info(sandbox_id, opts = {}) ⇒ Array<(Boolean, Integer, Hash)>
Check if sandbox is public.
-
#is_valid_auth_token(sandbox_id, auth_token, opts = {}) ⇒ Boolean
Check if sandbox auth token is valid.
-
#is_valid_auth_token_with_http_info(sandbox_id, auth_token, opts = {}) ⇒ Array<(Boolean, Integer, Hash)>
Check if sandbox auth token is valid.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PreviewApi
Returns a new instance of PreviewApi.
19 20 21 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_sandbox_id_from_signed_preview_url_token(signed_preview_token, port, opts = {}) ⇒ String
Get sandbox ID from signed preview URL token
27 28 29 30 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 27 def get_sandbox_id_from_signed_preview_url_token(signed_preview_token, port, opts = {}) data, _status_code, _headers = get_sandbox_id_from_signed_preview_url_token_with_http_info(signed_preview_token, port, opts) data end |
#get_sandbox_id_from_signed_preview_url_token_with_http_info(signed_preview_token, port, opts = {}) ⇒ Array<(String, Integer, Hash)>
Get sandbox ID from signed preview URL token
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 37 def get_sandbox_id_from_signed_preview_url_token_with_http_info(signed_preview_token, port, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PreviewApi.get_sandbox_id_from_signed_preview_url_token ...' end # verify the required parameter 'signed_preview_token' is set if @api_client.config.client_side_validation && signed_preview_token.nil? fail ArgumentError, "Missing the required parameter 'signed_preview_token' when calling PreviewApi.get_sandbox_id_from_signed_preview_url_token" end # verify the required parameter 'port' is set if @api_client.config.client_side_validation && port.nil? fail ArgumentError, "Missing the required parameter 'port' when calling PreviewApi.get_sandbox_id_from_signed_preview_url_token" end # resource path local_var_path = '/preview/{signedPreviewToken}/{port}/sandbox-id'.sub('{' + 'signedPreviewToken' + '}', CGI.escape(signed_preview_token.to_s)).sub('{' + 'port' + '}', CGI.escape(port.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'String' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"PreviewApi.get_sandbox_id_from_signed_preview_url_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PreviewApi#get_sandbox_id_from_signed_preview_url_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_signing_key(sandbox_id, opts = {}) ⇒ String
Get the signing key for a sandbox
93 94 95 96 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 93 def get_signing_key(sandbox_id, opts = {}) data, _status_code, _headers = get_signing_key_with_http_info(sandbox_id, opts) data end |
#get_signing_key_with_http_info(sandbox_id, opts = {}) ⇒ Array<(String, Integer, Hash)>
Get the signing key for a sandbox
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 102 def get_signing_key_with_http_info(sandbox_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PreviewApi.get_signing_key ...' end # verify the required parameter 'sandbox_id' is set if @api_client.config.client_side_validation && sandbox_id.nil? fail ArgumentError, "Missing the required parameter 'sandbox_id' when calling PreviewApi.get_signing_key" end # resource path local_var_path = '/preview/{sandboxId}/signing-key'.sub('{' + 'sandboxId' + '}', CGI.escape(sandbox_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'String' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"PreviewApi.get_signing_key", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PreviewApi#get_signing_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#has_sandbox_access(sandbox_id, opts = {}) ⇒ Boolean
Check if user has access to the sandbox
154 155 156 157 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 154 def has_sandbox_access(sandbox_id, opts = {}) data, _status_code, _headers = has_sandbox_access_with_http_info(sandbox_id, opts) data end |
#has_sandbox_access_with_http_info(sandbox_id, opts = {}) ⇒ Array<(Boolean, Integer, Hash)>
Check if user has access to the sandbox
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 163 def has_sandbox_access_with_http_info(sandbox_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PreviewApi.has_sandbox_access ...' end # verify the required parameter 'sandbox_id' is set if @api_client.config.client_side_validation && sandbox_id.nil? fail ArgumentError, "Missing the required parameter 'sandbox_id' when calling PreviewApi.has_sandbox_access" end # resource path local_var_path = '/preview/{sandboxId}/access'.sub('{' + 'sandboxId' + '}', CGI.escape(sandbox_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Boolean' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"PreviewApi.has_sandbox_access", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PreviewApi#has_sandbox_access\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#is_preview_warning_enabled(sandbox_id, opts = {}) ⇒ PreviewWarning
Check if the preview warning page is enabled for the sandbox
216 217 218 219 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 216 def is_preview_warning_enabled(sandbox_id, opts = {}) data, _status_code, _headers = is_preview_warning_enabled_with_http_info(sandbox_id, opts) data end |
#is_preview_warning_enabled_with_http_info(sandbox_id, opts = {}) ⇒ Array<(PreviewWarning, Integer, Hash)>
Check if the preview warning page is enabled for the sandbox
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 226 def is_preview_warning_enabled_with_http_info(sandbox_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PreviewApi.is_preview_warning_enabled ...' end # verify the required parameter 'sandbox_id' is set if @api_client.config.client_side_validation && sandbox_id.nil? fail ArgumentError, "Missing the required parameter 'sandbox_id' when calling PreviewApi.is_preview_warning_enabled" end # resource path local_var_path = '/preview/{sandboxId}/preview-warning'.sub('{' + 'sandboxId' + '}', CGI.escape(sandbox_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'port'] = opts[:'port'] if !opts[:'port'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PreviewWarning' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"PreviewApi.is_preview_warning_enabled", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PreviewApi#is_preview_warning_enabled\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#is_sandbox_public(sandbox_id, opts = {}) ⇒ Boolean
Check if sandbox is public
279 280 281 282 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 279 def is_sandbox_public(sandbox_id, opts = {}) data, _status_code, _headers = is_sandbox_public_with_http_info(sandbox_id, opts) data end |
#is_sandbox_public_with_http_info(sandbox_id, opts = {}) ⇒ Array<(Boolean, Integer, Hash)>
Check if sandbox is public
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 288 def is_sandbox_public_with_http_info(sandbox_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PreviewApi.is_sandbox_public ...' end # verify the required parameter 'sandbox_id' is set if @api_client.config.client_side_validation && sandbox_id.nil? fail ArgumentError, "Missing the required parameter 'sandbox_id' when calling PreviewApi.is_sandbox_public" end # resource path local_var_path = '/preview/{sandboxId}/public'.sub('{' + 'sandboxId' + '}', CGI.escape(sandbox_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Boolean' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"PreviewApi.is_sandbox_public", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PreviewApi#is_sandbox_public\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#is_valid_auth_token(sandbox_id, auth_token, opts = {}) ⇒ Boolean
Check if sandbox auth token is valid
341 342 343 344 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 341 def is_valid_auth_token(sandbox_id, auth_token, opts = {}) data, _status_code, _headers = is_valid_auth_token_with_http_info(sandbox_id, auth_token, opts) data end |
#is_valid_auth_token_with_http_info(sandbox_id, auth_token, opts = {}) ⇒ Array<(Boolean, Integer, Hash)>
Check if sandbox auth token is valid
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/daytona_api_client/api/preview_api.rb', line 351 def is_valid_auth_token_with_http_info(sandbox_id, auth_token, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PreviewApi.is_valid_auth_token ...' end # verify the required parameter 'sandbox_id' is set if @api_client.config.client_side_validation && sandbox_id.nil? fail ArgumentError, "Missing the required parameter 'sandbox_id' when calling PreviewApi.is_valid_auth_token" end # verify the required parameter 'auth_token' is set if @api_client.config.client_side_validation && auth_token.nil? fail ArgumentError, "Missing the required parameter 'auth_token' when calling PreviewApi.is_valid_auth_token" end # resource path local_var_path = '/preview/{sandboxId}/validate/{authToken}'.sub('{' + 'sandboxId' + '}', CGI.escape(sandbox_id.to_s)).sub('{' + 'authToken' + '}', CGI.escape(auth_token.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Boolean' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"PreviewApi.is_valid_auth_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PreviewApi#is_valid_auth_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |