Class: DaytonaApiClient::PtyCreateRequest

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/pty_create_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PtyCreateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::PtyCreateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::PtyCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'cwd')
    self.cwd = attributes[:'cwd']
  end

  if attributes.key?(:'envs')
    self.envs = attributes[:'envs']
  end

  if attributes.key?(:'cols')
    self.cols = attributes[:'cols']
  end

  if attributes.key?(:'rows')
    self.rows = attributes[:'rows']
  end

  if attributes.key?(:'lazy_start')
    self.lazy_start = attributes[:'lazy_start']
  else
    self.lazy_start = false
  end
end

Instance Attribute Details

#colsObject

Number of terminal columns



28
29
30
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 28

def cols
  @cols
end

#cwdObject

Starting directory for the PTY session, defaults to the sandbox’s working directory



22
23
24
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 22

def cwd
  @cwd
end

#envsObject

Environment variables for the PTY session



25
26
27
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 25

def envs
  @envs
end

#idObject

The unique identifier for the PTY session



19
20
21
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 19

def id
  @id
end

#lazy_startObject

Whether to start the PTY session lazily (only start when first client connects)



34
35
36
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 34

def lazy_start
  @lazy_start
end

#rowsObject

Number of terminal rows



31
32
33
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 31

def rows
  @rows
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 37

def self.attribute_map
  {
    :'id' => :'id',
    :'cwd' => :'cwd',
    :'envs' => :'envs',
    :'cols' => :'cols',
    :'rows' => :'rows',
    :'lazy_start' => :'lazyStart'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 179

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 59

def self.openapi_types
  {
    :'id' => :'String',
    :'cwd' => :'String',
    :'envs' => :'Object',
    :'cols' => :'Float',
    :'rows' => :'Float',
    :'lazy_start' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
159
160
161
162
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      cwd == o.cwd &&
      envs == o.envs &&
      cols == o.cols &&
      rows == o.rows &&
      lazy_start == o.lazy_start
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


166
167
168
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 166

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



172
173
174
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 172

def hash
  [id, cwd, envs, cols, rows, lazy_start].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



123
124
125
126
127
128
129
130
131
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 123

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 201

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
139
# File 'lib/daytona_api_client/models/pty_create_request.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end