Class: DaytonaApiClient::Region

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/region.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Region

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/daytona_api_client/models/region.rb', line 125

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::Region` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::Region`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'region_type')
    self.region_type = attributes[:'region_type']
  else
    self.region_type = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'proxy_url')
    self.proxy_url = attributes[:'proxy_url']
  end

  if attributes.key?(:'ssh_gateway_url')
    self.ssh_gateway_url = attributes[:'ssh_gateway_url']
  end

  if attributes.key?(:'snapshot_manager_url')
    self.snapshot_manager_url = attributes[:'snapshot_manager_url']
  end

  if attributes.key?(:'otel_endpoint')
    self.otel_endpoint = attributes[:'otel_endpoint']
  end
end

Instance Attribute Details

#created_atObject

Creation timestamp



31
32
33
# File 'lib/daytona_api_client/models/region.rb', line 31

def created_at
  @created_at
end

#idObject

Region ID



19
20
21
# File 'lib/daytona_api_client/models/region.rb', line 19

def id
  @id
end

#nameObject

Region name



22
23
24
# File 'lib/daytona_api_client/models/region.rb', line 22

def name
  @name
end

#organization_idObject

Organization ID



25
26
27
# File 'lib/daytona_api_client/models/region.rb', line 25

def organization_id
  @organization_id
end

#otel_endpointObject

OTel collector endpoint for sandboxes created in this region. When set, sandbox OTel data is sent to this endpoint instead of the Daytona-hosted collector and will not be available in the Daytona analytics API or dashboard.



46
47
48
# File 'lib/daytona_api_client/models/region.rb', line 46

def otel_endpoint
  @otel_endpoint
end

#proxy_urlObject

Proxy URL for the region



37
38
39
# File 'lib/daytona_api_client/models/region.rb', line 37

def proxy_url
  @proxy_url
end

#region_typeObject

The type of the region



28
29
30
# File 'lib/daytona_api_client/models/region.rb', line 28

def region_type
  @region_type
end

#snapshot_manager_urlObject

Snapshot Manager URL for the region



43
44
45
# File 'lib/daytona_api_client/models/region.rb', line 43

def snapshot_manager_url
  @snapshot_manager_url
end

#ssh_gateway_urlObject

SSH Gateway URL for the region



40
41
42
# File 'lib/daytona_api_client/models/region.rb', line 40

def ssh_gateway_url
  @ssh_gateway_url
end

#updated_atObject

Last update timestamp



34
35
36
# File 'lib/daytona_api_client/models/region.rb', line 34

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



87
88
89
# File 'lib/daytona_api_client/models/region.rb', line 87

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/daytona_api_client/models/region.rb', line 92

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/daytona_api_client/models/region.rb', line 71

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'organization_id' => :'organizationId',
    :'region_type' => :'regionType',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'proxy_url' => :'proxyUrl',
    :'ssh_gateway_url' => :'sshGatewayUrl',
    :'snapshot_manager_url' => :'snapshotManagerUrl',
    :'otel_endpoint' => :'otelEndpoint'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/daytona_api_client/models/region.rb', line 312

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
117
118
119
120
121
# File 'lib/daytona_api_client/models/region.rb', line 113

def self.openapi_nullable
  Set.new([
    :'organization_id',
    :'proxy_url',
    :'ssh_gateway_url',
    :'snapshot_manager_url',
    :'otel_endpoint'
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/daytona_api_client/models/region.rb', line 97

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'organization_id' => :'String',
    :'region_type' => :'RegionType',
    :'created_at' => :'String',
    :'updated_at' => :'String',
    :'proxy_url' => :'String',
    :'ssh_gateway_url' => :'String',
    :'snapshot_manager_url' => :'String',
    :'otel_endpoint' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/daytona_api_client/models/region.rb', line 282

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      organization_id == o.organization_id &&
      region_type == o.region_type &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      proxy_url == o.proxy_url &&
      ssh_gateway_url == o.ssh_gateway_url &&
      snapshot_manager_url == o.snapshot_manager_url &&
      otel_endpoint == o.otel_endpoint
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


299
300
301
# File 'lib/daytona_api_client/models/region.rb', line 299

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



305
306
307
# File 'lib/daytona_api_client/models/region.rb', line 305

def hash
  [id, name, organization_id, region_type, created_at, updated_at, proxy_url, ssh_gateway_url, snapshot_manager_url, otel_endpoint].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/daytona_api_client/models/region.rb', line 192

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @region_type.nil?
    invalid_properties.push('invalid value for "region_type", region_type cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/daytona_api_client/models/region.rb', line 334

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



220
221
222
223
224
225
226
227
228
# File 'lib/daytona_api_client/models/region.rb', line 220

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @region_type.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end