Class: DaytonaApiClient::RegistryPushAccessDto

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/daytona_api_client/models/registry_push_access_dto.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RegistryPushAccessDto

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::RegistryPushAccessDto` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::RegistryPushAccessDto`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  else
    self.username = nil
  end

  if attributes.key?(:'secret')
    self.secret = attributes[:'secret']
  else
    self.secret = nil
  end

  if attributes.key?(:'registry_url')
    self.registry_url = attributes[:'registry_url']
  else
    self.registry_url = nil
  end

  if attributes.key?(:'registry_id')
    self.registry_id = attributes[:'registry_id']
  else
    self.registry_id = nil
  end

  if attributes.key?(:'project')
    self.project = attributes[:'project']
  else
    self.project = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end
end

Instance Attribute Details

#expires_atObject

Token expiration time in ISO format



34
35
36
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 34

def expires_at
  @expires_at
end

#projectObject

Registry project ID



31
32
33
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 31

def project
  @project
end

#registry_idObject

Registry ID



28
29
30
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 28

def registry_id
  @registry_id
end

#registry_urlObject

Registry URL



25
26
27
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 25

def registry_url
  @registry_url
end

#secretObject

Temporary secret for registry authentication



22
23
24
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 22

def secret
  @secret
end

#usernameObject

Temporary username for registry authentication



19
20
21
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 19

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 37

def self.attribute_map
  {
    :'username' => :'username',
    :'secret' => :'secret',
    :'registry_url' => :'registryUrl',
    :'registry_id' => :'registryId',
    :'project' => :'project',
    :'expires_at' => :'expiresAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 262

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 59

def self.openapi_types
  {
    :'username' => :'String',
    :'secret' => :'String',
    :'registry_url' => :'String',
    :'registry_id' => :'String',
    :'project' => :'String',
    :'expires_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



236
237
238
239
240
241
242
243
244
245
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 236

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      username == o.username &&
      secret == o.secret &&
      registry_url == o.registry_url &&
      registry_id == o.registry_id &&
      project == o.project &&
      expires_at == o.expires_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


249
250
251
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 249

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



255
256
257
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 255

def hash
  [username, secret, registry_url, registry_id, project, expires_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @username.nil?
    invalid_properties.push('invalid value for "username", username cannot be nil.')
  end

  if @secret.nil?
    invalid_properties.push('invalid value for "secret", secret cannot be nil.')
  end

  if @registry_url.nil?
    invalid_properties.push('invalid value for "registry_url", registry_url cannot be nil.')
  end

  if @registry_id.nil?
    invalid_properties.push('invalid value for "registry_id", registry_id cannot be nil.')
  end

  if @project.nil?
    invalid_properties.push('invalid value for "project", project cannot be nil.')
  end

  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 284

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
167
168
169
170
171
172
# File 'lib/daytona_api_client/models/registry_push_access_dto.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @username.nil?
  return false if @secret.nil?
  return false if @registry_url.nil?
  return false if @registry_id.nil?
  return false if @project.nil?
  return false if @expires_at.nil?
  true
end