Class: DaytonaApiClient::ResizeSandbox

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/resize_sandbox.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ResizeSandbox

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 63

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::ResizeSandbox` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::ResizeSandbox`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cpu')
    self.cpu = attributes[:'cpu']
  end

  if attributes.key?(:'memory')
    self.memory = attributes[:'memory']
  end

  if attributes.key?(:'disk')
    self.disk = attributes[:'disk']
  end
end

Instance Attribute Details

#cpuObject

CPU cores to allocate to the sandbox (minimum: 1)



19
20
21
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 19

def cpu
  @cpu
end

#diskObject

Disk space in GB to allocate to the sandbox (can only be increased)



25
26
27
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 25

def disk
  @disk
end

#memoryObject

Memory in GB to allocate to the sandbox (minimum: 1)



22
23
24
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 22

def memory
  @memory
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 28

def self.attribute_map
  {
    :'cpu' => :'cpu',
    :'memory' => :'memory',
    :'disk' => :'disk'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 187

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 56

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 47

def self.openapi_types
  {
    :'cpu' => :'Integer',
    :'memory' => :'Integer',
    :'disk' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



164
165
166
167
168
169
170
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 164

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cpu == o.cpu &&
      memory == o.memory &&
      disk == o.disk
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


174
175
176
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 174

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



180
181
182
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 180

def hash
  [cpu, memory, disk].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 92

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@cpu.nil? && @cpu < 1
    invalid_properties.push('invalid value for "cpu", must be greater than or equal to 1.')
  end

  if !@memory.nil? && @memory < 1
    invalid_properties.push('invalid value for "memory", must be greater than or equal to 1.')
  end

  if !@disk.nil? && @disk < 1
    invalid_properties.push('invalid value for "disk", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 209

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



112
113
114
115
116
117
118
# File 'lib/daytona_api_client/models/resize_sandbox.rb', line 112

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@cpu.nil? && @cpu < 1
  return false if !@memory.nil? && @memory < 1
  return false if !@disk.nil? && @disk < 1
  true
end