Class: DaytonaApiClient::RunnerHealthMetrics

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/runner_health_metrics.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RunnerHealthMetrics

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::RunnerHealthMetrics` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::RunnerHealthMetrics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'current_cpu_load_average')
    self.current_cpu_load_average = attributes[:'current_cpu_load_average']
  else
    self.current_cpu_load_average = nil
  end

  if attributes.key?(:'current_cpu_usage_percentage')
    self.current_cpu_usage_percentage = attributes[:'current_cpu_usage_percentage']
  else
    self.current_cpu_usage_percentage = nil
  end

  if attributes.key?(:'current_memory_usage_percentage')
    self.current_memory_usage_percentage = attributes[:'current_memory_usage_percentage']
  else
    self.current_memory_usage_percentage = nil
  end

  if attributes.key?(:'current_disk_usage_percentage')
    self.current_disk_usage_percentage = attributes[:'current_disk_usage_percentage']
  else
    self.current_disk_usage_percentage = nil
  end

  if attributes.key?(:'current_allocated_cpu')
    self.current_allocated_cpu = attributes[:'current_allocated_cpu']
  else
    self.current_allocated_cpu = nil
  end

  if attributes.key?(:'current_allocated_memory_gi_b')
    self.current_allocated_memory_gi_b = attributes[:'current_allocated_memory_gi_b']
  else
    self.current_allocated_memory_gi_b = nil
  end

  if attributes.key?(:'current_allocated_disk_gi_b')
    self.current_allocated_disk_gi_b = attributes[:'current_allocated_disk_gi_b']
  else
    self.current_allocated_disk_gi_b = nil
  end

  if attributes.key?(:'current_snapshot_count')
    self.current_snapshot_count = attributes[:'current_snapshot_count']
  else
    self.current_snapshot_count = nil
  end

  if attributes.key?(:'current_started_sandboxes')
    self.current_started_sandboxes = attributes[:'current_started_sandboxes']
  else
    self.current_started_sandboxes = nil
  end

  if attributes.key?(:'cpu')
    self.cpu = attributes[:'cpu']
  else
    self.cpu = nil
  end

  if attributes.key?(:'memory_gi_b')
    self.memory_gi_b = attributes[:'memory_gi_b']
  else
    self.memory_gi_b = nil
  end

  if attributes.key?(:'disk_gi_b')
    self.disk_gi_b = attributes[:'disk_gi_b']
  else
    self.disk_gi_b = nil
  end

  if attributes.key?(:'gpu')
    self.gpu = attributes[:'gpu']
  end

  if attributes.key?(:'gpu_type')
    self.gpu_type = attributes[:'gpu_type']
  end
end

Instance Attribute Details

#cpuObject

Total CPU cores on the runner



46
47
48
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 46

def cpu
  @cpu
end

#current_allocated_cpuObject

Currently allocated CPU cores



31
32
33
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 31

def current_allocated_cpu
  @current_allocated_cpu
end

#current_allocated_disk_gi_bObject

Currently allocated disk in GiB



37
38
39
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 37

def current_allocated_disk_gi_b
  @current_allocated_disk_gi_b
end

#current_allocated_memory_gi_bObject

Currently allocated memory in GiB



34
35
36
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 34

def current_allocated_memory_gi_b
  @current_allocated_memory_gi_b
end

#current_cpu_load_averageObject

Current CPU load average



19
20
21
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 19

def current_cpu_load_average
  @current_cpu_load_average
end

#current_cpu_usage_percentageObject

Current CPU usage percentage



22
23
24
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 22

def current_cpu_usage_percentage
  @current_cpu_usage_percentage
end

#current_disk_usage_percentageObject

Current disk usage percentage



28
29
30
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 28

def current_disk_usage_percentage
  @current_disk_usage_percentage
end

#current_memory_usage_percentageObject

Current memory usage percentage



25
26
27
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 25

def current_memory_usage_percentage
  @current_memory_usage_percentage
end

#current_snapshot_countObject

Number of snapshots currently stored



40
41
42
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 40

def current_snapshot_count
  @current_snapshot_count
end

#current_started_sandboxesObject

Number of started sandboxes



43
44
45
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 43

def current_started_sandboxes
  @current_started_sandboxes
end

#disk_gi_bObject

Total disk space in GiB on the runner



52
53
54
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 52

def disk_gi_b
  @disk_gi_b
end

#gpuObject

Total number of GPUs on the runner



55
56
57
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 55

def gpu
  @gpu
end

#gpu_typeObject

GPU model name



58
59
60
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 58

def gpu_type
  @gpu_type
end

#memory_gi_bObject

Total RAM in GiB on the runner



49
50
51
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 49

def memory_gi_b
  @memory_gi_b
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 61

def self.attribute_map
  {
    :'current_cpu_load_average' => :'currentCpuLoadAverage',
    :'current_cpu_usage_percentage' => :'currentCpuUsagePercentage',
    :'current_memory_usage_percentage' => :'currentMemoryUsagePercentage',
    :'current_disk_usage_percentage' => :'currentDiskUsagePercentage',
    :'current_allocated_cpu' => :'currentAllocatedCpu',
    :'current_allocated_memory_gi_b' => :'currentAllocatedMemoryGiB',
    :'current_allocated_disk_gi_b' => :'currentAllocatedDiskGiB',
    :'current_snapshot_count' => :'currentSnapshotCount',
    :'current_started_sandboxes' => :'currentStartedSandboxes',
    :'cpu' => :'cpu',
    :'memory_gi_b' => :'memoryGiB',
    :'disk_gi_b' => :'diskGiB',
    :'gpu' => :'gpu',
    :'gpu_type' => :'gpuType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 444

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 111

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 91

def self.openapi_types
  {
    :'current_cpu_load_average' => :'Float',
    :'current_cpu_usage_percentage' => :'Float',
    :'current_memory_usage_percentage' => :'Float',
    :'current_disk_usage_percentage' => :'Float',
    :'current_allocated_cpu' => :'Float',
    :'current_allocated_memory_gi_b' => :'Float',
    :'current_allocated_disk_gi_b' => :'Float',
    :'current_snapshot_count' => :'Float',
    :'current_started_sandboxes' => :'Float',
    :'cpu' => :'Float',
    :'memory_gi_b' => :'Float',
    :'disk_gi_b' => :'Float',
    :'gpu' => :'Float',
    :'gpu_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 410

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      current_cpu_load_average == o.current_cpu_load_average &&
      current_cpu_usage_percentage == o.current_cpu_usage_percentage &&
      current_memory_usage_percentage == o.current_memory_usage_percentage &&
      current_disk_usage_percentage == o.current_disk_usage_percentage &&
      current_allocated_cpu == o.current_allocated_cpu &&
      current_allocated_memory_gi_b == o.current_allocated_memory_gi_b &&
      current_allocated_disk_gi_b == o.current_allocated_disk_gi_b &&
      current_snapshot_count == o.current_snapshot_count &&
      current_started_sandboxes == o.current_started_sandboxes &&
      cpu == o.cpu &&
      memory_gi_b == o.memory_gi_b &&
      disk_gi_b == o.disk_gi_b &&
      gpu == o.gpu &&
      gpu_type == o.gpu_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


431
432
433
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 431

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



437
438
439
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 437

def hash
  [current_cpu_load_average, current_cpu_usage_percentage, current_memory_usage_percentage, current_disk_usage_percentage, current_allocated_cpu, current_allocated_memory_gi_b, current_allocated_disk_gi_b, current_snapshot_count, current_started_sandboxes, cpu, memory_gi_b, disk_gi_b, gpu, gpu_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 215

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @current_cpu_load_average.nil?
    invalid_properties.push('invalid value for "current_cpu_load_average", current_cpu_load_average cannot be nil.')
  end

  if @current_cpu_usage_percentage.nil?
    invalid_properties.push('invalid value for "current_cpu_usage_percentage", current_cpu_usage_percentage cannot be nil.')
  end

  if @current_memory_usage_percentage.nil?
    invalid_properties.push('invalid value for "current_memory_usage_percentage", current_memory_usage_percentage cannot be nil.')
  end

  if @current_disk_usage_percentage.nil?
    invalid_properties.push('invalid value for "current_disk_usage_percentage", current_disk_usage_percentage cannot be nil.')
  end

  if @current_allocated_cpu.nil?
    invalid_properties.push('invalid value for "current_allocated_cpu", current_allocated_cpu cannot be nil.')
  end

  if @current_allocated_memory_gi_b.nil?
    invalid_properties.push('invalid value for "current_allocated_memory_gi_b", current_allocated_memory_gi_b cannot be nil.')
  end

  if @current_allocated_disk_gi_b.nil?
    invalid_properties.push('invalid value for "current_allocated_disk_gi_b", current_allocated_disk_gi_b cannot be nil.')
  end

  if @current_snapshot_count.nil?
    invalid_properties.push('invalid value for "current_snapshot_count", current_snapshot_count cannot be nil.')
  end

  if @current_started_sandboxes.nil?
    invalid_properties.push('invalid value for "current_started_sandboxes", current_started_sandboxes cannot be nil.')
  end

  if @cpu.nil?
    invalid_properties.push('invalid value for "cpu", cpu cannot be nil.')
  end

  if @memory_gi_b.nil?
    invalid_properties.push('invalid value for "memory_gi_b", memory_gi_b cannot be nil.')
  end

  if @disk_gi_b.nil?
    invalid_properties.push('invalid value for "disk_gi_b", disk_gi_b cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 466

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 271

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @current_cpu_load_average.nil?
  return false if @current_cpu_usage_percentage.nil?
  return false if @current_memory_usage_percentage.nil?
  return false if @current_disk_usage_percentage.nil?
  return false if @current_allocated_cpu.nil?
  return false if @current_allocated_memory_gi_b.nil?
  return false if @current_allocated_disk_gi_b.nil?
  return false if @current_snapshot_count.nil?
  return false if @current_started_sandboxes.nil?
  return false if @cpu.nil?
  return false if @memory_gi_b.nil?
  return false if @disk_gi_b.nil?
  true
end