Class: DaytonaApiClient::Sandbox

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/sandbox.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Sandbox

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/daytona_api_client/models/sandbox.rb', line 285

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::Sandbox` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::Sandbox`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  else
    self.organization_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'snapshot')
    self.snapshot = attributes[:'snapshot']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  else
    self.user = nil
  end

  if attributes.key?(:'env')
    if (value = attributes[:'env']).is_a?(Hash)
      self.env = value
    end
  else
    self.env = nil
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Hash)
      self.labels = value
    end
  else
    self.labels = nil
  end

  if attributes.key?(:'public')
    self.public = attributes[:'public']
  else
    self.public = nil
  end

  if attributes.key?(:'network_block_all')
    self.network_block_all = attributes[:'network_block_all']
  else
    self.network_block_all = nil
  end

  if attributes.key?(:'network_allow_list')
    self.network_allow_list = attributes[:'network_allow_list']
  end

  if attributes.key?(:'domain_allow_list')
    self.domain_allow_list = attributes[:'domain_allow_list']
  end

  if attributes.key?(:'outbound_proxy_url')
    self.outbound_proxy_url = attributes[:'outbound_proxy_url']
  end

  if attributes.key?(:'otel_endpoint_override')
    self.otel_endpoint_override = attributes[:'otel_endpoint_override']
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end

  if attributes.key?(:'cpu')
    self.cpu = attributes[:'cpu']
  else
    self.cpu = nil
  end

  if attributes.key?(:'gpu')
    self.gpu = attributes[:'gpu']
  else
    self.gpu = nil
  end

  if attributes.key?(:'spot')
    self.spot = attributes[:'spot']
  else
    self.spot = false
  end

  if attributes.key?(:'spot_evicted_at')
    self.spot_evicted_at = attributes[:'spot_evicted_at']
  end

  if attributes.key?(:'gpu_type')
    self.gpu_type = attributes[:'gpu_type']
  end

  if attributes.key?(:'memory')
    self.memory = attributes[:'memory']
  else
    self.memory = nil
  end

  if attributes.key?(:'disk')
    self.disk = attributes[:'disk']
  else
    self.disk = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'desired_state')
    self.desired_state = attributes[:'desired_state']
  end

  if attributes.key?(:'error_reason')
    self.error_reason = attributes[:'error_reason']
  end

  if attributes.key?(:'recoverable')
    self.recoverable = attributes[:'recoverable']
  end

  if attributes.key?(:'warm_pool_id')
    self.warm_pool_id = attributes[:'warm_pool_id']
  end

  if attributes.key?(:'backup_state')
    self.backup_state = attributes[:'backup_state']
  end

  if attributes.key?(:'backup_created_at')
    self.backup_created_at = attributes[:'backup_created_at']
  end

  if attributes.key?(:'auto_stop_interval')
    self.auto_stop_interval = attributes[:'auto_stop_interval']
  end

  if attributes.key?(:'auto_pause_interval')
    self.auto_pause_interval = attributes[:'auto_pause_interval']
  end

  if attributes.key?(:'auto_archive_interval')
    self.auto_archive_interval = attributes[:'auto_archive_interval']
  end

  if attributes.key?(:'auto_delete_interval')
    self.auto_delete_interval = attributes[:'auto_delete_interval']
  end

  if attributes.key?(:'auto_destroy_at')
    self.auto_destroy_at = attributes[:'auto_destroy_at']
  end

  if attributes.key?(:'volumes')
    if (value = attributes[:'volumes']).is_a?(Array)
      self.volumes = value
    end
  end

  if attributes.key?(:'build_info')
    self.build_info = attributes[:'build_info']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'last_activity_at')
    self.last_activity_at = attributes[:'last_activity_at']
  end

  if attributes.key?(:'sandbox_class')
    self.sandbox_class = attributes[:'sandbox_class']
  end

  if attributes.key?(:'daemon_version')
    self.daemon_version = attributes[:'daemon_version']
  end

  if attributes.key?(:'runner_id')
    self.runner_id = attributes[:'runner_id']
  end

  if attributes.key?(:'linked_sandbox_id')
    self.linked_sandbox_id = attributes[:'linked_sandbox_id']
  end

  if attributes.key?(:'toolbox_proxy_url')
    self.toolbox_proxy_url = attributes[:'toolbox_proxy_url']
  else
    self.toolbox_proxy_url = nil
  end
end

Instance Attribute Details

#auto_archive_intervalObject

Auto-archive interval in minutes



109
110
111
# File 'lib/daytona_api_client/models/sandbox.rb', line 109

def auto_archive_interval
  @auto_archive_interval
end

#auto_delete_intervalObject

Auto-delete interval in minutes (negative value means disabled, 0 means delete immediately upon stopping)



112
113
114
# File 'lib/daytona_api_client/models/sandbox.rb', line 112

def auto_delete_interval
  @auto_delete_interval
end

#auto_destroy_atObject

When the sandbox will be automatically destroyed, regardless of its state (only set when a TTL is configured)



115
116
117
# File 'lib/daytona_api_client/models/sandbox.rb', line 115

def auto_destroy_at
  @auto_destroy_at
end

#auto_pause_intervalObject

Auto-pause interval in minutes (0 means disabled)



106
107
108
# File 'lib/daytona_api_client/models/sandbox.rb', line 106

def auto_pause_interval
  @auto_pause_interval
end

#auto_stop_intervalObject

Auto-stop interval in minutes (0 means disabled)



103
104
105
# File 'lib/daytona_api_client/models/sandbox.rb', line 103

def auto_stop_interval
  @auto_stop_interval
end

#backup_created_atObject

The creation timestamp of the last backup



100
101
102
# File 'lib/daytona_api_client/models/sandbox.rb', line 100

def backup_created_at
  @backup_created_at
end

#backup_stateObject

The state of the backup



97
98
99
# File 'lib/daytona_api_client/models/sandbox.rb', line 97

def backup_state
  @backup_state
end

#build_infoObject

Build information for the sandbox



121
122
123
# File 'lib/daytona_api_client/models/sandbox.rb', line 121

def build_info
  @build_info
end

#cpuObject

The CPU quota for the sandbox



61
62
63
# File 'lib/daytona_api_client/models/sandbox.rb', line 61

def cpu
  @cpu
end

#created_atObject

The creation timestamp of the sandbox



124
125
126
# File 'lib/daytona_api_client/models/sandbox.rb', line 124

def created_at
  @created_at
end

#daemon_versionObject

The version of the daemon running in the sandbox



136
137
138
# File 'lib/daytona_api_client/models/sandbox.rb', line 136

def daemon_version
  @daemon_version
end

#desired_stateObject

The desired state of the sandbox



85
86
87
# File 'lib/daytona_api_client/models/sandbox.rb', line 85

def desired_state
  @desired_state
end

#diskObject

The disk quota for the sandbox



79
80
81
# File 'lib/daytona_api_client/models/sandbox.rb', line 79

def disk
  @disk
end

#domain_allow_listObject

Comma-separated list of allowed domains for the sandbox



49
50
51
# File 'lib/daytona_api_client/models/sandbox.rb', line 49

def domain_allow_list
  @domain_allow_list
end

#envObject

Environment variables for the sandbox



34
35
36
# File 'lib/daytona_api_client/models/sandbox.rb', line 34

def env
  @env
end

#error_reasonObject

The error reason of the sandbox



88
89
90
# File 'lib/daytona_api_client/models/sandbox.rb', line 88

def error_reason
  @error_reason
end

#gpuObject

The GPU quota for the sandbox



64
65
66
# File 'lib/daytona_api_client/models/sandbox.rb', line 64

def gpu
  @gpu
end

#gpu_typeObject

The GPU type assigned to the sandbox



73
74
75
# File 'lib/daytona_api_client/models/sandbox.rb', line 73

def gpu_type
  @gpu_type
end

#idObject

The ID of the sandbox



19
20
21
# File 'lib/daytona_api_client/models/sandbox.rb', line 19

def id
  @id
end

#labelsObject

Labels for the sandbox



37
38
39
# File 'lib/daytona_api_client/models/sandbox.rb', line 37

def labels
  @labels
end

#last_activity_atObject

The last activity timestamp of the sandbox



130
131
132
# File 'lib/daytona_api_client/models/sandbox.rb', line 130

def last_activity_at
  @last_activity_at
end

#linked_sandbox_idObject

ID of the sandbox this sandbox is linked to. When set, the sandbox is co-located on the same runner as the linked sandbox.



142
143
144
# File 'lib/daytona_api_client/models/sandbox.rb', line 142

def linked_sandbox_id
  @linked_sandbox_id
end

#memoryObject

The memory quota for the sandbox



76
77
78
# File 'lib/daytona_api_client/models/sandbox.rb', line 76

def memory
  @memory
end

#nameObject

The name of the sandbox



25
26
27
# File 'lib/daytona_api_client/models/sandbox.rb', line 25

def name
  @name
end

#network_allow_listObject

Comma-separated list of allowed CIDR network addresses for the sandbox



46
47
48
# File 'lib/daytona_api_client/models/sandbox.rb', line 46

def network_allow_list
  @network_allow_list
end

#network_block_allObject

Whether to block all network access for the sandbox



43
44
45
# File 'lib/daytona_api_client/models/sandbox.rb', line 43

def network_block_all
  @network_block_all
end

#organization_idObject

The organization ID of the sandbox



22
23
24
# File 'lib/daytona_api_client/models/sandbox.rb', line 22

def organization_id
  @organization_id
end

#otel_endpoint_overrideObject

OTel collector endpoint override for this sandbox. When set, sandbox OTel data is sent to this endpoint instead of the default collector and is not available in the Daytona analytics API or dashboard. Only returned on single-sandbox reads — never on list responses.



55
56
57
# File 'lib/daytona_api_client/models/sandbox.rb', line 55

def otel_endpoint_override
  @otel_endpoint_override
end

#outbound_proxy_urlObject

Outbound proxy URL the sandbox HTTP(S) traffic is routed through. Applied via the HTTP(S)_PROXY environment variables (convenience routing); network-layer enforcement applies only when the sandbox also has a domainAllowList. Only returned on single-sandbox reads — never on list responses.



52
53
54
# File 'lib/daytona_api_client/models/sandbox.rb', line 52

def outbound_proxy_url
  @outbound_proxy_url
end

#publicObject

Whether the sandbox http preview is public



40
41
42
# File 'lib/daytona_api_client/models/sandbox.rb', line 40

def public
  @public
end

#recoverableObject

Whether the sandbox error is recoverable.



91
92
93
# File 'lib/daytona_api_client/models/sandbox.rb', line 91

def recoverable
  @recoverable
end

#runner_idObject

The runner ID of the sandbox



139
140
141
# File 'lib/daytona_api_client/models/sandbox.rb', line 139

def runner_id
  @runner_id
end

#sandbox_classObject

The class of the sandbox



133
134
135
# File 'lib/daytona_api_client/models/sandbox.rb', line 133

def sandbox_class
  @sandbox_class
end

#snapshotObject

The snapshot used for the sandbox



28
29
30
# File 'lib/daytona_api_client/models/sandbox.rb', line 28

def snapshot
  @snapshot
end

#spotObject

Whether this is a spot GPU sandbox. Spot sandboxes may be instantly terminated to free capacity for on-demand GPU sandboxes. Absent on APIs that predate this field; treat as false.



67
68
69
# File 'lib/daytona_api_client/models/sandbox.rb', line 67

def spot
  @spot
end

#spot_evicted_atObject

When this sandbox was destroyed by spot preemption. Set only for spot-evicted sandboxes, which stay retrievable by ID for 24 hours after eviction.



70
71
72
# File 'lib/daytona_api_client/models/sandbox.rb', line 70

def spot_evicted_at
  @spot_evicted_at
end

#stateObject

The state of the sandbox



82
83
84
# File 'lib/daytona_api_client/models/sandbox.rb', line 82

def state
  @state
end

#targetObject

The target environment for the sandbox



58
59
60
# File 'lib/daytona_api_client/models/sandbox.rb', line 58

def target
  @target
end

#toolbox_proxy_urlObject

The toolbox proxy URL for the sandbox



145
146
147
# File 'lib/daytona_api_client/models/sandbox.rb', line 145

def toolbox_proxy_url
  @toolbox_proxy_url
end

#updated_atObject

The last update timestamp of the sandbox



127
128
129
# File 'lib/daytona_api_client/models/sandbox.rb', line 127

def updated_at
  @updated_at
end

#userObject

The user associated with the project



31
32
33
# File 'lib/daytona_api_client/models/sandbox.rb', line 31

def user
  @user
end

#volumesObject

Array of volumes attached to the sandbox



118
119
120
# File 'lib/daytona_api_client/models/sandbox.rb', line 118

def volumes
  @volumes
end

#warm_pool_idObject

Id of the warm pool this sandbox waits in; set only while it is an unclaimed member.



94
95
96
# File 'lib/daytona_api_client/models/sandbox.rb', line 94

def warm_pool_id
  @warm_pool_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



219
220
221
# File 'lib/daytona_api_client/models/sandbox.rb', line 219

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



224
225
226
# File 'lib/daytona_api_client/models/sandbox.rb', line 224

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/daytona_api_client/models/sandbox.rb', line 170

def self.attribute_map
  {
    :'id' => :'id',
    :'organization_id' => :'organizationId',
    :'name' => :'name',
    :'snapshot' => :'snapshot',
    :'user' => :'user',
    :'env' => :'env',
    :'labels' => :'labels',
    :'public' => :'public',
    :'network_block_all' => :'networkBlockAll',
    :'network_allow_list' => :'networkAllowList',
    :'domain_allow_list' => :'domainAllowList',
    :'outbound_proxy_url' => :'outboundProxyUrl',
    :'otel_endpoint_override' => :'otelEndpointOverride',
    :'target' => :'target',
    :'cpu' => :'cpu',
    :'gpu' => :'gpu',
    :'spot' => :'spot',
    :'spot_evicted_at' => :'spotEvictedAt',
    :'gpu_type' => :'gpuType',
    :'memory' => :'memory',
    :'disk' => :'disk',
    :'state' => :'state',
    :'desired_state' => :'desiredState',
    :'error_reason' => :'errorReason',
    :'recoverable' => :'recoverable',
    :'warm_pool_id' => :'warmPoolId',
    :'backup_state' => :'backupState',
    :'backup_created_at' => :'backupCreatedAt',
    :'auto_stop_interval' => :'autoStopInterval',
    :'auto_pause_interval' => :'autoPauseInterval',
    :'auto_archive_interval' => :'autoArchiveInterval',
    :'auto_delete_interval' => :'autoDeleteInterval',
    :'auto_destroy_at' => :'autoDestroyAt',
    :'volumes' => :'volumes',
    :'build_info' => :'buildInfo',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'last_activity_at' => :'lastActivityAt',
    :'sandbox_class' => :'sandboxClass',
    :'daemon_version' => :'daemonVersion',
    :'runner_id' => :'runnerId',
    :'linked_sandbox_id' => :'linkedSandboxId',
    :'toolbox_proxy_url' => :'toolboxProxyUrl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'lib/daytona_api_client/models/sandbox.rb', line 822

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



278
279
280
281
# File 'lib/daytona_api_client/models/sandbox.rb', line 278

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/daytona_api_client/models/sandbox.rb', line 229

def self.openapi_types
  {
    :'id' => :'String',
    :'organization_id' => :'String',
    :'name' => :'String',
    :'snapshot' => :'String',
    :'user' => :'String',
    :'env' => :'Hash<String, String>',
    :'labels' => :'Hash<String, String>',
    :'public' => :'Boolean',
    :'network_block_all' => :'Boolean',
    :'network_allow_list' => :'String',
    :'domain_allow_list' => :'String',
    :'outbound_proxy_url' => :'String',
    :'otel_endpoint_override' => :'String',
    :'target' => :'String',
    :'cpu' => :'Float',
    :'gpu' => :'Float',
    :'spot' => :'Boolean',
    :'spot_evicted_at' => :'String',
    :'gpu_type' => :'GpuType',
    :'memory' => :'Float',
    :'disk' => :'Float',
    :'state' => :'SandboxState',
    :'desired_state' => :'SandboxDesiredState',
    :'error_reason' => :'String',
    :'recoverable' => :'Boolean',
    :'warm_pool_id' => :'String',
    :'backup_state' => :'String',
    :'backup_created_at' => :'String',
    :'auto_stop_interval' => :'Float',
    :'auto_pause_interval' => :'Float',
    :'auto_archive_interval' => :'Float',
    :'auto_delete_interval' => :'Float',
    :'auto_destroy_at' => :'String',
    :'volumes' => :'Array<SandboxVolume>',
    :'build_info' => :'BuildInfo',
    :'created_at' => :'String',
    :'updated_at' => :'String',
    :'last_activity_at' => :'String',
    :'sandbox_class' => :'String',
    :'daemon_version' => :'String',
    :'runner_id' => :'String',
    :'linked_sandbox_id' => :'String',
    :'toolbox_proxy_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
# File 'lib/daytona_api_client/models/sandbox.rb', line 759

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      organization_id == o.organization_id &&
      name == o.name &&
      snapshot == o.snapshot &&
      user == o.user &&
      env == o.env &&
      labels == o.labels &&
      public == o.public &&
      network_block_all == o.network_block_all &&
      network_allow_list == o.network_allow_list &&
      domain_allow_list == o.domain_allow_list &&
      outbound_proxy_url == o.outbound_proxy_url &&
      otel_endpoint_override == o.otel_endpoint_override &&
      target == o.target &&
      cpu == o.cpu &&
      gpu == o.gpu &&
      spot == o.spot &&
      spot_evicted_at == o.spot_evicted_at &&
      gpu_type == o.gpu_type &&
      memory == o.memory &&
      disk == o.disk &&
      state == o.state &&
      desired_state == o.desired_state &&
      error_reason == o.error_reason &&
      recoverable == o.recoverable &&
      warm_pool_id == o.warm_pool_id &&
      backup_state == o.backup_state &&
      backup_created_at == o.backup_created_at &&
      auto_stop_interval == o.auto_stop_interval &&
      auto_pause_interval == o.auto_pause_interval &&
      auto_archive_interval == o.auto_archive_interval &&
      auto_delete_interval == o.auto_delete_interval &&
      auto_destroy_at == o.auto_destroy_at &&
      volumes == o.volumes &&
      build_info == o.build_info &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      last_activity_at == o.last_activity_at &&
      sandbox_class == o.sandbox_class &&
      daemon_version == o.daemon_version &&
      runner_id == o.runner_id &&
      linked_sandbox_id == o.linked_sandbox_id &&
      toolbox_proxy_url == o.toolbox_proxy_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


809
810
811
# File 'lib/daytona_api_client/models/sandbox.rb', line 809

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



815
816
817
# File 'lib/daytona_api_client/models/sandbox.rb', line 815

def hash
  [id, organization_id, name, snapshot, user, env, labels, public, network_block_all, network_allow_list, domain_allow_list, outbound_proxy_url, otel_endpoint_override, target, cpu, gpu, spot, spot_evicted_at, gpu_type, memory, disk, state, desired_state, error_reason, recoverable, warm_pool_id, backup_state, backup_created_at, auto_stop_interval, auto_pause_interval, auto_archive_interval, auto_delete_interval, auto_destroy_at, volumes, build_info, created_at, updated_at, last_activity_at, sandbox_class, daemon_version, runner_id, linked_sandbox_id, toolbox_proxy_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
# File 'lib/daytona_api_client/models/sandbox.rb', line 510

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @organization_id.nil?
    invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @user.nil?
    invalid_properties.push('invalid value for "user", user cannot be nil.')
  end

  if @env.nil?
    invalid_properties.push('invalid value for "env", env cannot be nil.')
  end

  if @labels.nil?
    invalid_properties.push('invalid value for "labels", labels cannot be nil.')
  end

  if @public.nil?
    invalid_properties.push('invalid value for "public", public cannot be nil.')
  end

  if @network_block_all.nil?
    invalid_properties.push('invalid value for "network_block_all", network_block_all cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  if @cpu.nil?
    invalid_properties.push('invalid value for "cpu", cpu cannot be nil.')
  end

  if @gpu.nil?
    invalid_properties.push('invalid value for "gpu", gpu cannot be nil.')
  end

  if @memory.nil?
    invalid_properties.push('invalid value for "memory", memory cannot be nil.')
  end

  if @disk.nil?
    invalid_properties.push('invalid value for "disk", disk cannot be nil.')
  end

  if @toolbox_proxy_url.nil?
    invalid_properties.push('invalid value for "toolbox_proxy_url", toolbox_proxy_url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



844
845
846
847
848
849
850
851
852
853
854
855
856
# File 'lib/daytona_api_client/models/sandbox.rb', line 844

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
# File 'lib/daytona_api_client/models/sandbox.rb', line 574

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @organization_id.nil?
  return false if @name.nil?
  return false if @user.nil?
  return false if @env.nil?
  return false if @labels.nil?
  return false if @public.nil?
  return false if @network_block_all.nil?
  return false if @target.nil?
  return false if @cpu.nil?
  return false if @gpu.nil?
  return false if @memory.nil?
  return false if @disk.nil?
  backup_state_validator = EnumAttributeValidator.new('String', ["None", "Pending", "InProgress", "Completed", "Error", "unknown_default_open_api"])
  return false unless backup_state_validator.valid?(@backup_state)
  sandbox_class_validator = EnumAttributeValidator.new('String', ["linux-vm", "container", "android", "windows", "unknown_default_open_api"])
  return false unless sandbox_class_validator.valid?(@sandbox_class)
  return false if @toolbox_proxy_url.nil?
  true
end