Class: DaytonaApiClient::SandboxStateUpdatedWebhook

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/daytona_api_client/models/sandbox_state_updated_webhook.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SandboxStateUpdatedWebhook

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::SandboxStateUpdatedWebhook` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::SandboxStateUpdatedWebhook`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  else
    self.event = nil
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  else
    self.timestamp = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  else
    self.organization_id = nil
  end

  if attributes.key?(:'old_state')
    self.old_state = attributes[:'old_state']
  else
    self.old_state = nil
  end

  if attributes.key?(:'new_state')
    self.new_state = attributes[:'new_state']
  else
    self.new_state = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#event ⇒ Object

Event type identifier



19
20
21
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 19

def event
  @event
end

#id ⇒ Object

Sandbox ID



25
26
27
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 25

def id
  @id
end

#new_state ⇒ Object

New state



34
35
36
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 34

def new_state
  @new_state
end

#old_state ⇒ Object

Previous state



31
32
33
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 31

def old_state
  @old_state
end

#organization_id ⇒ Object

Organization ID



28
29
30
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 28

def organization_id
  @organization_id
end

#timestamp ⇒ Object

Timestamp when the event occurred



22
23
24
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 22

def timestamp
  @timestamp
end

#updated_at ⇒ Object

When the sandbox was last updated



37
38
39
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 37

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



75
76
77
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 62

def self.attribute_map
  {
    :'event' => :'event',
    :'timestamp' => :'timestamp',
    :'id' => :'id',
    :'organization_id' => :'organizationId',
    :'old_state' => :'oldState',
    :'new_state' => :'newState',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 311

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



98
99
100
101
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 85

def self.openapi_types
  {
    :'event' => :'WebhookEvent',
    :'timestamp' => :'Time',
    :'id' => :'String',
    :'organization_id' => :'String',
    :'old_state' => :'SandboxState',
    :'new_state' => :'SandboxState',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



284
285
286
287
288
289
290
291
292
293
294
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 284

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      event == o.event &&
      timestamp == o.timestamp &&
      id == o.id &&
      organization_id == o.organization_id &&
      old_state == o.old_state &&
      new_state == o.new_state &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 298

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



304
305
306
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 304

def hash
  [event, timestamp, id, organization_id, old_state, new_state, updated_at].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 164

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @event.nil?
    invalid_properties.push('invalid value for "event", event cannot be nil.')
  end

  if @timestamp.nil?
    invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @organization_id.nil?
    invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.')
  end

  if @old_state.nil?
    invalid_properties.push('invalid value for "old_state", old_state cannot be nil.')
  end

  if @new_state.nil?
    invalid_properties.push('invalid value for "new_state", new_state cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



200
201
202
203
204
205
206
207
208
209
210
# File 'lib/daytona_api_client/models/sandbox_state_updated_webhook.rb', line 200

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @event.nil?
  return false if @timestamp.nil?
  return false if @id.nil?
  return false if @organization_id.nil?
  return false if @old_state.nil?
  return false if @new_state.nil?
  return false if @updated_at.nil?
  true
end