Class: DaytonaApiClient::Secret
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::Secret
- Defined in:
- lib/daytona_api_client/models/secret.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Creation timestamp.
-
#description ⇒ Object
Optional description of the secret.
-
#hosts ⇒ Object
Allowed hosts this secret may be sent to.
-
#id ⇒ Object
Secret ID.
-
#name ⇒ Object
Secret name.
-
#placeholder ⇒ Object
Opaque placeholder token injected as env var value in sandboxes.
-
#updated_at ⇒ Object
Last update timestamp.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Secret
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Secret
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/daytona_api_client/models/secret.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::Secret` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::Secret`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'placeholder') self.placeholder = attributes[:'placeholder'] else self.placeholder = nil end if attributes.key?(:'hosts') if (value = attributes[:'hosts']).is_a?(Array) self.hosts = value end else self.hosts = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Creation timestamp
28 29 30 |
# File 'lib/daytona_api_client/models/secret.rb', line 28 def created_at @created_at end |
#description ⇒ Object
Optional description of the secret
25 26 27 |
# File 'lib/daytona_api_client/models/secret.rb', line 25 def description @description end |
#hosts ⇒ Object
Allowed hosts this secret may be sent to
34 35 36 |
# File 'lib/daytona_api_client/models/secret.rb', line 34 def hosts @hosts end |
#id ⇒ Object
Secret ID
19 20 21 |
# File 'lib/daytona_api_client/models/secret.rb', line 19 def id @id end |
#name ⇒ Object
Secret name
22 23 24 |
# File 'lib/daytona_api_client/models/secret.rb', line 22 def name @name end |
#placeholder ⇒ Object
Opaque placeholder token injected as env var value in sandboxes
31 32 33 |
# File 'lib/daytona_api_client/models/secret.rb', line 31 def placeholder @placeholder end |
#updated_at ⇒ Object
Last update timestamp
37 38 39 |
# File 'lib/daytona_api_client/models/secret.rb', line 37 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/daytona_api_client/models/secret.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/daytona_api_client/models/secret.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/daytona_api_client/models/secret.rb', line 40 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'created_at' => :'createdAt', :'placeholder' => :'placeholder', :'hosts' => :'hosts', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/daytona_api_client/models/secret.rb', line 274 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/daytona_api_client/models/secret.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/daytona_api_client/models/secret.rb', line 63 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'created_at' => :'Time', :'placeholder' => :'String', :'hosts' => :'Array<String>', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/daytona_api_client/models/secret.rb', line 247 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && created_at == o.created_at && placeholder == o.placeholder && hosts == o.hosts && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
261 262 263 |
# File 'lib/daytona_api_client/models/secret.rb', line 261 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
267 268 269 |
# File 'lib/daytona_api_client/models/secret.rb', line 267 def hash [id, name, description, created_at, placeholder, hosts, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/daytona_api_client/models/secret.rb', line 142 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @placeholder.nil? invalid_properties.push('invalid value for "placeholder", placeholder cannot be nil.') end if @hosts.nil? invalid_properties.push('invalid value for "hosts", hosts cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/daytona_api_client/models/secret.rb', line 296 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/daytona_api_client/models/secret.rb', line 174 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @created_at.nil? return false if @placeholder.nil? return false if @hosts.nil? return false if @updated_at.nil? true end |