Class: DaytonaApiClient::SnapshotStateUpdatedWebhook
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::SnapshotStateUpdatedWebhook
- Defined in:
- lib/daytona_api_client/models/snapshot_state_updated_webhook.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#event ⇒ Object
Event type identifier.
-
#id ⇒ Object
Snapshot ID.
-
#name ⇒ Object
Snapshot name.
-
#new_state ⇒ Object
New state.
-
#old_state ⇒ Object
Previous state.
-
#organization_id ⇒ Object
Organization ID.
-
#timestamp ⇒ Object
Timestamp when the event occurred.
-
#updated_at ⇒ Object
When the snapshot was last updated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SnapshotStateUpdatedWebhook
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SnapshotStateUpdatedWebhook
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::SnapshotStateUpdatedWebhook` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::SnapshotStateUpdatedWebhook`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'event') self.event = attributes[:'event'] else self.event = nil end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] else self. = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] else self.organization_id = nil end if attributes.key?(:'old_state') self.old_state = attributes[:'old_state'] else self.old_state = nil end if attributes.key?(:'new_state') self.new_state = attributes[:'new_state'] else self.new_state = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#event ⇒ Object
Event type identifier
19 20 21 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 19 def event @event end |
#id ⇒ Object
Snapshot ID
25 26 27 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 25 def id @id end |
#name ⇒ Object
Snapshot name
28 29 30 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 28 def name @name end |
#new_state ⇒ Object
New state
37 38 39 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 37 def new_state @new_state end |
#old_state ⇒ Object
Previous state
34 35 36 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 34 def old_state @old_state end |
#organization_id ⇒ Object
Organization ID
31 32 33 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 31 def organization_id @organization_id end |
#timestamp ⇒ Object
Timestamp when the event occurred
22 23 24 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 22 def @timestamp end |
#updated_at ⇒ Object
When the snapshot was last updated
40 41 42 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 40 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 65 def self.attribute_map { :'event' => :'event', :'timestamp' => :'timestamp', :'id' => :'id', :'name' => :'name', :'organization_id' => :'organizationId', :'old_state' => :'oldState', :'new_state' => :'newState', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 338 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 89 def self.openapi_types { :'event' => :'WebhookEvent', :'timestamp' => :'Time', :'id' => :'String', :'name' => :'String', :'organization_id' => :'String', :'old_state' => :'SnapshotState', :'new_state' => :'SnapshotState', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 310 def ==(o) return true if self.equal?(o) self.class == o.class && event == o.event && == o. && id == o.id && name == o.name && organization_id == o.organization_id && old_state == o.old_state && new_state == o.new_state && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
325 326 327 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 325 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
331 332 333 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 331 def hash [event, , id, name, organization_id, old_state, new_state, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 175 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @event.nil? invalid_properties.push('invalid value for "event", event cannot be nil.') end if @timestamp.nil? invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @organization_id.nil? invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.') end if @old_state.nil? invalid_properties.push('invalid value for "old_state", old_state cannot be nil.') end if @new_state.nil? invalid_properties.push('invalid value for "new_state", new_state cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 360 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/daytona_api_client/models/snapshot_state_updated_webhook.rb', line 215 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @event.nil? return false if @timestamp.nil? return false if @id.nil? return false if @name.nil? return false if @organization_id.nil? return false if @old_state.nil? return false if @new_state.nil? return false if @updated_at.nil? true end |