Class: DaytonaApiClient::SshAccessDto

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/ssh_access_dto.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SshAccessDto

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::SshAccessDto` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::SshAccessDto`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'sandbox_id')
    self.sandbox_id = attributes[:'sandbox_id']
  else
    self.sandbox_id = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  else
    self.token = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'ssh_command')
    self.ssh_command = attributes[:'ssh_command']
  else
    self.ssh_command = nil
  end
end

Instance Attribute Details

#created_atObject

When the SSH access was created



31
32
33
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 31

def created_at
  @created_at
end

#expires_atObject

When the SSH access expires



28
29
30
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 28

def expires_at
  @expires_at
end

#idObject

Unique identifier for the SSH access



19
20
21
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 19

def id
  @id
end

#sandbox_idObject

ID of the sandbox this SSH access is for



22
23
24
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 22

def sandbox_id
  @sandbox_id
end

#ssh_commandObject

SSH command to connect to the sandbox



37
38
39
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 37

def ssh_command
  @ssh_command
end

#tokenObject

SSH access token



25
26
27
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 25

def token
  @token
end

#updated_atObject

When the SSH access was last updated



34
35
36
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 34

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 40

def self.attribute_map
  {
    :'id' => :'id',
    :'sandbox_id' => :'sandboxId',
    :'token' => :'token',
    :'expires_at' => :'expiresAt',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'ssh_command' => :'sshCommand'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 289

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 63

def self.openapi_types
  {
    :'id' => :'String',
    :'sandbox_id' => :'String',
    :'token' => :'String',
    :'expires_at' => :'Time',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'ssh_command' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



262
263
264
265
266
267
268
269
270
271
272
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 262

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      sandbox_id == o.sandbox_id &&
      token == o.token &&
      expires_at == o.expires_at &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      ssh_command == o.ssh_command
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


276
277
278
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 276

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



282
283
284
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 282

def hash
  [id, sandbox_id, token, expires_at, created_at, updated_at, ssh_command].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @sandbox_id.nil?
    invalid_properties.push('invalid value for "sandbox_id", sandbox_id cannot be nil.')
  end

  if @token.nil?
    invalid_properties.push('invalid value for "token", token cannot be nil.')
  end

  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @ssh_command.nil?
    invalid_properties.push('invalid value for "ssh_command", ssh_command cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 311

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
181
182
183
184
185
186
187
188
# File 'lib/daytona_api_client/models/ssh_access_dto.rb', line 178

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @sandbox_id.nil?
  return false if @token.nil?
  return false if @expires_at.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if @ssh_command.nil?
  true
end