Class: DaytonaApiClient::StringFilter

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/string_filter.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ StringFilter

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/daytona_api_client/models/string_filter.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::StringFilter` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::StringFilter`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'eq')
    self.eq = attributes[:'eq']
  end

  if attributes.key?(:'_not')
    self._not = attributes[:'_not']
  end

  if attributes.key?(:'_in')
    if (value = attributes[:'_in']).is_a?(Array)
      self._in = value
    end
  end

  if attributes.key?(:'not_in')
    if (value = attributes[:'not_in']).is_a?(Array)
      self.not_in = value
    end
  end
end

Instance Attribute Details

#_inObject

Match values present in this list. Accepts comma-separated values or repeated query parameters. Maximum 100 entries.



25
26
27
# File 'lib/daytona_api_client/models/string_filter.rb', line 25

def _in
  @_in
end

#_notObject

Match values not equal to this value.



22
23
24
# File 'lib/daytona_api_client/models/string_filter.rb', line 22

def _not
  @_not
end

#eqObject

Match values equal to this value.



19
20
21
# File 'lib/daytona_api_client/models/string_filter.rb', line 19

def eq
  @eq
end

#not_inObject

Match values not present in this list. Accepts comma-separated values or repeated query parameters. Maximum 100 entries.



28
29
30
# File 'lib/daytona_api_client/models/string_filter.rb', line 28

def not_in
  @not_in
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/daytona_api_client/models/string_filter.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/daytona_api_client/models/string_filter.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/daytona_api_client/models/string_filter.rb', line 31

def self.attribute_map
  {
    :'eq' => :'eq',
    :'_not' => :'not',
    :'_in' => :'in',
    :'not_in' => :'notIn'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/daytona_api_client/models/string_filter.rb', line 144

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/daytona_api_client/models/string_filter.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/daytona_api_client/models/string_filter.rb', line 51

def self.openapi_types
  {
    :'eq' => :'String',
    :'_not' => :'String',
    :'_in' => :'Array<String>',
    :'not_in' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



120
121
122
123
124
125
126
127
# File 'lib/daytona_api_client/models/string_filter.rb', line 120

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      eq == o.eq &&
      _not == o._not &&
      _in == o._in &&
      not_in == o.not_in
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


131
132
133
# File 'lib/daytona_api_client/models/string_filter.rb', line 131

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



137
138
139
# File 'lib/daytona_api_client/models/string_filter.rb', line 137

def hash
  [eq, _not, _in, not_in].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
# File 'lib/daytona_api_client/models/string_filter.rb', line 105

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/daytona_api_client/models/string_filter.rb', line 166

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



113
114
115
116
# File 'lib/daytona_api_client/models/string_filter.rb', line 113

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end