Class: DaytonaApiClient::TraceSpan
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::TraceSpan
- Defined in:
- lib/daytona_api_client/models/trace_span.rb
Instance Attribute Summary collapse
-
#duration_ns ⇒ Object
Span duration in nanoseconds.
-
#parent_span_id ⇒ Object
Parent span identifier.
-
#span_attributes ⇒ Object
Span attributes.
-
#span_id ⇒ Object
Span identifier.
-
#span_name ⇒ Object
Span name.
-
#status_code ⇒ Object
Status code of the span.
-
#status_message ⇒ Object
Status message.
-
#timestamp ⇒ Object
Span start timestamp.
-
#trace_id ⇒ Object
Trace identifier.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TraceSpan
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TraceSpan
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::TraceSpan` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::TraceSpan`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'trace_id') self.trace_id = attributes[:'trace_id'] else self.trace_id = nil end if attributes.key?(:'span_id') self.span_id = attributes[:'span_id'] else self.span_id = nil end if attributes.key?(:'parent_span_id') self.parent_span_id = attributes[:'parent_span_id'] end if attributes.key?(:'span_name') self.span_name = attributes[:'span_name'] else self.span_name = nil end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] else self. = nil end if attributes.key?(:'duration_ns') self.duration_ns = attributes[:'duration_ns'] else self.duration_ns = nil end if attributes.key?(:'span_attributes') if (value = attributes[:'span_attributes']).is_a?(Hash) self.span_attributes = value end else self.span_attributes = nil end if attributes.key?(:'status_code') self.status_code = attributes[:'status_code'] end if attributes.key?(:'status_message') self. = attributes[:'status_message'] end end |
Instance Attribute Details
#duration_ns ⇒ Object
Span duration in nanoseconds
34 35 36 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 34 def duration_ns @duration_ns end |
#parent_span_id ⇒ Object
Parent span identifier
25 26 27 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 25 def parent_span_id @parent_span_id end |
#span_attributes ⇒ Object
Span attributes
37 38 39 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 37 def span_attributes @span_attributes end |
#span_id ⇒ Object
Span identifier
22 23 24 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 22 def span_id @span_id end |
#span_name ⇒ Object
Span name
28 29 30 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 28 def span_name @span_name end |
#status_code ⇒ Object
Status code of the span
40 41 42 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 40 def status_code @status_code end |
#status_message ⇒ Object
Status message
43 44 45 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 43 def @status_message end |
#timestamp ⇒ Object
Span start timestamp
31 32 33 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 31 def @timestamp end |
#trace_id ⇒ Object
Trace identifier
19 20 21 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 19 def trace_id @trace_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 46 def self.attribute_map { :'trace_id' => :'traceId', :'span_id' => :'spanId', :'parent_span_id' => :'parentSpanId', :'span_name' => :'spanName', :'timestamp' => :'timestamp', :'duration_ns' => :'durationNs', :'span_attributes' => :'spanAttributes', :'status_code' => :'statusCode', :'status_message' => :'statusMessage' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 294 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 71 def self.openapi_types { :'trace_id' => :'String', :'span_id' => :'String', :'parent_span_id' => :'String', :'span_name' => :'String', :'timestamp' => :'String', :'duration_ns' => :'Float', :'span_attributes' => :'Hash<String, String>', :'status_code' => :'String', :'status_message' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && trace_id == o.trace_id && span_id == o.span_id && parent_span_id == o.parent_span_id && span_name == o.span_name && == o. && duration_ns == o.duration_ns && span_attributes == o.span_attributes && status_code == o.status_code && == o. end |
#eql?(o) ⇒ Boolean
281 282 283 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 281 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
287 288 289 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 287 def hash [trace_id, span_id, parent_span_id, span_name, , duration_ns, span_attributes, status_code, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 160 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @trace_id.nil? invalid_properties.push('invalid value for "trace_id", trace_id cannot be nil.') end if @span_id.nil? invalid_properties.push('invalid value for "span_id", span_id cannot be nil.') end if @span_name.nil? invalid_properties.push('invalid value for "span_name", span_name cannot be nil.') end if @timestamp.nil? invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.') end if @duration_ns.nil? invalid_properties.push('invalid value for "duration_ns", duration_ns cannot be nil.') end if @span_attributes.nil? invalid_properties.push('invalid value for "span_attributes", span_attributes cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 316 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 196 197 198 199 200 201 |
# File 'lib/daytona_api_client/models/trace_span.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @trace_id.nil? return false if @span_id.nil? return false if @span_name.nil? return false if @timestamp.nil? return false if @duration_ns.nil? return false if @span_attributes.nil? true end |