Class: DaytonaApiClient::UpdateIdentityProvider

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/daytona_api_client/models/update_identity_provider.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateIdentityProvider

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::UpdateIdentityProvider` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::UpdateIdentityProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'oidc_config')
    self.oidc_config = attributes[:'oidc_config']
  end

  if attributes.key?(:'email_domains')
    if (value = attributes[:'email_domains']).is_a?(Array)
      self.email_domains = value
    end
  end

  if attributes.key?(:'allow_any_domain')
    self.allow_any_domain = attributes[:'allow_any_domain']
  end

  if attributes.key?(:'trust_email_verified')
    self.trust_email_verified = attributes[:'trust_email_verified']
  end

  if attributes.key?(:'default_assigned_role_ids')
    if (value = attributes[:'default_assigned_role_ids']).is_a?(Array)
      self.default_assigned_role_ids = value
    end
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end
end

Instance Attribute Details

#allow_any_domainObject

When true, the IdP accepts any email domain returned by the external provider. Disables the post-callback domain check and allows emailDomains to be empty. Only enable for trusted IdPs that strictly control which users can authenticate.



28
29
30
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 28

def allow_any_domain
  @allow_any_domain
end

#default_assigned_role_idsObject

Organization role IDs assigned to users who join the organization via SSO through this identity provider. Roles must be global or belong to this organization. Empty grants the lowest access: membership with no resource permissions.



34
35
36
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 34

def default_assigned_role_ids
  @default_assigned_role_ids
end

#email_domainsObject

Email domains used for IdP discovery on the login form and to validate the user identity returned by the IdP. If provided and allowAnyDomain is not being set to true, must contain at least one domain. To clear domains in the same request, set allowAnyDomain: true and emailDomains: [].



25
26
27
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 25

def email_domains
  @email_domains
end

#enabledObject

Whether the identity provider is enabled



37
38
39
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 37

def enabled
  @enabled
end

#nameObject

Display name for the identity provider



19
20
21
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 19

def name
  @name
end

#oidc_configObject

OIDC configuration



22
23
24
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 22

def oidc_config
  @oidc_config
end

#trust_email_verifiedObject

When true, skip the email_verified claim check on SSO logins through this identity provider. Only intended for providers that never emit the claim (e.g. Microsoft Entra ID). Risky: only enable if the IdP strictly controls its users' email addresses.



31
32
33
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 31

def trust_email_verified
  @trust_email_verified
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 40

def self.attribute_map
  {
    :'name' => :'name',
    :'oidc_config' => :'oidcConfig',
    :'email_domains' => :'emailDomains',
    :'allow_any_domain' => :'allowAnyDomain',
    :'trust_email_verified' => :'trustEmailVerified',
    :'default_assigned_role_ids' => :'defaultAssignedRoleIds',
    :'enabled' => :'enabled'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 174

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 63

def self.openapi_types
  {
    :'name' => :'String',
    :'oidc_config' => :'UpdateOidcIdPConfig',
    :'email_domains' => :'Array<String>',
    :'allow_any_domain' => :'Boolean',
    :'trust_email_verified' => :'Boolean',
    :'default_assigned_role_ids' => :'Array<String>',
    :'enabled' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
153
154
155
156
157
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      oidc_config == o.oidc_config &&
      email_domains == o.email_domains &&
      allow_any_domain == o.allow_any_domain &&
      trust_email_verified == o.trust_email_verified &&
      default_assigned_role_ids == o.default_assigned_role_ids &&
      enabled == o.enabled
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


161
162
163
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 161

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



167
168
169
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 167

def hash
  [name, oidc_config, email_domains, allow_any_domain, trust_email_verified, default_assigned_role_ids, enabled].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 196

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
# File 'lib/daytona_api_client/models/update_identity_provider.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end