Class: DaytonaApiClient::UpdateOrganizationQuota

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/daytona_api_client/models/update_organization_quota.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateOrganizationQuota

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 131

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::UpdateOrganizationQuota` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::UpdateOrganizationQuota`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'max_cpu_per_sandbox')
    self.max_cpu_per_sandbox = attributes[:'max_cpu_per_sandbox']
  else
    self.max_cpu_per_sandbox = nil
  end

  if attributes.key?(:'max_memory_per_sandbox')
    self.max_memory_per_sandbox = attributes[:'max_memory_per_sandbox']
  else
    self.max_memory_per_sandbox = nil
  end

  if attributes.key?(:'max_disk_per_sandbox')
    self.max_disk_per_sandbox = attributes[:'max_disk_per_sandbox']
  else
    self.max_disk_per_sandbox = nil
  end

  if attributes.key?(:'snapshot_quota')
    self.snapshot_quota = attributes[:'snapshot_quota']
  else
    self.snapshot_quota = nil
  end

  if attributes.key?(:'max_snapshot_size')
    self.max_snapshot_size = attributes[:'max_snapshot_size']
  else
    self.max_snapshot_size = nil
  end

  if attributes.key?(:'volume_quota')
    self.volume_quota = attributes[:'volume_quota']
  else
    self.volume_quota = nil
  end

  if attributes.key?(:'secret_quota')
    self.secret_quota = attributes[:'secret_quota']
  else
    self.secret_quota = nil
  end

  if attributes.key?(:'max_secrets_per_sandbox')
    self.max_secrets_per_sandbox = attributes[:'max_secrets_per_sandbox']
  else
    self.max_secrets_per_sandbox = nil
  end

  if attributes.key?(:'authenticated_rate_limit')
    self.authenticated_rate_limit = attributes[:'authenticated_rate_limit']
  else
    self.authenticated_rate_limit = nil
  end

  if attributes.key?(:'sandbox_create_rate_limit')
    self.sandbox_create_rate_limit = attributes[:'sandbox_create_rate_limit']
  else
    self.sandbox_create_rate_limit = nil
  end

  if attributes.key?(:'sandbox_lifecycle_rate_limit')
    self.sandbox_lifecycle_rate_limit = attributes[:'sandbox_lifecycle_rate_limit']
  else
    self.sandbox_lifecycle_rate_limit = nil
  end

  if attributes.key?(:'authenticated_rate_limit_ttl_seconds')
    self.authenticated_rate_limit_ttl_seconds = attributes[:'authenticated_rate_limit_ttl_seconds']
  else
    self.authenticated_rate_limit_ttl_seconds = nil
  end

  if attributes.key?(:'sandbox_create_rate_limit_ttl_seconds')
    self.sandbox_create_rate_limit_ttl_seconds = attributes[:'sandbox_create_rate_limit_ttl_seconds']
  else
    self.sandbox_create_rate_limit_ttl_seconds = nil
  end

  if attributes.key?(:'sandbox_lifecycle_rate_limit_ttl_seconds')
    self.sandbox_lifecycle_rate_limit_ttl_seconds = attributes[:'sandbox_lifecycle_rate_limit_ttl_seconds']
  else
    self.sandbox_lifecycle_rate_limit_ttl_seconds = nil
  end

  if attributes.key?(:'snapshot_deactivation_timeout_minutes')
    self.snapshot_deactivation_timeout_minutes = attributes[:'snapshot_deactivation_timeout_minutes']
  else
    self.snapshot_deactivation_timeout_minutes = nil
  end

  if attributes.key?(:'max_concurrent_snapshot_processing')
    self.max_concurrent_snapshot_processing = attributes[:'max_concurrent_snapshot_processing']
  else
    self.max_concurrent_snapshot_processing = nil
  end
end

Instance Attribute Details

#authenticated_rate_limitObject

Returns the value of attribute authenticated_rate_limit.



35
36
37
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 35

def authenticated_rate_limit
  @authenticated_rate_limit
end

#authenticated_rate_limit_ttl_secondsObject

Returns the value of attribute authenticated_rate_limit_ttl_seconds.



41
42
43
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 41

def authenticated_rate_limit_ttl_seconds
  @authenticated_rate_limit_ttl_seconds
end

#max_concurrent_snapshot_processingObject

Maximum number of snapshots an organization can process (building or pulling) concurrently. Excess are queued. <= 0 means unlimited.



51
52
53
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 51

def max_concurrent_snapshot_processing
  @max_concurrent_snapshot_processing
end

#max_cpu_per_sandboxObject

Returns the value of attribute max_cpu_per_sandbox.



18
19
20
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 18

def max_cpu_per_sandbox
  @max_cpu_per_sandbox
end

#max_disk_per_sandboxObject

Returns the value of attribute max_disk_per_sandbox.



22
23
24
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 22

def max_disk_per_sandbox
  @max_disk_per_sandbox
end

#max_memory_per_sandboxObject

Returns the value of attribute max_memory_per_sandbox.



20
21
22
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 20

def max_memory_per_sandbox
  @max_memory_per_sandbox
end

#max_secrets_per_sandboxObject

Maximum number of secrets that can be mounted to a single sandbox



33
34
35
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 33

def max_secrets_per_sandbox
  @max_secrets_per_sandbox
end

#max_snapshot_sizeObject

Returns the value of attribute max_snapshot_size.



26
27
28
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 26

def max_snapshot_size
  @max_snapshot_size
end

#sandbox_create_rate_limitObject

Returns the value of attribute sandbox_create_rate_limit.



37
38
39
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 37

def sandbox_create_rate_limit
  @sandbox_create_rate_limit
end

#sandbox_create_rate_limit_ttl_secondsObject

Returns the value of attribute sandbox_create_rate_limit_ttl_seconds.



43
44
45
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 43

def sandbox_create_rate_limit_ttl_seconds
  @sandbox_create_rate_limit_ttl_seconds
end

#sandbox_lifecycle_rate_limitObject

Returns the value of attribute sandbox_lifecycle_rate_limit.



39
40
41
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 39

def sandbox_lifecycle_rate_limit
  @sandbox_lifecycle_rate_limit
end

#sandbox_lifecycle_rate_limit_ttl_secondsObject

Returns the value of attribute sandbox_lifecycle_rate_limit_ttl_seconds.



45
46
47
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 45

def sandbox_lifecycle_rate_limit_ttl_seconds
  @sandbox_lifecycle_rate_limit_ttl_seconds
end

#secret_quotaObject

Returns the value of attribute secret_quota.



30
31
32
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 30

def secret_quota
  @secret_quota
end

#snapshot_deactivation_timeout_minutesObject

Time in minutes before an unused snapshot is deactivated



48
49
50
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 48

def snapshot_deactivation_timeout_minutes
  @snapshot_deactivation_timeout_minutes
end

#snapshot_quotaObject

Returns the value of attribute snapshot_quota.



24
25
26
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 24

def snapshot_quota
  @snapshot_quota
end

#volume_quotaObject

Returns the value of attribute volume_quota.



28
29
30
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 28

def volume_quota
  @volume_quota
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 54

def self.attribute_map
  {
    :'max_cpu_per_sandbox' => :'maxCpuPerSandbox',
    :'max_memory_per_sandbox' => :'maxMemoryPerSandbox',
    :'max_disk_per_sandbox' => :'maxDiskPerSandbox',
    :'snapshot_quota' => :'snapshotQuota',
    :'max_snapshot_size' => :'maxSnapshotSize',
    :'volume_quota' => :'volumeQuota',
    :'secret_quota' => :'secretQuota',
    :'max_secrets_per_sandbox' => :'maxSecretsPerSandbox',
    :'authenticated_rate_limit' => :'authenticatedRateLimit',
    :'sandbox_create_rate_limit' => :'sandboxCreateRateLimit',
    :'sandbox_lifecycle_rate_limit' => :'sandboxLifecycleRateLimit',
    :'authenticated_rate_limit_ttl_seconds' => :'authenticatedRateLimitTtlSeconds',
    :'sandbox_create_rate_limit_ttl_seconds' => :'sandboxCreateRateLimitTtlSeconds',
    :'sandbox_lifecycle_rate_limit_ttl_seconds' => :'sandboxLifecycleRateLimitTtlSeconds',
    :'snapshot_deactivation_timeout_minutes' => :'snapshotDeactivationTimeoutMinutes',
    :'max_concurrent_snapshot_processing' => :'maxConcurrentSnapshotProcessing'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 295

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 108

def self.openapi_nullable
  Set.new([
    :'max_cpu_per_sandbox',
    :'max_memory_per_sandbox',
    :'max_disk_per_sandbox',
    :'snapshot_quota',
    :'max_snapshot_size',
    :'volume_quota',
    :'secret_quota',
    :'max_secrets_per_sandbox',
    :'authenticated_rate_limit',
    :'sandbox_create_rate_limit',
    :'sandbox_lifecycle_rate_limit',
    :'authenticated_rate_limit_ttl_seconds',
    :'sandbox_create_rate_limit_ttl_seconds',
    :'sandbox_lifecycle_rate_limit_ttl_seconds',
    :'snapshot_deactivation_timeout_minutes',
    :'max_concurrent_snapshot_processing'
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 86

def self.openapi_types
  {
    :'max_cpu_per_sandbox' => :'Float',
    :'max_memory_per_sandbox' => :'Float',
    :'max_disk_per_sandbox' => :'Float',
    :'snapshot_quota' => :'Float',
    :'max_snapshot_size' => :'Float',
    :'volume_quota' => :'Float',
    :'secret_quota' => :'Float',
    :'max_secrets_per_sandbox' => :'Float',
    :'authenticated_rate_limit' => :'Float',
    :'sandbox_create_rate_limit' => :'Float',
    :'sandbox_lifecycle_rate_limit' => :'Float',
    :'authenticated_rate_limit_ttl_seconds' => :'Float',
    :'sandbox_create_rate_limit_ttl_seconds' => :'Float',
    :'sandbox_lifecycle_rate_limit_ttl_seconds' => :'Float',
    :'snapshot_deactivation_timeout_minutes' => :'Float',
    :'max_concurrent_snapshot_processing' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 259

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      max_cpu_per_sandbox == o.max_cpu_per_sandbox &&
      max_memory_per_sandbox == o.max_memory_per_sandbox &&
      max_disk_per_sandbox == o.max_disk_per_sandbox &&
      snapshot_quota == o.snapshot_quota &&
      max_snapshot_size == o.max_snapshot_size &&
      volume_quota == o.volume_quota &&
      secret_quota == o.secret_quota &&
      max_secrets_per_sandbox == o.max_secrets_per_sandbox &&
      authenticated_rate_limit == o.authenticated_rate_limit &&
      sandbox_create_rate_limit == o.sandbox_create_rate_limit &&
      sandbox_lifecycle_rate_limit == o.sandbox_lifecycle_rate_limit &&
      authenticated_rate_limit_ttl_seconds == o.authenticated_rate_limit_ttl_seconds &&
      sandbox_create_rate_limit_ttl_seconds == o.sandbox_create_rate_limit_ttl_seconds &&
      sandbox_lifecycle_rate_limit_ttl_seconds == o.sandbox_lifecycle_rate_limit_ttl_seconds &&
      snapshot_deactivation_timeout_minutes == o.snapshot_deactivation_timeout_minutes &&
      max_concurrent_snapshot_processing == o.max_concurrent_snapshot_processing
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


282
283
284
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 282

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



288
289
290
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 288

def hash
  [max_cpu_per_sandbox, max_memory_per_sandbox, max_disk_per_sandbox, snapshot_quota, max_snapshot_size, volume_quota, secret_quota, max_secrets_per_sandbox, authenticated_rate_limit, sandbox_create_rate_limit, sandbox_lifecycle_rate_limit, authenticated_rate_limit_ttl_seconds, sandbox_create_rate_limit_ttl_seconds, sandbox_lifecycle_rate_limit_ttl_seconds, snapshot_deactivation_timeout_minutes, max_concurrent_snapshot_processing].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



244
245
246
247
248
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 244

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 317

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



252
253
254
255
# File 'lib/daytona_api_client/models/update_organization_quota.rb', line 252

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end