Class: DaytonaApiClient::WarmPool

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/warm_pool.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WarmPool

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/daytona_api_client/models/warm_pool.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::WarmPool` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::WarmPool`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  else
    self.organization_id = nil
  end

  if attributes.key?(:'snapshot')
    self.snapshot = attributes[:'snapshot']
  else
    self.snapshot = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end

  if attributes.key?(:'pool')
    self.pool = attributes[:'pool']
  else
    self.pool = nil
  end

  if attributes.key?(:'current_size')
    self.current_size = attributes[:'current_size']
  else
    self.current_size = nil
  end

  if attributes.key?(:'cpu')
    self.cpu = attributes[:'cpu']
  else
    self.cpu = nil
  end

  if attributes.key?(:'mem')
    self.mem = attributes[:'mem']
  else
    self.mem = nil
  end

  if attributes.key?(:'disk')
    self.disk = attributes[:'disk']
  else
    self.disk = nil
  end

  if attributes.key?(:'os_user')
    self.os_user = attributes[:'os_user']
  else
    self.os_user = nil
  end

  if attributes.key?(:'env')
    if (value = attributes[:'env']).is_a?(Hash)
      self.env = value
    end
  else
    self.env = nil
  end

  if attributes.key?(:'error_reason')
    self.error_reason = attributes[:'error_reason']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#cpuObject

Returns the value of attribute cpu.



32
33
34
# File 'lib/daytona_api_client/models/warm_pool.rb', line 32

def cpu
  @cpu
end

#created_atObject

Returns the value of attribute created_at.



44
45
46
# File 'lib/daytona_api_client/models/warm_pool.rb', line 44

def created_at
  @created_at
end

#current_sizeObject

Current number of ready warm sandboxes in the pool



30
31
32
# File 'lib/daytona_api_client/models/warm_pool.rb', line 30

def current_size
  @current_size
end

#diskObject

Returns the value of attribute disk.



36
37
38
# File 'lib/daytona_api_client/models/warm_pool.rb', line 36

def disk
  @disk
end

#envObject

Returns the value of attribute env.



40
41
42
# File 'lib/daytona_api_client/models/warm_pool.rb', line 40

def env
  @env
end

#error_reasonObject

Returns the value of attribute error_reason.



42
43
44
# File 'lib/daytona_api_client/models/warm_pool.rb', line 42

def error_reason
  @error_reason
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/daytona_api_client/models/warm_pool.rb', line 18

def id
  @id
end

#memObject

Returns the value of attribute mem.



34
35
36
# File 'lib/daytona_api_client/models/warm_pool.rb', line 34

def mem
  @mem
end

#organization_idObject

Returns the value of attribute organization_id.



20
21
22
# File 'lib/daytona_api_client/models/warm_pool.rb', line 20

def organization_id
  @organization_id
end

#os_userObject

Returns the value of attribute os_user.



38
39
40
# File 'lib/daytona_api_client/models/warm_pool.rb', line 38

def os_user
  @os_user
end

#poolObject

Desired number of warm sandboxes



27
28
29
# File 'lib/daytona_api_client/models/warm_pool.rb', line 27

def pool
  @pool
end

#snapshotObject

Returns the value of attribute snapshot.



22
23
24
# File 'lib/daytona_api_client/models/warm_pool.rb', line 22

def snapshot
  @snapshot
end

#targetObject

Returns the value of attribute target.



24
25
26
# File 'lib/daytona_api_client/models/warm_pool.rb', line 24

def target
  @target
end

#updated_atObject

Returns the value of attribute updated_at.



46
47
48
# File 'lib/daytona_api_client/models/warm_pool.rb', line 46

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/daytona_api_client/models/warm_pool.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/daytona_api_client/models/warm_pool.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/daytona_api_client/models/warm_pool.rb', line 49

def self.attribute_map
  {
    :'id' => :'id',
    :'organization_id' => :'organizationId',
    :'snapshot' => :'snapshot',
    :'target' => :'target',
    :'pool' => :'pool',
    :'current_size' => :'currentSize',
    :'cpu' => :'cpu',
    :'mem' => :'mem',
    :'disk' => :'disk',
    :'os_user' => :'osUser',
    :'env' => :'env',
    :'error_reason' => :'errorReason',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
# File 'lib/daytona_api_client/models/warm_pool.rb', line 452

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
103
# File 'lib/daytona_api_client/models/warm_pool.rb', line 99

def self.openapi_nullable
  Set.new([
    :'error_reason',
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/daytona_api_client/models/warm_pool.rb', line 79

def self.openapi_types
  {
    :'id' => :'String',
    :'organization_id' => :'String',
    :'snapshot' => :'String',
    :'target' => :'String',
    :'pool' => :'Float',
    :'current_size' => :'Float',
    :'cpu' => :'Float',
    :'mem' => :'Float',
    :'disk' => :'Float',
    :'os_user' => :'String',
    :'env' => :'Hash<String, String>',
    :'error_reason' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/daytona_api_client/models/warm_pool.rb', line 418

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      organization_id == o.organization_id &&
      snapshot == o.snapshot &&
      target == o.target &&
      pool == o.pool &&
      current_size == o.current_size &&
      cpu == o.cpu &&
      mem == o.mem &&
      disk == o.disk &&
      os_user == o.os_user &&
      env == o.env &&
      error_reason == o.error_reason &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


439
440
441
# File 'lib/daytona_api_client/models/warm_pool.rb', line 439

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



445
446
447
# File 'lib/daytona_api_client/models/warm_pool.rb', line 445

def hash
  [id, organization_id, snapshot, target, pool, current_size, cpu, mem, disk, os_user, env, error_reason, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/daytona_api_client/models/warm_pool.rb', line 208

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @organization_id.nil?
    invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.')
  end

  if @snapshot.nil?
    invalid_properties.push('invalid value for "snapshot", snapshot cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  if @pool.nil?
    invalid_properties.push('invalid value for "pool", pool cannot be nil.')
  end

  if @current_size.nil?
    invalid_properties.push('invalid value for "current_size", current_size cannot be nil.')
  end

  if @cpu.nil?
    invalid_properties.push('invalid value for "cpu", cpu cannot be nil.')
  end

  if @mem.nil?
    invalid_properties.push('invalid value for "mem", mem cannot be nil.')
  end

  if @disk.nil?
    invalid_properties.push('invalid value for "disk", disk cannot be nil.')
  end

  if @os_user.nil?
    invalid_properties.push('invalid value for "os_user", os_user cannot be nil.')
  end

  if @env.nil?
    invalid_properties.push('invalid value for "env", env cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



474
475
476
477
478
479
480
481
482
483
484
485
486
# File 'lib/daytona_api_client/models/warm_pool.rb', line 474

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/daytona_api_client/models/warm_pool.rb', line 268

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @organization_id.nil?
  return false if @snapshot.nil?
  return false if @target.nil?
  return false if @pool.nil?
  return false if @current_size.nil?
  return false if @cpu.nil?
  return false if @mem.nil?
  return false if @disk.nil?
  return false if @os_user.nil?
  return false if @env.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end