Class: DaytonaApiClient::WebhooksApi
- Inherits:
-
Object
- Object
- DaytonaApiClient::WebhooksApi
- Defined in:
- lib/daytona_api_client/api/webhooks_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ WebhooksApi
constructor
A new instance of WebhooksApi.
-
#webhook_controller_get_app_portal_access(organization_id, opts = {}) ⇒ WebhookAppPortalAccess
Get Svix Consumer App Portal access for an organization.
-
#webhook_controller_get_app_portal_access_with_http_info(organization_id, opts = {}) ⇒ Array<(WebhookAppPortalAccess, Integer, Hash)>
Get Svix Consumer App Portal access for an organization.
-
#webhook_controller_get_initialization_status(organization_id, opts = {}) ⇒ WebhookInitializationStatus
Get webhook initialization status for an organization.
-
#webhook_controller_get_initialization_status_with_http_info(organization_id, opts = {}) ⇒ Array<(WebhookInitializationStatus, Integer, Hash)>
Get webhook initialization status for an organization.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WebhooksApi
Returns a new instance of WebhooksApi.
19 20 21 |
# File 'lib/daytona_api_client/api/webhooks_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/daytona_api_client/api/webhooks_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#webhook_controller_get_app_portal_access(organization_id, opts = {}) ⇒ WebhookAppPortalAccess
Get Svix Consumer App Portal access for an organization
27 28 29 30 |
# File 'lib/daytona_api_client/api/webhooks_api.rb', line 27 def webhook_controller_get_app_portal_access(organization_id, opts = {}) data, _status_code, _headers = webhook_controller_get_app_portal_access_with_http_info(organization_id, opts) data end |
#webhook_controller_get_app_portal_access_with_http_info(organization_id, opts = {}) ⇒ Array<(WebhookAppPortalAccess, Integer, Hash)>
Get Svix Consumer App Portal access for an organization
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/daytona_api_client/api/webhooks_api.rb', line 37 def webhook_controller_get_app_portal_access_with_http_info(organization_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.webhook_controller_get_app_portal_access ...' end # verify the required parameter 'organization_id' is set if @api_client.config.client_side_validation && organization_id.nil? fail ArgumentError, "Missing the required parameter 'organization_id' when calling WebhooksApi.webhook_controller_get_app_portal_access" end # resource path local_var_path = '/webhooks/organizations/{organizationId}/app-portal-access'.sub('{' + 'organizationId' + '}', CGI.escape(organization_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Daytona-Organization-ID'] = opts[:'x_daytona_organization_id'] if !opts[:'x_daytona_organization_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebhookAppPortalAccess' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"WebhooksApi.webhook_controller_get_app_portal_access", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#webhook_controller_get_app_portal_access\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#webhook_controller_get_initialization_status(organization_id, opts = {}) ⇒ WebhookInitializationStatus
Get webhook initialization status for an organization
91 92 93 94 |
# File 'lib/daytona_api_client/api/webhooks_api.rb', line 91 def webhook_controller_get_initialization_status(organization_id, opts = {}) data, _status_code, _headers = webhook_controller_get_initialization_status_with_http_info(organization_id, opts) data end |
#webhook_controller_get_initialization_status_with_http_info(organization_id, opts = {}) ⇒ Array<(WebhookInitializationStatus, Integer, Hash)>
Get webhook initialization status for an organization
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/daytona_api_client/api/webhooks_api.rb', line 101 def webhook_controller_get_initialization_status_with_http_info(organization_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.webhook_controller_get_initialization_status ...' end # verify the required parameter 'organization_id' is set if @api_client.config.client_side_validation && organization_id.nil? fail ArgumentError, "Missing the required parameter 'organization_id' when calling WebhooksApi.webhook_controller_get_initialization_status" end # resource path local_var_path = '/webhooks/organizations/{organizationId}/initialization-status'.sub('{' + 'organizationId' + '}', CGI.escape(organization_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Daytona-Organization-ID'] = opts[:'x_daytona_organization_id'] if !opts[:'x_daytona_organization_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebhookInitializationStatus' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"WebhooksApi.webhook_controller_get_initialization_status", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#webhook_controller_get_initialization_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |