Class: DaytonaApiClient::AuditApi
- Inherits:
-
Object
- Object
- DaytonaApiClient::AuditApi
- Defined in:
- lib/daytona_api_client/api/audit_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_organization_audit_logs(organization_id, opts = {}) ⇒ PaginatedAuditLogs
Get audit logs for organization.
-
#get_organization_audit_logs_with_http_info(organization_id, opts = {}) ⇒ Array<(PaginatedAuditLogs, Integer, Hash)>
Get audit logs for organization.
-
#initialize(api_client = ApiClient.default) ⇒ AuditApi
constructor
A new instance of AuditApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/daytona_api_client/api/audit_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_organization_audit_logs(organization_id, opts = {}) ⇒ PaginatedAuditLogs
Get audit logs for organization
31 32 33 34 |
# File 'lib/daytona_api_client/api/audit_api.rb', line 31 def get_organization_audit_logs(organization_id, opts = {}) data, _status_code, _headers = get_organization_audit_logs_with_http_info(organization_id, opts) data end |
#get_organization_audit_logs_with_http_info(organization_id, opts = {}) ⇒ Array<(PaginatedAuditLogs, Integer, Hash)>
Get audit logs for organization
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/daytona_api_client/api/audit_api.rb', line 45 def get_organization_audit_logs_with_http_info(organization_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuditApi.get_organization_audit_logs ...' end # verify the required parameter 'organization_id' is set if @api_client.config.client_side_validation && organization_id.nil? fail ArgumentError, "Missing the required parameter 'organization_id' when calling AuditApi.get_organization_audit_logs" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling AuditApi.get_organization_audit_logs, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 200 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AuditApi.get_organization_audit_logs, must be smaller than or equal to 200.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AuditApi.get_organization_audit_logs, must be greater than or equal to 1.' end # resource path local_var_path = '/audit/organizations/{organizationId}'.sub('{' + 'organizationId' + '}', CGI.escape(organization_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'from'] = opts[:'from'] if !opts[:'from'].nil? query_params[:'to'] = opts[:'to'] if !opts[:'to'].nil? query_params[:'nextToken'] = opts[:'next_token'] if !opts[:'next_token'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedAuditLogs' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"AuditApi.get_organization_audit_logs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditApi#get_organization_audit_logs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |