Class: DaytonaApiClient::CreateOrganizationRegionQuota

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/daytona_api_client/models/create_organization_region_quota.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateOrganizationRegionQuota

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::CreateOrganizationRegionQuota` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::CreateOrganizationRegionQuota`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'sandbox_class')
    self.sandbox_class = attributes[:'sandbox_class']
  else
    self.sandbox_class = nil
  end

  if attributes.key?(:'total_cpu_quota')
    self.total_cpu_quota = attributes[:'total_cpu_quota']
  else
    self.total_cpu_quota = nil
  end

  if attributes.key?(:'total_memory_quota')
    self.total_memory_quota = attributes[:'total_memory_quota']
  else
    self.total_memory_quota = nil
  end

  if attributes.key?(:'total_disk_quota')
    self.total_disk_quota = attributes[:'total_disk_quota']
  else
    self.total_disk_quota = nil
  end

  if attributes.key?(:'total_gpu_quota')
    self.total_gpu_quota = attributes[:'total_gpu_quota']
  else
    self.total_gpu_quota = nil
  end

  if attributes.key?(:'allowed_gpu_types')
    if (value = attributes[:'allowed_gpu_types']).is_a?(Array)
      self.allowed_gpu_types = value
    end
  end

  if attributes.key?(:'max_cpu_per_sandbox')
    self.max_cpu_per_sandbox = attributes[:'max_cpu_per_sandbox']
  end

  if attributes.key?(:'max_memory_per_sandbox')
    self.max_memory_per_sandbox = attributes[:'max_memory_per_sandbox']
  end

  if attributes.key?(:'max_disk_per_sandbox')
    self.max_disk_per_sandbox = attributes[:'max_disk_per_sandbox']
  end

  if attributes.key?(:'max_disk_per_non_ephemeral_sandbox')
    self.max_disk_per_non_ephemeral_sandbox = attributes[:'max_disk_per_non_ephemeral_sandbox']
  end

  if attributes.key?(:'max_cpu_per_gpu_sandbox')
    self.max_cpu_per_gpu_sandbox = attributes[:'max_cpu_per_gpu_sandbox']
  end

  if attributes.key?(:'max_memory_per_gpu_sandbox')
    self.max_memory_per_gpu_sandbox = attributes[:'max_memory_per_gpu_sandbox']
  end

  if attributes.key?(:'max_disk_per_gpu_sandbox')
    self.max_disk_per_gpu_sandbox = attributes[:'max_disk_per_gpu_sandbox']
  end
end

Instance Attribute Details

#allowed_gpu_typesObject

Returns the value of attribute allowed_gpu_types.



28
29
30
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 28

def allowed_gpu_types
  @allowed_gpu_types
end

#max_cpu_per_gpu_sandboxObject

Returns the value of attribute max_cpu_per_gpu_sandbox.



38
39
40
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 38

def max_cpu_per_gpu_sandbox
  @max_cpu_per_gpu_sandbox
end

#max_cpu_per_sandboxObject

Returns the value of attribute max_cpu_per_sandbox.



30
31
32
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 30

def max_cpu_per_sandbox
  @max_cpu_per_sandbox
end

#max_disk_per_gpu_sandboxObject

Returns the value of attribute max_disk_per_gpu_sandbox.



42
43
44
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 42

def max_disk_per_gpu_sandbox
  @max_disk_per_gpu_sandbox
end

#max_disk_per_non_ephemeral_sandboxObject

Returns the value of attribute max_disk_per_non_ephemeral_sandbox.



36
37
38
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 36

def max_disk_per_non_ephemeral_sandbox
  @max_disk_per_non_ephemeral_sandbox
end

#max_disk_per_sandboxObject

Returns the value of attribute max_disk_per_sandbox.



34
35
36
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 34

def max_disk_per_sandbox
  @max_disk_per_sandbox
end

#max_memory_per_gpu_sandboxObject

Returns the value of attribute max_memory_per_gpu_sandbox.



40
41
42
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 40

def max_memory_per_gpu_sandbox
  @max_memory_per_gpu_sandbox
end

#max_memory_per_sandboxObject

Returns the value of attribute max_memory_per_sandbox.



32
33
34
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 32

def max_memory_per_sandbox
  @max_memory_per_sandbox
end

#sandbox_classObject

Returns the value of attribute sandbox_class.



18
19
20
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 18

def sandbox_class
  @sandbox_class
end

#total_cpu_quotaObject

Returns the value of attribute total_cpu_quota.



20
21
22
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 20

def total_cpu_quota
  @total_cpu_quota
end

#total_disk_quotaObject

Returns the value of attribute total_disk_quota.



24
25
26
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 24

def total_disk_quota
  @total_disk_quota
end

#total_gpu_quotaObject

Returns the value of attribute total_gpu_quota.



26
27
28
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 26

def total_gpu_quota
  @total_gpu_quota
end

#total_memory_quotaObject

Returns the value of attribute total_memory_quota.



22
23
24
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 22

def total_memory_quota
  @total_memory_quota
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 67

def self.attribute_map
  {
    :'sandbox_class' => :'sandboxClass',
    :'total_cpu_quota' => :'totalCpuQuota',
    :'total_memory_quota' => :'totalMemoryQuota',
    :'total_disk_quota' => :'totalDiskQuota',
    :'total_gpu_quota' => :'totalGpuQuota',
    :'allowed_gpu_types' => :'allowedGpuTypes',
    :'max_cpu_per_sandbox' => :'maxCpuPerSandbox',
    :'max_memory_per_sandbox' => :'maxMemoryPerSandbox',
    :'max_disk_per_sandbox' => :'maxDiskPerSandbox',
    :'max_disk_per_non_ephemeral_sandbox' => :'maxDiskPerNonEphemeralSandbox',
    :'max_cpu_per_gpu_sandbox' => :'maxCpuPerGpuSandbox',
    :'max_memory_per_gpu_sandbox' => :'maxMemoryPerGpuSandbox',
    :'max_disk_per_gpu_sandbox' => :'maxDiskPerGpuSandbox'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 334

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 115

def self.openapi_nullable
  Set.new([
    :'allowed_gpu_types',
    :'max_cpu_per_sandbox',
    :'max_memory_per_sandbox',
    :'max_disk_per_sandbox',
    :'max_disk_per_non_ephemeral_sandbox',
    :'max_cpu_per_gpu_sandbox',
    :'max_memory_per_gpu_sandbox',
    :'max_disk_per_gpu_sandbox'
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 96

def self.openapi_types
  {
    :'sandbox_class' => :'SandboxClass',
    :'total_cpu_quota' => :'Float',
    :'total_memory_quota' => :'Float',
    :'total_disk_quota' => :'Float',
    :'total_gpu_quota' => :'Float',
    :'allowed_gpu_types' => :'Array<GpuType>',
    :'max_cpu_per_sandbox' => :'Float',
    :'max_memory_per_sandbox' => :'Float',
    :'max_disk_per_sandbox' => :'Float',
    :'max_disk_per_non_ephemeral_sandbox' => :'Float',
    :'max_cpu_per_gpu_sandbox' => :'Float',
    :'max_memory_per_gpu_sandbox' => :'Float',
    :'max_disk_per_gpu_sandbox' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 301

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      sandbox_class == o.sandbox_class &&
      total_cpu_quota == o.total_cpu_quota &&
      total_memory_quota == o.total_memory_quota &&
      total_disk_quota == o.total_disk_quota &&
      total_gpu_quota == o.total_gpu_quota &&
      allowed_gpu_types == o.allowed_gpu_types &&
      max_cpu_per_sandbox == o.max_cpu_per_sandbox &&
      max_memory_per_sandbox == o.max_memory_per_sandbox &&
      max_disk_per_sandbox == o.max_disk_per_sandbox &&
      max_disk_per_non_ephemeral_sandbox == o.max_disk_per_non_ephemeral_sandbox &&
      max_cpu_per_gpu_sandbox == o.max_cpu_per_gpu_sandbox &&
      max_memory_per_gpu_sandbox == o.max_memory_per_gpu_sandbox &&
      max_disk_per_gpu_sandbox == o.max_disk_per_gpu_sandbox
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


321
322
323
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 321

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



327
328
329
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 327

def hash
  [sandbox_class, total_cpu_quota, total_memory_quota, total_disk_quota, total_gpu_quota, allowed_gpu_types, max_cpu_per_sandbox, max_memory_per_sandbox, max_disk_per_sandbox, max_disk_per_non_ephemeral_sandbox, max_cpu_per_gpu_sandbox, max_memory_per_gpu_sandbox, max_disk_per_gpu_sandbox].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 211

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @sandbox_class.nil?
    invalid_properties.push('invalid value for "sandbox_class", sandbox_class cannot be nil.')
  end

  if @total_cpu_quota.nil?
    invalid_properties.push('invalid value for "total_cpu_quota", total_cpu_quota cannot be nil.')
  end

  if @total_memory_quota.nil?
    invalid_properties.push('invalid value for "total_memory_quota", total_memory_quota cannot be nil.')
  end

  if @total_disk_quota.nil?
    invalid_properties.push('invalid value for "total_disk_quota", total_disk_quota cannot be nil.')
  end

  if @total_gpu_quota.nil?
    invalid_properties.push('invalid value for "total_gpu_quota", total_gpu_quota cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 356

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



239
240
241
242
243
244
245
246
247
# File 'lib/daytona_api_client/models/create_organization_region_quota.rb', line 239

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @sandbox_class.nil?
  return false if @total_cpu_quota.nil?
  return false if @total_memory_quota.nil?
  return false if @total_disk_quota.nil?
  return false if @total_gpu_quota.nil?
  true
end