Class: DaytonaApiClient::CreateSandbox
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::CreateSandbox
- Defined in:
- lib/daytona_api_client/models/create_sandbox.rb
Instance Attribute Summary collapse
-
#auto_archive_interval ⇒ Object
Auto-archive interval in minutes (0 means the maximum interval will be used).
-
#auto_delete_interval ⇒ Object
Auto-delete interval in minutes (negative value means disabled, 0 means delete immediately upon stopping).
-
#auto_stop_interval ⇒ Object
Auto-stop interval in minutes (0 means disabled).
-
#build_info ⇒ Object
Build information for the sandbox.
-
#cpu ⇒ Object
CPU cores allocated to the sandbox.
-
#disk ⇒ Object
Disk space allocated to the sandbox in GB.
-
#domain_allow_list ⇒ Object
Comma-separated list of allowed domains for the sandbox.
-
#env ⇒ Object
Environment variables for the sandbox.
-
#gpu ⇒ Object
GPU units allocated to the sandbox.
-
#gpu_type ⇒ Object
Preferred GPU type for the sandbox.
-
#labels ⇒ Object
Labels for the sandbox.
-
#linked_sandbox ⇒ Object
ID or name of an existing sandbox to link the new sandbox to.
-
#memory ⇒ Object
Memory allocated to the sandbox in GB.
-
#name ⇒ Object
The name of the sandbox.
-
#network_allow_list ⇒ Object
Comma-separated list of allowed CIDR network addresses for the sandbox.
-
#network_block_all ⇒ Object
Whether to block all network access for the sandbox.
-
#public ⇒ Object
Whether the sandbox http preview is publicly accessible.
-
#snapshot ⇒ Object
The ID or name of the snapshot used for the sandbox.
-
#target ⇒ Object
The target (region) where the sandbox will be created.
-
#user ⇒ Object
The user associated with the project.
-
#volumes ⇒ Object
Array of volumes to attach to the sandbox.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSandbox
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateSandbox
Initializes the object
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 153 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::CreateSandbox` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::CreateSandbox`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'snapshot') self.snapshot = attributes[:'snapshot'] end if attributes.key?(:'user') self.user = attributes[:'user'] end if attributes.key?(:'env') if (value = attributes[:'env']).is_a?(Hash) self.env = value end end if attributes.key?(:'labels') if (value = attributes[:'labels']).is_a?(Hash) self.labels = value end end if attributes.key?(:'public') self.public = attributes[:'public'] end if attributes.key?(:'network_block_all') self.network_block_all = attributes[:'network_block_all'] end if attributes.key?(:'network_allow_list') self.network_allow_list = attributes[:'network_allow_list'] end if attributes.key?(:'domain_allow_list') self.domain_allow_list = attributes[:'domain_allow_list'] end if attributes.key?(:'target') self.target = attributes[:'target'] end if attributes.key?(:'cpu') self.cpu = attributes[:'cpu'] end if attributes.key?(:'gpu') self.gpu = attributes[:'gpu'] end if attributes.key?(:'gpu_type') if (value = attributes[:'gpu_type']).is_a?(Array) self.gpu_type = value end end if attributes.key?(:'memory') self.memory = attributes[:'memory'] end if attributes.key?(:'disk') self.disk = attributes[:'disk'] end if attributes.key?(:'auto_stop_interval') self.auto_stop_interval = attributes[:'auto_stop_interval'] end if attributes.key?(:'auto_archive_interval') self.auto_archive_interval = attributes[:'auto_archive_interval'] end if attributes.key?(:'auto_delete_interval') self.auto_delete_interval = attributes[:'auto_delete_interval'] end if attributes.key?(:'volumes') if (value = attributes[:'volumes']).is_a?(Array) self.volumes = value end end if attributes.key?(:'build_info') self.build_info = attributes[:'build_info'] end if attributes.key?(:'linked_sandbox') self.linked_sandbox = attributes[:'linked_sandbox'] end end |
Instance Attribute Details
#auto_archive_interval ⇒ Object
Auto-archive interval in minutes (0 means the maximum interval will be used)
67 68 69 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 67 def auto_archive_interval @auto_archive_interval end |
#auto_delete_interval ⇒ Object
Auto-delete interval in minutes (negative value means disabled, 0 means delete immediately upon stopping)
70 71 72 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 70 def auto_delete_interval @auto_delete_interval end |
#auto_stop_interval ⇒ Object
Auto-stop interval in minutes (0 means disabled)
64 65 66 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 64 def auto_stop_interval @auto_stop_interval end |
#build_info ⇒ Object
Build information for the sandbox
76 77 78 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 76 def build_info @build_info end |
#cpu ⇒ Object
CPU cores allocated to the sandbox
49 50 51 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 49 def cpu @cpu end |
#disk ⇒ Object
Disk space allocated to the sandbox in GB
61 62 63 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 61 def disk @disk end |
#domain_allow_list ⇒ Object
Comma-separated list of allowed domains for the sandbox
43 44 45 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 43 def domain_allow_list @domain_allow_list end |
#env ⇒ Object
Environment variables for the sandbox
28 29 30 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 28 def env @env end |
#gpu ⇒ Object
GPU units allocated to the sandbox
52 53 54 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 52 def gpu @gpu end |
#gpu_type ⇒ Object
Preferred GPU type for the sandbox. Accepts a single value or an ordered preference list — the scheduler tries each in order and pins the sandbox to the first that has capacity.
55 56 57 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 55 def gpu_type @gpu_type end |
#labels ⇒ Object
Labels for the sandbox
31 32 33 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 31 def labels @labels end |
#linked_sandbox ⇒ Object
ID or name of an existing sandbox to link the new sandbox to. The new sandbox will be scheduled on the same runner as the linked sandbox so a local network can be established between them. Linked sandboxes must be ephemeral (autoDeleteInterval=0) and cannot themselves be linked to another sandbox.
79 80 81 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 79 def linked_sandbox @linked_sandbox end |
#memory ⇒ Object
Memory allocated to the sandbox in GB
58 59 60 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 58 def memory @memory end |
#name ⇒ Object
The name of the sandbox. If not provided, the sandbox ID will be used as the name
19 20 21 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 19 def name @name end |
#network_allow_list ⇒ Object
Comma-separated list of allowed CIDR network addresses for the sandbox
40 41 42 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 40 def network_allow_list @network_allow_list end |
#network_block_all ⇒ Object
Whether to block all network access for the sandbox
37 38 39 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 37 def network_block_all @network_block_all end |
#public ⇒ Object
Whether the sandbox http preview is publicly accessible
34 35 36 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 34 def public @public end |
#snapshot ⇒ Object
The ID or name of the snapshot used for the sandbox
22 23 24 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 22 def snapshot @snapshot end |
#target ⇒ Object
The target (region) where the sandbox will be created
46 47 48 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 46 def target @target end |
#user ⇒ Object
The user associated with the project
25 26 27 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 25 def user @user end |
#volumes ⇒ Object
Array of volumes to attach to the sandbox
73 74 75 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 73 def volumes @volumes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
109 110 111 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 109 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
114 115 116 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 114 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 82 def self.attribute_map { :'name' => :'name', :'snapshot' => :'snapshot', :'user' => :'user', :'env' => :'env', :'labels' => :'labels', :'public' => :'public', :'network_block_all' => :'networkBlockAll', :'network_allow_list' => :'networkAllowList', :'domain_allow_list' => :'domainAllowList', :'target' => :'target', :'cpu' => :'cpu', :'gpu' => :'gpu', :'gpu_type' => :'gpuType', :'memory' => :'memory', :'disk' => :'disk', :'auto_stop_interval' => :'autoStopInterval', :'auto_archive_interval' => :'autoArchiveInterval', :'auto_delete_interval' => :'autoDeleteInterval', :'volumes' => :'volumes', :'build_info' => :'buildInfo', :'linked_sandbox' => :'linkedSandbox' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 318 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
146 147 148 149 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 146 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 119 def self.openapi_types { :'name' => :'String', :'snapshot' => :'String', :'user' => :'String', :'env' => :'Hash<String, String>', :'labels' => :'Hash<String, String>', :'public' => :'Boolean', :'network_block_all' => :'Boolean', :'network_allow_list' => :'String', :'domain_allow_list' => :'String', :'target' => :'String', :'cpu' => :'Integer', :'gpu' => :'Integer', :'gpu_type' => :'Array<GpuType>', :'memory' => :'Integer', :'disk' => :'Integer', :'auto_stop_interval' => :'Integer', :'auto_archive_interval' => :'Integer', :'auto_delete_interval' => :'Integer', :'volumes' => :'Array<SandboxVolume>', :'build_info' => :'CreateBuildInfo', :'linked_sandbox' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 277 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && snapshot == o.snapshot && user == o.user && env == o.env && labels == o.labels && public == o.public && network_block_all == o.network_block_all && network_allow_list == o.network_allow_list && domain_allow_list == o.domain_allow_list && target == o.target && cpu == o.cpu && gpu == o.gpu && gpu_type == o.gpu_type && memory == o.memory && disk == o.disk && auto_stop_interval == o.auto_stop_interval && auto_archive_interval == o.auto_archive_interval && auto_delete_interval == o.auto_delete_interval && volumes == o.volumes && build_info == o.build_info && linked_sandbox == o.linked_sandbox end |
#eql?(o) ⇒ Boolean
305 306 307 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 305 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
311 312 313 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 311 def hash [name, snapshot, user, env, labels, public, network_block_all, network_allow_list, domain_allow_list, target, cpu, gpu, gpu_type, memory, disk, auto_stop_interval, auto_archive_interval, auto_delete_interval, volumes, build_info, linked_sandbox].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
262 263 264 265 266 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 262 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 340 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
270 271 272 273 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 270 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |