Class: DaytonaApiClient::CreateSandbox
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::CreateSandbox
- Defined in:
- lib/daytona_api_client/models/create_sandbox.rb
Instance Attribute Summary collapse
-
#auto_archive_interval ⇒ Object
Auto-archive interval in minutes (0 means the maximum interval will be used).
-
#auto_delete_interval ⇒ Object
Auto-delete interval in minutes (negative value means disabled, 0 means delete immediately upon stopping).
-
#auto_pause_interval ⇒ Object
Auto-pause interval in minutes (0 means disabled).
-
#auto_stop_interval ⇒ Object
Auto-stop interval in minutes (0 means disabled).
-
#build_info ⇒ Object
Build information for the sandbox.
-
#cpu ⇒ Object
CPU cores allocated to the sandbox.
-
#disk ⇒ Object
Disk space allocated to the sandbox in GB.
-
#domain_allow_list ⇒ Object
Comma-separated list of allowed domains for the sandbox.
-
#env ⇒ Object
Environment variables for the sandbox.
-
#gpu ⇒ Object
GPU units allocated to the sandbox.
-
#gpu_type ⇒ Object
Preferred GPU type for the sandbox.
-
#labels ⇒ Object
Labels for the sandbox.
-
#linked_sandbox ⇒ Object
ID or name of an existing sandbox to link the new sandbox to.
-
#memory ⇒ Object
Memory allocated to the sandbox in GB.
-
#name ⇒ Object
The name of the sandbox.
-
#network_allow_list ⇒ Object
Comma-separated list of allowed CIDR network addresses for the sandbox.
-
#network_block_all ⇒ Object
Whether to block all network access for the sandbox.
-
#otel_endpoint_override ⇒ Object
OTel collector endpoint override for this sandbox.
-
#outbound_proxy_url ⇒ Object
Outbound proxy URL to route the sandbox HTTP(S) traffic through (http or https; credentials may be included in the URL).
-
#public ⇒ Object
Whether the sandbox http preview is publicly accessible.
-
#secrets ⇒ Object
Secrets to mount in this sandbox.
-
#snapshot ⇒ Object
The ID or name of the snapshot used for the sandbox.
-
#spot ⇒ Object
GPU-only.
-
#target ⇒ Object
The target (region) where the sandbox will be created.
-
#ttl_minutes ⇒ Object
Maximum time to live in minutes, counted as wall-clock time since creation regardless of sandbox state (0 means disabled).
-
#user ⇒ Object
The user associated with the project.
-
#volumes ⇒ Object
Array of volumes to attach to the sandbox.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSandbox
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateSandbox
Initializes the object
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 183 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::CreateSandbox` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::CreateSandbox`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'snapshot') self.snapshot = attributes[:'snapshot'] end if attributes.key?(:'user') self.user = attributes[:'user'] end if attributes.key?(:'env') if (value = attributes[:'env']).is_a?(Hash) self.env = value end end if attributes.key?(:'labels') if (value = attributes[:'labels']).is_a?(Hash) self.labels = value end end if attributes.key?(:'public') self.public = attributes[:'public'] end if attributes.key?(:'network_block_all') self.network_block_all = attributes[:'network_block_all'] end if attributes.key?(:'network_allow_list') self.network_allow_list = attributes[:'network_allow_list'] end if attributes.key?(:'domain_allow_list') self.domain_allow_list = attributes[:'domain_allow_list'] end if attributes.key?(:'outbound_proxy_url') self.outbound_proxy_url = attributes[:'outbound_proxy_url'] end if attributes.key?(:'otel_endpoint_override') self.otel_endpoint_override = attributes[:'otel_endpoint_override'] end if attributes.key?(:'target') self.target = attributes[:'target'] end if attributes.key?(:'cpu') self.cpu = attributes[:'cpu'] end if attributes.key?(:'gpu') self.gpu = attributes[:'gpu'] end if attributes.key?(:'gpu_type') if (value = attributes[:'gpu_type']).is_a?(Array) self.gpu_type = value end end if attributes.key?(:'spot') self.spot = attributes[:'spot'] else self.spot = false end if attributes.key?(:'memory') self.memory = attributes[:'memory'] end if attributes.key?(:'disk') self.disk = attributes[:'disk'] end if attributes.key?(:'auto_stop_interval') self.auto_stop_interval = attributes[:'auto_stop_interval'] end if attributes.key?(:'auto_pause_interval') self.auto_pause_interval = attributes[:'auto_pause_interval'] end if attributes.key?(:'auto_archive_interval') self.auto_archive_interval = attributes[:'auto_archive_interval'] end if attributes.key?(:'auto_delete_interval') self.auto_delete_interval = attributes[:'auto_delete_interval'] end if attributes.key?(:'ttl_minutes') self.ttl_minutes = attributes[:'ttl_minutes'] end if attributes.key?(:'volumes') if (value = attributes[:'volumes']).is_a?(Array) self.volumes = value end end if attributes.key?(:'build_info') self.build_info = attributes[:'build_info'] end if attributes.key?(:'linked_sandbox') self.linked_sandbox = attributes[:'linked_sandbox'] end if attributes.key?(:'secrets') if (value = attributes[:'secrets']).is_a?(Array) self.secrets = value end end end |
Instance Attribute Details
#auto_archive_interval ⇒ Object
Auto-archive interval in minutes (0 means the maximum interval will be used)
79 80 81 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 79 def auto_archive_interval @auto_archive_interval end |
#auto_delete_interval ⇒ Object
Auto-delete interval in minutes (negative value means disabled, 0 means delete immediately upon stopping)
82 83 84 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 82 def auto_delete_interval @auto_delete_interval end |
#auto_pause_interval ⇒ Object
Auto-pause interval in minutes (0 means disabled). Only supported for sandbox classes that support pausing. Not allowed for ephemeral sandboxes. At most one of autoStopInterval and autoPauseInterval may be non-zero. For non-ephemeral sandbox classes that support pausing, defaults to 60 minutes (with auto-stop disabled) when neither interval is provided.
76 77 78 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 76 def auto_pause_interval @auto_pause_interval end |
#auto_stop_interval ⇒ Object
Auto-stop interval in minutes (0 means disabled)
73 74 75 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 73 def auto_stop_interval @auto_stop_interval end |
#build_info ⇒ Object
Build information for the sandbox
91 92 93 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 91 def build_info @build_info end |
#cpu ⇒ Object
CPU cores allocated to the sandbox
55 56 57 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 55 def cpu @cpu end |
#disk ⇒ Object
Disk space allocated to the sandbox in GB
70 71 72 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 70 def disk @disk end |
#domain_allow_list ⇒ Object
Comma-separated list of allowed domains for the sandbox
43 44 45 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 43 def domain_allow_list @domain_allow_list end |
#env ⇒ Object
Environment variables for the sandbox
28 29 30 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 28 def env @env end |
#gpu ⇒ Object
GPU units allocated to the sandbox
58 59 60 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 58 def gpu @gpu end |
#gpu_type ⇒ Object
Preferred GPU type for the sandbox. Accepts a single value or an ordered preference list — the scheduler tries each in order and pins the sandbox to the first that has capacity.
61 62 63 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 61 def gpu_type @gpu_type end |
#labels ⇒ Object
Labels for the sandbox
31 32 33 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 31 def labels @labels end |
#linked_sandbox ⇒ Object
ID or name of an existing sandbox to link the new sandbox to. The new sandbox will be scheduled on the same runner as the linked sandbox so a local network can be established between them. Linked sandboxes must be ephemeral (autoDeleteInterval=0) and cannot themselves be linked to another sandbox. GPU sandboxes cannot participate in links in either direction: a GPU sandbox cannot specify linkedSandbox, and cannot be the link target of another sandbox.
94 95 96 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 94 def linked_sandbox @linked_sandbox end |
#memory ⇒ Object
Memory allocated to the sandbox in GB
67 68 69 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 67 def memory @memory end |
#name ⇒ Object
The name of the sandbox. If not provided, the sandbox ID will be used as the name
19 20 21 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 19 def name @name end |
#network_allow_list ⇒ Object
Comma-separated list of allowed CIDR network addresses for the sandbox
40 41 42 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 40 def network_allow_list @network_allow_list end |
#network_block_all ⇒ Object
Whether to block all network access for the sandbox
37 38 39 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 37 def network_block_all @network_block_all end |
#otel_endpoint_override ⇒ Object
OTel collector endpoint override for this sandbox. When set, sandbox OTel data is sent to this endpoint instead of the default collector (the Daytona-hosted collector or the region-configured endpoint) and will not be available in the Daytona analytics API or dashboard.
49 50 51 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 49 def otel_endpoint_override @otel_endpoint_override end |
#outbound_proxy_url ⇒ Object
Outbound proxy URL to route the sandbox HTTP(S) traffic through (http or https; credentials may be included in the URL). On its own this is convenience routing, not a security boundary: it is applied by injecting the standard HTTP(S)_PROXY environment variables at creation, so a process that clears those variables egresses directly. Combine with domainAllowList to have web-port (80/443) egress transparently redirected through the proxy chain at the network layer, which cannot be bypassed from inside the sandbox.
46 47 48 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 46 def outbound_proxy_url @outbound_proxy_url end |
#public ⇒ Object
Whether the sandbox http preview is publicly accessible
34 35 36 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 34 def public @public end |
#secrets ⇒ Object
Secrets to mount in this sandbox. Each entry maps an env var name to a vault secret name.
97 98 99 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 97 def secrets @secrets end |
#snapshot ⇒ Object
The ID or name of the snapshot used for the sandbox
22 23 24 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 22 def snapshot @snapshot end |
#spot ⇒ Object
GPU-only. When true, the sandbox may be instantly terminated without notice to free GPU capacity for an on-demand (non-spot) GPU sandbox. Ignored / rejected when the sandbox requests no GPUs.
64 65 66 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 64 def spot @spot end |
#target ⇒ Object
The target (region) where the sandbox will be created
52 53 54 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 52 def target @target end |
#ttl_minutes ⇒ Object
Maximum time to live in minutes, counted as wall-clock time since creation regardless of sandbox state (0 means disabled). When it elapses the sandbox is destroyed, even if it is stopped, paused, or archived. Subject to the maximum sandbox lifespan configured for the organization region and sandbox class, in which case it also defaults to that maximum and cannot be disabled.
85 86 87 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 85 def ttl_minutes @ttl_minutes end |
#user ⇒ Object
The user associated with the project
25 26 27 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 25 def user @user end |
#volumes ⇒ Object
Array of volumes to attach to the sandbox
88 89 90 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 88 def volumes @volumes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
133 134 135 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 133 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
138 139 140 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 138 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 100 def self.attribute_map { :'name' => :'name', :'snapshot' => :'snapshot', :'user' => :'user', :'env' => :'env', :'labels' => :'labels', :'public' => :'public', :'network_block_all' => :'networkBlockAll', :'network_allow_list' => :'networkAllowList', :'domain_allow_list' => :'domainAllowList', :'outbound_proxy_url' => :'outboundProxyUrl', :'otel_endpoint_override' => :'otelEndpointOverride', :'target' => :'target', :'cpu' => :'cpu', :'gpu' => :'gpu', :'gpu_type' => :'gpuType', :'spot' => :'spot', :'memory' => :'memory', :'disk' => :'disk', :'auto_stop_interval' => :'autoStopInterval', :'auto_pause_interval' => :'autoPauseInterval', :'auto_archive_interval' => :'autoArchiveInterval', :'auto_delete_interval' => :'autoDeleteInterval', :'ttl_minutes' => :'ttlMinutes', :'volumes' => :'volumes', :'build_info' => :'buildInfo', :'linked_sandbox' => :'linkedSandbox', :'secrets' => :'secrets' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 382 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
176 177 178 179 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 176 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 143 def self.openapi_types { :'name' => :'String', :'snapshot' => :'String', :'user' => :'String', :'env' => :'Hash<String, String>', :'labels' => :'Hash<String, String>', :'public' => :'Boolean', :'network_block_all' => :'Boolean', :'network_allow_list' => :'String', :'domain_allow_list' => :'String', :'outbound_proxy_url' => :'String', :'otel_endpoint_override' => :'String', :'target' => :'String', :'cpu' => :'Integer', :'gpu' => :'Integer', :'gpu_type' => :'Array<GpuType>', :'spot' => :'Boolean', :'memory' => :'Integer', :'disk' => :'Integer', :'auto_stop_interval' => :'Integer', :'auto_pause_interval' => :'Integer', :'auto_archive_interval' => :'Integer', :'auto_delete_interval' => :'Integer', :'ttl_minutes' => :'Integer', :'volumes' => :'Array<SandboxVolume>', :'build_info' => :'CreateBuildInfo', :'linked_sandbox' => :'String', :'secrets' => :'Array<Hash<String, String>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 335 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && snapshot == o.snapshot && user == o.user && env == o.env && labels == o.labels && public == o.public && network_block_all == o.network_block_all && network_allow_list == o.network_allow_list && domain_allow_list == o.domain_allow_list && outbound_proxy_url == o.outbound_proxy_url && otel_endpoint_override == o.otel_endpoint_override && target == o.target && cpu == o.cpu && gpu == o.gpu && gpu_type == o.gpu_type && spot == o.spot && memory == o.memory && disk == o.disk && auto_stop_interval == o.auto_stop_interval && auto_pause_interval == o.auto_pause_interval && auto_archive_interval == o.auto_archive_interval && auto_delete_interval == o.auto_delete_interval && ttl_minutes == o.ttl_minutes && volumes == o.volumes && build_info == o.build_info && linked_sandbox == o.linked_sandbox && secrets == o.secrets end |
#eql?(o) ⇒ Boolean
369 370 371 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 369 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
375 376 377 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 375 def hash [name, snapshot, user, env, labels, public, network_block_all, network_allow_list, domain_allow_list, outbound_proxy_url, otel_endpoint_override, target, cpu, gpu, gpu_type, spot, memory, disk, auto_stop_interval, auto_pause_interval, auto_archive_interval, auto_delete_interval, ttl_minutes, volumes, build_info, linked_sandbox, secrets].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
320 321 322 323 324 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 320 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 404 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
328 329 330 331 |
# File 'lib/daytona_api_client/models/create_sandbox.rb', line 328 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |