Class: DaytonaApiClient::CreateSnapshot
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::CreateSnapshot
- Defined in:
- lib/daytona_api_client/models/create_snapshot.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#build_info ⇒ Object
Build information for the snapshot.
-
#cpu ⇒ Object
CPU cores allocated to the resulting sandbox.
-
#disk ⇒ Object
Disk space allocated to the sandbox in GB.
-
#entrypoint ⇒ Object
The entrypoint command for the snapshot.
-
#gpu ⇒ Object
GPU units allocated to the resulting sandbox.
-
#image_name ⇒ Object
The image name of the snapshot.
-
#memory ⇒ Object
Memory allocated to the resulting sandbox in GB.
-
#name ⇒ Object
The name of the snapshot.
-
#region_id ⇒ Object
ID of the region where the snapshot will be available.
-
#sandbox_class ⇒ Object
Target sandbox class.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSnapshot
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateSnapshot
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::CreateSnapshot` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::CreateSnapshot`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'image_name') self.image_name = attributes[:'image_name'] end if attributes.key?(:'entrypoint') if (value = attributes[:'entrypoint']).is_a?(Array) self.entrypoint = value end end if attributes.key?(:'cpu') self.cpu = attributes[:'cpu'] end if attributes.key?(:'gpu') self.gpu = attributes[:'gpu'] end if attributes.key?(:'memory') self.memory = attributes[:'memory'] end if attributes.key?(:'disk') self.disk = attributes[:'disk'] end if attributes.key?(:'build_info') self.build_info = attributes[:'build_info'] end if attributes.key?(:'region_id') self.region_id = attributes[:'region_id'] end if attributes.key?(:'sandbox_class') self.sandbox_class = attributes[:'sandbox_class'] end end |
Instance Attribute Details
#build_info ⇒ Object
Build information for the snapshot
40 41 42 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 40 def build_info @build_info end |
#cpu ⇒ Object
CPU cores allocated to the resulting sandbox
28 29 30 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 28 def cpu @cpu end |
#disk ⇒ Object
Disk space allocated to the sandbox in GB
37 38 39 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 37 def disk @disk end |
#entrypoint ⇒ Object
The entrypoint command for the snapshot
25 26 27 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 25 def entrypoint @entrypoint end |
#gpu ⇒ Object
GPU units allocated to the resulting sandbox
31 32 33 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 31 def gpu @gpu end |
#image_name ⇒ Object
The image name of the snapshot
22 23 24 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 22 def image_name @image_name end |
#memory ⇒ Object
Memory allocated to the resulting sandbox in GB
34 35 36 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 34 def memory @memory end |
#name ⇒ Object
The name of the snapshot
19 20 21 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 19 def name @name end |
#region_id ⇒ Object
ID of the region where the snapshot will be available. Defaults to organization default region if not specified.
43 44 45 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 43 def region_id @region_id end |
#sandbox_class ⇒ Object
Target sandbox class. Determines which runners can host sandboxes created from this snapshot.
46 47 48 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 46 def sandbox_class @sandbox_class end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
87 88 89 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 87 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 92 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 71 def self.attribute_map { :'name' => :'name', :'image_name' => :'imageName', :'entrypoint' => :'entrypoint', :'cpu' => :'cpu', :'gpu' => :'gpu', :'memory' => :'memory', :'disk' => :'disk', :'build_info' => :'buildInfo', :'region_id' => :'regionId', :'sandbox_class' => :'sandboxClass' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 241 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 113 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 97 def self.openapi_types { :'name' => :'String', :'image_name' => :'String', :'entrypoint' => :'Array<String>', :'cpu' => :'Integer', :'gpu' => :'Integer', :'memory' => :'Integer', :'disk' => :'Integer', :'build_info' => :'CreateBuildInfo', :'region_id' => :'String', :'sandbox_class' => :'SandboxClass' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 211 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && image_name == o.image_name && entrypoint == o.entrypoint && cpu == o.cpu && gpu == o.gpu && memory == o.memory && disk == o.disk && build_info == o.build_info && region_id == o.region_id && sandbox_class == o.sandbox_class end |
#eql?(o) ⇒ Boolean
228 229 230 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 228 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
234 235 236 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 234 def hash [name, image_name, entrypoint, cpu, gpu, memory, disk, build_info, region_id, sandbox_class].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
181 182 183 184 185 186 187 188 189 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 181 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 263 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 |
# File 'lib/daytona_api_client/models/create_snapshot.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |