Class: DaytonaApiClient::CreateUser

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/create_user.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateUser

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/daytona_api_client/models/create_user.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::CreateUser` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::CreateUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'personal_organization_quota')
    self.personal_organization_quota = attributes[:'personal_organization_quota']
  end

  if attributes.key?(:'personal_organization_default_region_id')
    self.personal_organization_default_region_id = attributes[:'personal_organization_default_region_id']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'email_verified')
    self.email_verified = attributes[:'email_verified']
  end
end

Instance Attribute Details

#emailObject

Returns the value of attribute email.



22
23
24
# File 'lib/daytona_api_client/models/create_user.rb', line 22

def email
  @email
end

#email_verifiedObject

Returns the value of attribute email_verified.



30
31
32
# File 'lib/daytona_api_client/models/create_user.rb', line 30

def email_verified
  @email_verified
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/daytona_api_client/models/create_user.rb', line 18

def id
  @id
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/daytona_api_client/models/create_user.rb', line 20

def name
  @name
end

#personal_organization_default_region_idObject

Returns the value of attribute personal_organization_default_region_id.



26
27
28
# File 'lib/daytona_api_client/models/create_user.rb', line 26

def personal_organization_default_region_id
  @personal_organization_default_region_id
end

#personal_organization_quotaObject

Returns the value of attribute personal_organization_quota.



24
25
26
# File 'lib/daytona_api_client/models/create_user.rb', line 24

def personal_organization_quota
  @personal_organization_quota
end

#roleObject

Returns the value of attribute role.



28
29
30
# File 'lib/daytona_api_client/models/create_user.rb', line 28

def role
  @role
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/daytona_api_client/models/create_user.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/daytona_api_client/models/create_user.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/daytona_api_client/models/create_user.rb', line 55

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'email' => :'email',
    :'personal_organization_quota' => :'personalOrganizationQuota',
    :'personal_organization_default_region_id' => :'personalOrganizationDefaultRegionId',
    :'role' => :'role',
    :'email_verified' => :'emailVerified'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/daytona_api_client/models/create_user.rb', line 231

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/daytona_api_client/models/create_user.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
# File 'lib/daytona_api_client/models/create_user.rb', line 78

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'email' => :'String',
    :'personal_organization_quota' => :'CreateOrganizationQuota',
    :'personal_organization_default_region_id' => :'String',
    :'role' => :'String',
    :'email_verified' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



204
205
206
207
208
209
210
211
212
213
214
# File 'lib/daytona_api_client/models/create_user.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      email == o.email &&
      personal_organization_quota == o.personal_organization_quota &&
      personal_organization_default_region_id == o.personal_organization_default_region_id &&
      role == o.role &&
      email_verified == o.email_verified
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/daytona_api_client/models/create_user.rb', line 218

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



224
225
226
# File 'lib/daytona_api_client/models/create_user.rb', line 224

def hash
  [id, name, email, personal_organization_quota, personal_organization_default_region_id, role, email_verified].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/daytona_api_client/models/create_user.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/daytona_api_client/models/create_user.rb', line 253

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
167
168
169
170
# File 'lib/daytona_api_client/models/create_user.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  role_validator = EnumAttributeValidator.new('String', ["admin", "user", "unknown_default_open_api"])
  return false unless role_validator.valid?(@role)
  true
end