Class: DaytonaApiClient::IntFilter
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::IntFilter
- Defined in:
- lib/daytona_api_client/models/int_filter.rb
Instance Attribute Summary collapse
-
#_in ⇒ Object
Match values present in this list.
-
#_not ⇒ Object
Match values not equal to this value.
-
#eq ⇒ Object
Match values equal to this value.
-
#gt ⇒ Object
Match values strictly greater than this value.
-
#gte ⇒ Object
Match values greater than or equal to this value.
-
#lt ⇒ Object
Match values strictly less than this value.
-
#lte ⇒ Object
Match values less than or equal to this value.
-
#not_in ⇒ Object
Match values not present in this list.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntFilter
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntFilter
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::IntFilter` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::IntFilter`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'eq') self.eq = attributes[:'eq'] end if attributes.key?(:'_not') self._not = attributes[:'_not'] end if attributes.key?(:'_in') if (value = attributes[:'_in']).is_a?(Array) self._in = value end end if attributes.key?(:'not_in') if (value = attributes[:'not_in']).is_a?(Array) self.not_in = value end end if attributes.key?(:'gte') self.gte = attributes[:'gte'] end if attributes.key?(:'lte') self.lte = attributes[:'lte'] end if attributes.key?(:'gt') self.gt = attributes[:'gt'] end if attributes.key?(:'lt') self.lt = attributes[:'lt'] end end |
Instance Attribute Details
#_in ⇒ Object
Match values present in this list. Accepts comma-separated values or repeated query parameters. Maximum 100 entries.
25 26 27 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 25 def _in @_in end |
#_not ⇒ Object
Match values not equal to this value.
22 23 24 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 22 def _not @_not end |
#eq ⇒ Object
Match values equal to this value.
19 20 21 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 19 def eq @eq end |
#gt ⇒ Object
Match values strictly greater than this value.
37 38 39 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 37 def gt @gt end |
#gte ⇒ Object
Match values greater than or equal to this value.
31 32 33 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 31 def gte @gte end |
#lt ⇒ Object
Match values strictly less than this value.
40 41 42 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 40 def lt @lt end |
#lte ⇒ Object
Match values less than or equal to this value.
34 35 36 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 34 def lte @lte end |
#not_in ⇒ Object
Match values not present in this list. Accepts comma-separated values or repeated query parameters. Maximum 100 entries.
28 29 30 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 28 def not_in @not_in end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 43 def self.attribute_map { :'eq' => :'eq', :'_not' => :'not', :'_in' => :'in', :'not_in' => :'notIn', :'gte' => :'gte', :'lte' => :'lte', :'gt' => :'gt', :'lt' => :'lt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 184 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 67 def self.openapi_types { :'eq' => :'Float', :'_not' => :'Float', :'_in' => :'Array<Float>', :'not_in' => :'Array<Float>', :'gte' => :'Float', :'lte' => :'Float', :'gt' => :'Float', :'lt' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 156 def ==(o) return true if self.equal?(o) self.class == o.class && eq == o.eq && _not == o._not && _in == o._in && not_in == o.not_in && gte == o.gte && lte == o.lte && gt == o.gt && lt == o.lt end |
#eql?(o) ⇒ Boolean
171 172 173 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 171 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 177 def hash [eq, _not, _in, not_in, gte, lte, gt, lt].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 |
# File 'lib/daytona_api_client/models/int_filter.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |