Class: DaytonaApiClient::JobsApi
- Inherits:
-
Object
- Object
- DaytonaApiClient::JobsApi
- Defined in:
- lib/daytona_api_client/api/jobs_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_job(job_id, opts = {}) ⇒ Job
Get job details.
-
#get_job_with_http_info(job_id, opts = {}) ⇒ Array<(Job, Integer, Hash)>
Get job details.
-
#initialize(api_client = ApiClient.default) ⇒ JobsApi
constructor
A new instance of JobsApi.
-
#list_jobs(opts = {}) ⇒ PaginatedJobs
List jobs for the runner Returns a paginated list of jobs for the runner, optionally filtered by status.
-
#list_jobs_with_http_info(opts = {}) ⇒ Array<(PaginatedJobs, Integer, Hash)>
List jobs for the runner Returns a paginated list of jobs for the runner, optionally filtered by status.
-
#poll_jobs(opts = {}) ⇒ PollJobsResponse
Long poll for jobs Long poll endpoint for runners to fetch pending jobs.
-
#poll_jobs_with_http_info(opts = {}) ⇒ Array<(PollJobsResponse, Integer, Hash)>
Long poll for jobs Long poll endpoint for runners to fetch pending jobs.
-
#update_job_status(job_id, update_job_status, opts = {}) ⇒ Job
Update job status.
-
#update_job_status_with_http_info(job_id, update_job_status, opts = {}) ⇒ Array<(Job, Integer, Hash)>
Update job status.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/daytona_api_client/api/jobs_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_job(job_id, opts = {}) ⇒ Job
Get job details
26 27 28 29 |
# File 'lib/daytona_api_client/api/jobs_api.rb', line 26 def get_job(job_id, opts = {}) data, _status_code, _headers = get_job_with_http_info(job_id, opts) data end |
#get_job_with_http_info(job_id, opts = {}) ⇒ Array<(Job, Integer, Hash)>
Get job details
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/daytona_api_client/api/jobs_api.rb', line 35 def get_job_with_http_info(job_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobsApi.get_job ...' end # verify the required parameter 'job_id' is set if @api_client.config.client_side_validation && job_id.nil? fail ArgumentError, "Missing the required parameter 'job_id' when calling JobsApi.get_job" end # resource path local_var_path = '/jobs/{jobId}'.sub('{' + 'jobId' + '}', CGI.escape(job_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Job' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"JobsApi.get_job", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobsApi#get_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_jobs(opts = {}) ⇒ PaginatedJobs
List jobs for the runner Returns a paginated list of jobs for the runner, optionally filtered by status.
91 92 93 94 |
# File 'lib/daytona_api_client/api/jobs_api.rb', line 91 def list_jobs(opts = {}) data, _status_code, _headers = list_jobs_with_http_info(opts) data end |
#list_jobs_with_http_info(opts = {}) ⇒ Array<(PaginatedJobs, Integer, Hash)>
List jobs for the runner Returns a paginated list of jobs for the runner, optionally filtered by status.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/daytona_api_client/api/jobs_api.rb', line 104 def list_jobs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobsApi.list_jobs ...' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling JobsApi.list_jobs, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 200 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling JobsApi.list_jobs, must be smaller than or equal to 200.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling JobsApi.list_jobs, must be greater than or equal to 1.' end # resource path local_var_path = '/jobs' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedJobs' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"JobsApi.list_jobs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobsApi#list_jobs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#poll_jobs(opts = {}) ⇒ PollJobsResponse
Long poll for jobs Long poll endpoint for runners to fetch pending jobs. Returns immediately if jobs are available, otherwise waits up to timeout seconds.
170 171 172 173 |
# File 'lib/daytona_api_client/api/jobs_api.rb', line 170 def poll_jobs(opts = {}) data, _status_code, _headers = poll_jobs_with_http_info(opts) data end |
#poll_jobs_with_http_info(opts = {}) ⇒ Array<(PollJobsResponse, Integer, Hash)>
Long poll for jobs Long poll endpoint for runners to fetch pending jobs. Returns immediately if jobs are available, otherwise waits up to timeout seconds.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/daytona_api_client/api/jobs_api.rb', line 181 def poll_jobs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobsApi.poll_jobs ...' end # resource path local_var_path = '/jobs/poll' # query parameters query_params = opts[:query_params] || {} query_params[:'timeout'] = opts[:'timeout'] if !opts[:'timeout'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PollJobsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"JobsApi.poll_jobs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobsApi#poll_jobs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_job_status(job_id, update_job_status, opts = {}) ⇒ Job
Update job status
232 233 234 235 |
# File 'lib/daytona_api_client/api/jobs_api.rb', line 232 def update_job_status(job_id, update_job_status, opts = {}) data, _status_code, _headers = update_job_status_with_http_info(job_id, update_job_status, opts) data end |
#update_job_status_with_http_info(job_id, update_job_status, opts = {}) ⇒ Array<(Job, Integer, Hash)>
Update job status
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/daytona_api_client/api/jobs_api.rb', line 242 def update_job_status_with_http_info(job_id, update_job_status, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobsApi.update_job_status ...' end # verify the required parameter 'job_id' is set if @api_client.config.client_side_validation && job_id.nil? fail ArgumentError, "Missing the required parameter 'job_id' when calling JobsApi.update_job_status" end # verify the required parameter 'update_job_status' is set if @api_client.config.client_side_validation && update_job_status.nil? fail ArgumentError, "Missing the required parameter 'update_job_status' when calling JobsApi.update_job_status" end # resource path local_var_path = '/jobs/{jobId}/status'.sub('{' + 'jobId' + '}', CGI.escape(job_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_job_status) # return_type return_type = opts[:debug_return_type] || 'Job' # auth_names auth_names = opts[:debug_auth_names] || ['bearer', 'oauth2'] = opts.merge( :operation => :"JobsApi.update_job_status", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobsApi#update_job_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |