Class: DaytonaApiClient::LogEntry

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/log_entry.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LogEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/daytona_api_client/models/log_entry.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::LogEntry` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::LogEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  else
    self.timestamp = nil
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  else
    self.body = nil
  end

  if attributes.key?(:'severity_text')
    self.severity_text = attributes[:'severity_text']
  else
    self.severity_text = nil
  end

  if attributes.key?(:'severity_number')
    self.severity_number = attributes[:'severity_number']
  end

  if attributes.key?(:'service_name')
    self.service_name = attributes[:'service_name']
  else
    self.service_name = nil
  end

  if attributes.key?(:'resource_attributes')
    if (value = attributes[:'resource_attributes']).is_a?(Hash)
      self.resource_attributes = value
    end
  else
    self.resource_attributes = nil
  end

  if attributes.key?(:'log_attributes')
    if (value = attributes[:'log_attributes']).is_a?(Hash)
      self.log_attributes = value
    end
  else
    self.log_attributes = nil
  end

  if attributes.key?(:'trace_id')
    self.trace_id = attributes[:'trace_id']
  end

  if attributes.key?(:'span_id')
    self.span_id = attributes[:'span_id']
  end
end

Instance Attribute Details

#bodyObject

Log message body



22
23
24
# File 'lib/daytona_api_client/models/log_entry.rb', line 22

def body
  @body
end

#log_attributesObject

Log-specific attributes



37
38
39
# File 'lib/daytona_api_client/models/log_entry.rb', line 37

def log_attributes
  @log_attributes
end

#resource_attributesObject

Resource attributes from OTEL



34
35
36
# File 'lib/daytona_api_client/models/log_entry.rb', line 34

def resource_attributes
  @resource_attributes
end

#service_nameObject

Service name that generated the log



31
32
33
# File 'lib/daytona_api_client/models/log_entry.rb', line 31

def service_name
  @service_name
end

#severity_numberObject

Severity level number



28
29
30
# File 'lib/daytona_api_client/models/log_entry.rb', line 28

def severity_number
  @severity_number
end

#severity_textObject

Severity level text (e.g., INFO, WARN, ERROR)



25
26
27
# File 'lib/daytona_api_client/models/log_entry.rb', line 25

def severity_text
  @severity_text
end

#span_idObject

Associated span ID if available



43
44
45
# File 'lib/daytona_api_client/models/log_entry.rb', line 43

def span_id
  @span_id
end

#timestampObject

Timestamp of the log entry



19
20
21
# File 'lib/daytona_api_client/models/log_entry.rb', line 19

def timestamp
  @timestamp
end

#trace_idObject

Associated trace ID if available



40
41
42
# File 'lib/daytona_api_client/models/log_entry.rb', line 40

def trace_id
  @trace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/daytona_api_client/models/log_entry.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/daytona_api_client/models/log_entry.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/daytona_api_client/models/log_entry.rb', line 46

def self.attribute_map
  {
    :'timestamp' => :'timestamp',
    :'body' => :'body',
    :'severity_text' => :'severityText',
    :'severity_number' => :'severityNumber',
    :'service_name' => :'serviceName',
    :'resource_attributes' => :'resourceAttributes',
    :'log_attributes' => :'logAttributes',
    :'trace_id' => :'traceId',
    :'span_id' => :'spanId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/daytona_api_client/models/log_entry.rb', line 296

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/daytona_api_client/models/log_entry.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/daytona_api_client/models/log_entry.rb', line 71

def self.openapi_types
  {
    :'timestamp' => :'String',
    :'body' => :'String',
    :'severity_text' => :'String',
    :'severity_number' => :'Float',
    :'service_name' => :'String',
    :'resource_attributes' => :'Hash<String, String>',
    :'log_attributes' => :'Hash<String, String>',
    :'trace_id' => :'String',
    :'span_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/daytona_api_client/models/log_entry.rb', line 267

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      timestamp == o.timestamp &&
      body == o.body &&
      severity_text == o.severity_text &&
      severity_number == o.severity_number &&
      service_name == o.service_name &&
      resource_attributes == o.resource_attributes &&
      log_attributes == o.log_attributes &&
      trace_id == o.trace_id &&
      span_id == o.span_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


283
284
285
# File 'lib/daytona_api_client/models/log_entry.rb', line 283

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



289
290
291
# File 'lib/daytona_api_client/models/log_entry.rb', line 289

def hash
  [timestamp, body, severity_text, severity_number, service_name, resource_attributes, log_attributes, trace_id, span_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/daytona_api_client/models/log_entry.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @timestamp.nil?
    invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.')
  end

  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  if @severity_text.nil?
    invalid_properties.push('invalid value for "severity_text", severity_text cannot be nil.')
  end

  if @service_name.nil?
    invalid_properties.push('invalid value for "service_name", service_name cannot be nil.')
  end

  if @resource_attributes.nil?
    invalid_properties.push('invalid value for "resource_attributes", resource_attributes cannot be nil.')
  end

  if @log_attributes.nil?
    invalid_properties.push('invalid value for "log_attributes", log_attributes cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/daytona_api_client/models/log_entry.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
200
201
202
203
# File 'lib/daytona_api_client/models/log_entry.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @timestamp.nil?
  return false if @body.nil?
  return false if @severity_text.nil?
  return false if @service_name.nil?
  return false if @resource_attributes.nil?
  return false if @log_attributes.nil?
  true
end