Class: DaytonaApiClient::RegionQuota
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::RegionQuota
- Defined in:
- lib/daytona_api_client/models/region_quota.rb
Instance Attribute Summary collapse
-
#max_cpu_per_sandbox ⇒ Object
Returns the value of attribute max_cpu_per_sandbox.
-
#max_disk_per_non_ephemeral_sandbox ⇒ Object
Returns the value of attribute max_disk_per_non_ephemeral_sandbox.
-
#max_disk_per_sandbox ⇒ Object
Returns the value of attribute max_disk_per_sandbox.
-
#max_memory_per_sandbox ⇒ Object
Returns the value of attribute max_memory_per_sandbox.
-
#organization_id ⇒ Object
Returns the value of attribute organization_id.
-
#region_id ⇒ Object
Returns the value of attribute region_id.
-
#total_cpu_quota ⇒ Object
Returns the value of attribute total_cpu_quota.
-
#total_disk_quota ⇒ Object
Returns the value of attribute total_disk_quota.
-
#total_memory_quota ⇒ Object
Returns the value of attribute total_memory_quota.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RegionQuota
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RegionQuota
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::RegionQuota` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::RegionQuota`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] else self.organization_id = nil end if attributes.key?(:'region_id') self.region_id = attributes[:'region_id'] else self.region_id = nil end if attributes.key?(:'total_cpu_quota') self.total_cpu_quota = attributes[:'total_cpu_quota'] else self.total_cpu_quota = nil end if attributes.key?(:'total_memory_quota') self.total_memory_quota = attributes[:'total_memory_quota'] else self.total_memory_quota = nil end if attributes.key?(:'total_disk_quota') self.total_disk_quota = attributes[:'total_disk_quota'] else self.total_disk_quota = nil end if attributes.key?(:'max_cpu_per_sandbox') self.max_cpu_per_sandbox = attributes[:'max_cpu_per_sandbox'] else self.max_cpu_per_sandbox = nil end if attributes.key?(:'max_memory_per_sandbox') self.max_memory_per_sandbox = attributes[:'max_memory_per_sandbox'] else self.max_memory_per_sandbox = nil end if attributes.key?(:'max_disk_per_sandbox') self.max_disk_per_sandbox = attributes[:'max_disk_per_sandbox'] else self.max_disk_per_sandbox = nil end if attributes.key?(:'max_disk_per_non_ephemeral_sandbox') self.max_disk_per_non_ephemeral_sandbox = attributes[:'max_disk_per_non_ephemeral_sandbox'] else self.max_disk_per_non_ephemeral_sandbox = nil end end |
Instance Attribute Details
#max_cpu_per_sandbox ⇒ Object
Returns the value of attribute max_cpu_per_sandbox.
28 29 30 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 28 def max_cpu_per_sandbox @max_cpu_per_sandbox end |
#max_disk_per_non_ephemeral_sandbox ⇒ Object
Returns the value of attribute max_disk_per_non_ephemeral_sandbox.
34 35 36 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 34 def max_disk_per_non_ephemeral_sandbox @max_disk_per_non_ephemeral_sandbox end |
#max_disk_per_sandbox ⇒ Object
Returns the value of attribute max_disk_per_sandbox.
32 33 34 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 32 def max_disk_per_sandbox @max_disk_per_sandbox end |
#max_memory_per_sandbox ⇒ Object
Returns the value of attribute max_memory_per_sandbox.
30 31 32 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 30 def max_memory_per_sandbox @max_memory_per_sandbox end |
#organization_id ⇒ Object
Returns the value of attribute organization_id.
18 19 20 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 18 def organization_id @organization_id end |
#region_id ⇒ Object
Returns the value of attribute region_id.
20 21 22 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 20 def region_id @region_id end |
#total_cpu_quota ⇒ Object
Returns the value of attribute total_cpu_quota.
22 23 24 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 22 def total_cpu_quota @total_cpu_quota end |
#total_disk_quota ⇒ Object
Returns the value of attribute total_disk_quota.
26 27 28 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 26 def total_disk_quota @total_disk_quota end |
#total_memory_quota ⇒ Object
Returns the value of attribute total_memory_quota.
24 25 26 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 24 def total_memory_quota @total_memory_quota end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 37 def self.attribute_map { :'organization_id' => :'organizationId', :'region_id' => :'regionId', :'total_cpu_quota' => :'totalCpuQuota', :'total_memory_quota' => :'totalMemoryQuota', :'total_disk_quota' => :'totalDiskQuota', :'max_cpu_per_sandbox' => :'maxCpuPerSandbox', :'max_memory_per_sandbox' => :'maxMemoryPerSandbox', :'max_disk_per_sandbox' => :'maxDiskPerSandbox', :'max_disk_per_non_ephemeral_sandbox' => :'maxDiskPerNonEphemeralSandbox' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 278 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 81 82 83 84 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 77 def self.openapi_nullable Set.new([ :'max_cpu_per_sandbox', :'max_memory_per_sandbox', :'max_disk_per_sandbox', :'max_disk_per_non_ephemeral_sandbox' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 62 def self.openapi_types { :'organization_id' => :'String', :'region_id' => :'String', :'total_cpu_quota' => :'Float', :'total_memory_quota' => :'Float', :'total_disk_quota' => :'Float', :'max_cpu_per_sandbox' => :'Float', :'max_memory_per_sandbox' => :'Float', :'max_disk_per_sandbox' => :'Float', :'max_disk_per_non_ephemeral_sandbox' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 249 def ==(o) return true if self.equal?(o) self.class == o.class && organization_id == o.organization_id && region_id == o.region_id && total_cpu_quota == o.total_cpu_quota && total_memory_quota == o.total_memory_quota && total_disk_quota == o.total_disk_quota && max_cpu_per_sandbox == o.max_cpu_per_sandbox && max_memory_per_sandbox == o.max_memory_per_sandbox && max_disk_per_sandbox == o.max_disk_per_sandbox && max_disk_per_non_ephemeral_sandbox == o.max_disk_per_non_ephemeral_sandbox end |
#eql?(o) ⇒ Boolean
265 266 267 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 265 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
271 272 273 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 271 def hash [organization_id, region_id, total_cpu_quota, total_memory_quota, total_disk_quota, max_cpu_per_sandbox, max_memory_per_sandbox, max_disk_per_sandbox, max_disk_per_non_ephemeral_sandbox].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 159 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @organization_id.nil? invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.') end if @region_id.nil? invalid_properties.push('invalid value for "region_id", region_id cannot be nil.') end if @total_cpu_quota.nil? invalid_properties.push('invalid value for "total_cpu_quota", total_cpu_quota cannot be nil.') end if @total_memory_quota.nil? invalid_properties.push('invalid value for "total_memory_quota", total_memory_quota cannot be nil.') end if @total_disk_quota.nil? invalid_properties.push('invalid value for "total_disk_quota", total_disk_quota cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 300 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 190 191 192 193 194 195 |
# File 'lib/daytona_api_client/models/region_quota.rb', line 187 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @organization_id.nil? return false if @region_id.nil? return false if @total_cpu_quota.nil? return false if @total_memory_quota.nil? return false if @total_disk_quota.nil? true end |