Class: DaytonaApiClient::RegionUsageOverview
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaApiClient::RegionUsageOverview
- Defined in:
- lib/daytona_api_client/models/region_usage_overview.rb
Instance Attribute Summary collapse
-
#current_cpu_usage ⇒ Object
Returns the value of attribute current_cpu_usage.
-
#current_disk_usage ⇒ Object
Returns the value of attribute current_disk_usage.
-
#current_gpu_usage ⇒ Object
Returns the value of attribute current_gpu_usage.
-
#current_memory_usage ⇒ Object
Returns the value of attribute current_memory_usage.
-
#max_cpu_per_gpu_sandbox ⇒ Object
Returns the value of attribute max_cpu_per_gpu_sandbox.
-
#max_cpu_per_sandbox ⇒ Object
Returns the value of attribute max_cpu_per_sandbox.
-
#max_disk_per_gpu_sandbox ⇒ Object
Returns the value of attribute max_disk_per_gpu_sandbox.
-
#max_disk_per_non_ephemeral_sandbox ⇒ Object
Returns the value of attribute max_disk_per_non_ephemeral_sandbox.
-
#max_disk_per_sandbox ⇒ Object
Returns the value of attribute max_disk_per_sandbox.
-
#max_memory_per_gpu_sandbox ⇒ Object
Returns the value of attribute max_memory_per_gpu_sandbox.
-
#max_memory_per_sandbox ⇒ Object
Returns the value of attribute max_memory_per_sandbox.
-
#region_id ⇒ Object
Returns the value of attribute region_id.
-
#total_cpu_quota ⇒ Object
Returns the value of attribute total_cpu_quota.
-
#total_disk_quota ⇒ Object
Returns the value of attribute total_disk_quota.
-
#total_gpu_quota ⇒ Object
Returns the value of attribute total_gpu_quota.
-
#total_memory_quota ⇒ Object
Returns the value of attribute total_memory_quota.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RegionUsageOverview
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RegionUsageOverview
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 119 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::RegionUsageOverview` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::RegionUsageOverview`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'region_id') self.region_id = attributes[:'region_id'] else self.region_id = nil end if attributes.key?(:'total_cpu_quota') self.total_cpu_quota = attributes[:'total_cpu_quota'] else self.total_cpu_quota = nil end if attributes.key?(:'current_cpu_usage') self.current_cpu_usage = attributes[:'current_cpu_usage'] else self.current_cpu_usage = nil end if attributes.key?(:'total_memory_quota') self.total_memory_quota = attributes[:'total_memory_quota'] else self.total_memory_quota = nil end if attributes.key?(:'current_memory_usage') self.current_memory_usage = attributes[:'current_memory_usage'] else self.current_memory_usage = nil end if attributes.key?(:'total_disk_quota') self.total_disk_quota = attributes[:'total_disk_quota'] else self.total_disk_quota = nil end if attributes.key?(:'current_disk_usage') self.current_disk_usage = attributes[:'current_disk_usage'] else self.current_disk_usage = nil end if attributes.key?(:'total_gpu_quota') self.total_gpu_quota = attributes[:'total_gpu_quota'] else self.total_gpu_quota = nil end if attributes.key?(:'current_gpu_usage') self.current_gpu_usage = attributes[:'current_gpu_usage'] else self.current_gpu_usage = nil end if attributes.key?(:'max_cpu_per_sandbox') self.max_cpu_per_sandbox = attributes[:'max_cpu_per_sandbox'] else self.max_cpu_per_sandbox = nil end if attributes.key?(:'max_memory_per_sandbox') self.max_memory_per_sandbox = attributes[:'max_memory_per_sandbox'] else self.max_memory_per_sandbox = nil end if attributes.key?(:'max_disk_per_sandbox') self.max_disk_per_sandbox = attributes[:'max_disk_per_sandbox'] else self.max_disk_per_sandbox = nil end if attributes.key?(:'max_disk_per_non_ephemeral_sandbox') self.max_disk_per_non_ephemeral_sandbox = attributes[:'max_disk_per_non_ephemeral_sandbox'] else self.max_disk_per_non_ephemeral_sandbox = nil end if attributes.key?(:'max_cpu_per_gpu_sandbox') self.max_cpu_per_gpu_sandbox = attributes[:'max_cpu_per_gpu_sandbox'] else self.max_cpu_per_gpu_sandbox = nil end if attributes.key?(:'max_memory_per_gpu_sandbox') self.max_memory_per_gpu_sandbox = attributes[:'max_memory_per_gpu_sandbox'] else self.max_memory_per_gpu_sandbox = nil end if attributes.key?(:'max_disk_per_gpu_sandbox') self.max_disk_per_gpu_sandbox = attributes[:'max_disk_per_gpu_sandbox'] else self.max_disk_per_gpu_sandbox = nil end end |
Instance Attribute Details
#current_cpu_usage ⇒ Object
Returns the value of attribute current_cpu_usage.
22 23 24 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 22 def current_cpu_usage @current_cpu_usage end |
#current_disk_usage ⇒ Object
Returns the value of attribute current_disk_usage.
30 31 32 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 30 def current_disk_usage @current_disk_usage end |
#current_gpu_usage ⇒ Object
Returns the value of attribute current_gpu_usage.
34 35 36 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 34 def current_gpu_usage @current_gpu_usage end |
#current_memory_usage ⇒ Object
Returns the value of attribute current_memory_usage.
26 27 28 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 26 def current_memory_usage @current_memory_usage end |
#max_cpu_per_gpu_sandbox ⇒ Object
Returns the value of attribute max_cpu_per_gpu_sandbox.
44 45 46 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 44 def max_cpu_per_gpu_sandbox @max_cpu_per_gpu_sandbox end |
#max_cpu_per_sandbox ⇒ Object
Returns the value of attribute max_cpu_per_sandbox.
36 37 38 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 36 def max_cpu_per_sandbox @max_cpu_per_sandbox end |
#max_disk_per_gpu_sandbox ⇒ Object
Returns the value of attribute max_disk_per_gpu_sandbox.
48 49 50 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 48 def max_disk_per_gpu_sandbox @max_disk_per_gpu_sandbox end |
#max_disk_per_non_ephemeral_sandbox ⇒ Object
Returns the value of attribute max_disk_per_non_ephemeral_sandbox.
42 43 44 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 42 def max_disk_per_non_ephemeral_sandbox @max_disk_per_non_ephemeral_sandbox end |
#max_disk_per_sandbox ⇒ Object
Returns the value of attribute max_disk_per_sandbox.
40 41 42 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 40 def max_disk_per_sandbox @max_disk_per_sandbox end |
#max_memory_per_gpu_sandbox ⇒ Object
Returns the value of attribute max_memory_per_gpu_sandbox.
46 47 48 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 46 def max_memory_per_gpu_sandbox @max_memory_per_gpu_sandbox end |
#max_memory_per_sandbox ⇒ Object
Returns the value of attribute max_memory_per_sandbox.
38 39 40 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 38 def max_memory_per_sandbox @max_memory_per_sandbox end |
#region_id ⇒ Object
Returns the value of attribute region_id.
18 19 20 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 18 def region_id @region_id end |
#total_cpu_quota ⇒ Object
Returns the value of attribute total_cpu_quota.
20 21 22 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 20 def total_cpu_quota @total_cpu_quota end |
#total_disk_quota ⇒ Object
Returns the value of attribute total_disk_quota.
28 29 30 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 28 def total_disk_quota @total_disk_quota end |
#total_gpu_quota ⇒ Object
Returns the value of attribute total_gpu_quota.
32 33 34 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 32 def total_gpu_quota @total_gpu_quota end |
#total_memory_quota ⇒ Object
Returns the value of attribute total_memory_quota.
24 25 26 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 24 def total_memory_quota @total_memory_quota end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 51 def self.attribute_map { :'region_id' => :'regionId', :'total_cpu_quota' => :'totalCpuQuota', :'current_cpu_usage' => :'currentCpuUsage', :'total_memory_quota' => :'totalMemoryQuota', :'current_memory_usage' => :'currentMemoryUsage', :'total_disk_quota' => :'totalDiskQuota', :'current_disk_usage' => :'currentDiskUsage', :'total_gpu_quota' => :'totalGpuQuota', :'current_gpu_usage' => :'currentGpuUsage', :'max_cpu_per_sandbox' => :'maxCpuPerSandbox', :'max_memory_per_sandbox' => :'maxMemoryPerSandbox', :'max_disk_per_sandbox' => :'maxDiskPerSandbox', :'max_disk_per_non_ephemeral_sandbox' => :'maxDiskPerNonEphemeralSandbox', :'max_cpu_per_gpu_sandbox' => :'maxCpuPerGpuSandbox', :'max_memory_per_gpu_sandbox' => :'maxMemoryPerGpuSandbox', :'max_disk_per_gpu_sandbox' => :'maxDiskPerGpuSandbox' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 418 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 105 def self.openapi_nullable Set.new([ :'max_cpu_per_sandbox', :'max_memory_per_sandbox', :'max_disk_per_sandbox', :'max_disk_per_non_ephemeral_sandbox', :'max_cpu_per_gpu_sandbox', :'max_memory_per_gpu_sandbox', :'max_disk_per_gpu_sandbox' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 83 def self.openapi_types { :'region_id' => :'String', :'total_cpu_quota' => :'Float', :'current_cpu_usage' => :'Float', :'total_memory_quota' => :'Float', :'current_memory_usage' => :'Float', :'total_disk_quota' => :'Float', :'current_disk_usage' => :'Float', :'total_gpu_quota' => :'Float', :'current_gpu_usage' => :'Float', :'max_cpu_per_sandbox' => :'Float', :'max_memory_per_sandbox' => :'Float', :'max_disk_per_sandbox' => :'Float', :'max_disk_per_non_ephemeral_sandbox' => :'Float', :'max_cpu_per_gpu_sandbox' => :'Float', :'max_memory_per_gpu_sandbox' => :'Float', :'max_disk_per_gpu_sandbox' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 382 def ==(o) return true if self.equal?(o) self.class == o.class && region_id == o.region_id && total_cpu_quota == o.total_cpu_quota && current_cpu_usage == o.current_cpu_usage && total_memory_quota == o.total_memory_quota && current_memory_usage == o.current_memory_usage && total_disk_quota == o.total_disk_quota && current_disk_usage == o.current_disk_usage && total_gpu_quota == o.total_gpu_quota && current_gpu_usage == o.current_gpu_usage && max_cpu_per_sandbox == o.max_cpu_per_sandbox && max_memory_per_sandbox == o.max_memory_per_sandbox && max_disk_per_sandbox == o.max_disk_per_sandbox && max_disk_per_non_ephemeral_sandbox == o.max_disk_per_non_ephemeral_sandbox && max_cpu_per_gpu_sandbox == o.max_cpu_per_gpu_sandbox && max_memory_per_gpu_sandbox == o.max_memory_per_gpu_sandbox && max_disk_per_gpu_sandbox == o.max_disk_per_gpu_sandbox end |
#eql?(o) ⇒ Boolean
405 406 407 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 405 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
411 412 413 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 411 def hash [region_id, total_cpu_quota, current_cpu_usage, total_memory_quota, current_memory_usage, total_disk_quota, current_disk_usage, total_gpu_quota, current_gpu_usage, max_cpu_per_sandbox, max_memory_per_sandbox, max_disk_per_sandbox, max_disk_per_non_ephemeral_sandbox, max_cpu_per_gpu_sandbox, max_memory_per_gpu_sandbox, max_disk_per_gpu_sandbox].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 232 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @region_id.nil? invalid_properties.push('invalid value for "region_id", region_id cannot be nil.') end if @total_cpu_quota.nil? invalid_properties.push('invalid value for "total_cpu_quota", total_cpu_quota cannot be nil.') end if @current_cpu_usage.nil? invalid_properties.push('invalid value for "current_cpu_usage", current_cpu_usage cannot be nil.') end if @total_memory_quota.nil? invalid_properties.push('invalid value for "total_memory_quota", total_memory_quota cannot be nil.') end if @current_memory_usage.nil? invalid_properties.push('invalid value for "current_memory_usage", current_memory_usage cannot be nil.') end if @total_disk_quota.nil? invalid_properties.push('invalid value for "total_disk_quota", total_disk_quota cannot be nil.') end if @current_disk_usage.nil? invalid_properties.push('invalid value for "current_disk_usage", current_disk_usage cannot be nil.') end if @total_gpu_quota.nil? invalid_properties.push('invalid value for "total_gpu_quota", total_gpu_quota cannot be nil.') end if @current_gpu_usage.nil? invalid_properties.push('invalid value for "current_gpu_usage", current_gpu_usage cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 440 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 276 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @region_id.nil? return false if @total_cpu_quota.nil? return false if @current_cpu_usage.nil? return false if @total_memory_quota.nil? return false if @current_memory_usage.nil? return false if @total_disk_quota.nil? return false if @current_disk_usage.nil? return false if @total_gpu_quota.nil? return false if @current_gpu_usage.nil? true end |