Class: DaytonaApiClient::RegionUsageOverview
- Inherits:
-
Object
- Object
- DaytonaApiClient::RegionUsageOverview
- Defined in:
- lib/daytona_api_client/models/region_usage_overview.rb
Instance Attribute Summary collapse
-
#current_cpu_usage ⇒ Object
Returns the value of attribute current_cpu_usage.
-
#current_disk_usage ⇒ Object
Returns the value of attribute current_disk_usage.
-
#current_memory_usage ⇒ Object
Returns the value of attribute current_memory_usage.
-
#region_id ⇒ Object
Returns the value of attribute region_id.
-
#total_cpu_quota ⇒ Object
Returns the value of attribute total_cpu_quota.
-
#total_disk_quota ⇒ Object
Returns the value of attribute total_disk_quota.
-
#total_memory_quota ⇒ Object
Returns the value of attribute total_memory_quota.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RegionUsageOverview
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RegionUsageOverview
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::RegionUsageOverview` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::RegionUsageOverview`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'region_id') self.region_id = attributes[:'region_id'] else self.region_id = nil end if attributes.key?(:'total_cpu_quota') self.total_cpu_quota = attributes[:'total_cpu_quota'] else self.total_cpu_quota = nil end if attributes.key?(:'current_cpu_usage') self.current_cpu_usage = attributes[:'current_cpu_usage'] else self.current_cpu_usage = nil end if attributes.key?(:'total_memory_quota') self.total_memory_quota = attributes[:'total_memory_quota'] else self.total_memory_quota = nil end if attributes.key?(:'current_memory_usage') self.current_memory_usage = attributes[:'current_memory_usage'] else self.current_memory_usage = nil end if attributes.key?(:'total_disk_quota') self.total_disk_quota = attributes[:'total_disk_quota'] else self.total_disk_quota = nil end if attributes.key?(:'current_disk_usage') self.current_disk_usage = attributes[:'current_disk_usage'] else self.current_disk_usage = nil end end |
Instance Attribute Details
#current_cpu_usage ⇒ Object
Returns the value of attribute current_cpu_usage.
22 23 24 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 22 def current_cpu_usage @current_cpu_usage end |
#current_disk_usage ⇒ Object
Returns the value of attribute current_disk_usage.
30 31 32 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 30 def current_disk_usage @current_disk_usage end |
#current_memory_usage ⇒ Object
Returns the value of attribute current_memory_usage.
26 27 28 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 26 def current_memory_usage @current_memory_usage end |
#region_id ⇒ Object
Returns the value of attribute region_id.
18 19 20 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 18 def region_id @region_id end |
#total_cpu_quota ⇒ Object
Returns the value of attribute total_cpu_quota.
20 21 22 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 20 def total_cpu_quota @total_cpu_quota end |
#total_disk_quota ⇒ Object
Returns the value of attribute total_disk_quota.
28 29 30 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 28 def total_disk_quota @total_disk_quota end |
#total_memory_quota ⇒ Object
Returns the value of attribute total_memory_quota.
24 25 26 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 24 def total_memory_quota @total_memory_quota end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 306 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = DaytonaApiClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 33 def self.attribute_map { :'region_id' => :'regionId', :'total_cpu_quota' => :'totalCpuQuota', :'current_cpu_usage' => :'currentCpuUsage', :'total_memory_quota' => :'totalMemoryQuota', :'current_memory_usage' => :'currentMemoryUsage', :'total_disk_quota' => :'totalDiskQuota', :'current_disk_usage' => :'currentDiskUsage' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 282 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 56 def self.openapi_types { :'region_id' => :'String', :'total_cpu_quota' => :'Float', :'current_cpu_usage' => :'Float', :'total_memory_quota' => :'Float', :'current_memory_usage' => :'Float', :'total_disk_quota' => :'Float', :'current_disk_usage' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 255 def ==(o) return true if self.equal?(o) self.class == o.class && region_id == o.region_id && total_cpu_quota == o.total_cpu_quota && current_cpu_usage == o.current_cpu_usage && total_memory_quota == o.total_memory_quota && current_memory_usage == o.current_memory_usage && total_disk_quota == o.total_disk_quota && current_disk_usage == o.current_disk_usage end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 377 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
269 270 271 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 269 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
275 276 277 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 275 def hash [region_id, total_cpu_quota, current_cpu_usage, total_memory_quota, current_memory_usage, total_disk_quota, current_disk_usage].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @region_id.nil? invalid_properties.push('invalid value for "region_id", region_id cannot be nil.') end if @total_cpu_quota.nil? invalid_properties.push('invalid value for "total_cpu_quota", total_cpu_quota cannot be nil.') end if @current_cpu_usage.nil? invalid_properties.push('invalid value for "current_cpu_usage", current_cpu_usage cannot be nil.') end if @total_memory_quota.nil? invalid_properties.push('invalid value for "total_memory_quota", total_memory_quota cannot be nil.') end if @current_memory_usage.nil? invalid_properties.push('invalid value for "current_memory_usage", current_memory_usage cannot be nil.') end if @total_disk_quota.nil? invalid_properties.push('invalid value for "total_disk_quota", total_disk_quota cannot be nil.') end if @current_disk_usage.nil? invalid_properties.push('invalid value for "current_disk_usage", current_disk_usage cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
353 354 355 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 353 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 359 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
347 348 349 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 347 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/daytona_api_client/models/region_usage_overview.rb', line 171 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @region_id.nil? return false if @total_cpu_quota.nil? return false if @current_cpu_usage.nil? return false if @total_memory_quota.nil? return false if @current_memory_usage.nil? return false if @total_disk_quota.nil? return false if @current_disk_usage.nil? true end |