Class: DaytonaApiClient::RunnerHealthMetrics

Inherits:
Object
  • Object
show all
Defined in:
lib/daytona_api_client/models/runner_health_metrics.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RunnerHealthMetrics

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::RunnerHealthMetrics` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::RunnerHealthMetrics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'current_cpu_load_average')
    self.current_cpu_load_average = attributes[:'current_cpu_load_average']
  else
    self.current_cpu_load_average = nil
  end

  if attributes.key?(:'current_cpu_usage_percentage')
    self.current_cpu_usage_percentage = attributes[:'current_cpu_usage_percentage']
  else
    self.current_cpu_usage_percentage = nil
  end

  if attributes.key?(:'current_memory_usage_percentage')
    self.current_memory_usage_percentage = attributes[:'current_memory_usage_percentage']
  else
    self.current_memory_usage_percentage = nil
  end

  if attributes.key?(:'current_disk_usage_percentage')
    self.current_disk_usage_percentage = attributes[:'current_disk_usage_percentage']
  else
    self.current_disk_usage_percentage = nil
  end

  if attributes.key?(:'current_allocated_cpu')
    self.current_allocated_cpu = attributes[:'current_allocated_cpu']
  else
    self.current_allocated_cpu = nil
  end

  if attributes.key?(:'current_allocated_memory_gi_b')
    self.current_allocated_memory_gi_b = attributes[:'current_allocated_memory_gi_b']
  else
    self.current_allocated_memory_gi_b = nil
  end

  if attributes.key?(:'current_allocated_disk_gi_b')
    self.current_allocated_disk_gi_b = attributes[:'current_allocated_disk_gi_b']
  else
    self.current_allocated_disk_gi_b = nil
  end

  if attributes.key?(:'current_snapshot_count')
    self.current_snapshot_count = attributes[:'current_snapshot_count']
  else
    self.current_snapshot_count = nil
  end

  if attributes.key?(:'current_started_sandboxes')
    self.current_started_sandboxes = attributes[:'current_started_sandboxes']
  else
    self.current_started_sandboxes = nil
  end

  if attributes.key?(:'cpu')
    self.cpu = attributes[:'cpu']
  else
    self.cpu = nil
  end

  if attributes.key?(:'memory_gi_b')
    self.memory_gi_b = attributes[:'memory_gi_b']
  else
    self.memory_gi_b = nil
  end

  if attributes.key?(:'disk_gi_b')
    self.disk_gi_b = attributes[:'disk_gi_b']
  else
    self.disk_gi_b = nil
  end
end

Instance Attribute Details

#cpuObject

Total CPU cores on the runner



46
47
48
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 46

def cpu
  @cpu
end

#current_allocated_cpuObject

Currently allocated CPU cores



31
32
33
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 31

def current_allocated_cpu
  @current_allocated_cpu
end

#current_allocated_disk_gi_bObject

Currently allocated disk in GiB



37
38
39
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 37

def current_allocated_disk_gi_b
  @current_allocated_disk_gi_b
end

#current_allocated_memory_gi_bObject

Currently allocated memory in GiB



34
35
36
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 34

def current_allocated_memory_gi_b
  @current_allocated_memory_gi_b
end

#current_cpu_load_averageObject

Current CPU load average



19
20
21
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 19

def current_cpu_load_average
  @current_cpu_load_average
end

#current_cpu_usage_percentageObject

Current CPU usage percentage



22
23
24
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 22

def current_cpu_usage_percentage
  @current_cpu_usage_percentage
end

#current_disk_usage_percentageObject

Current disk usage percentage



28
29
30
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 28

def current_disk_usage_percentage
  @current_disk_usage_percentage
end

#current_memory_usage_percentageObject

Current memory usage percentage



25
26
27
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 25

def current_memory_usage_percentage
  @current_memory_usage_percentage
end

#current_snapshot_countObject

Number of snapshots currently stored



40
41
42
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 40

def current_snapshot_count
  @current_snapshot_count
end

#current_started_sandboxesObject

Number of started sandboxes



43
44
45
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 43

def current_started_sandboxes
  @current_started_sandboxes
end

#disk_gi_bObject

Total disk space in GiB on the runner



52
53
54
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 52

def disk_gi_b
  @disk_gi_b
end

#memory_gi_bObject

Total RAM in GiB on the runner



49
50
51
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 49

def memory_gi_b
  @memory_gi_b
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 448

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = DaytonaApiClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 55

def self.attribute_map
  {
    :'current_cpu_load_average' => :'currentCpuLoadAverage',
    :'current_cpu_usage_percentage' => :'currentCpuUsagePercentage',
    :'current_memory_usage_percentage' => :'currentMemoryUsagePercentage',
    :'current_disk_usage_percentage' => :'currentDiskUsagePercentage',
    :'current_allocated_cpu' => :'currentAllocatedCpu',
    :'current_allocated_memory_gi_b' => :'currentAllocatedMemoryGiB',
    :'current_allocated_disk_gi_b' => :'currentAllocatedDiskGiB',
    :'current_snapshot_count' => :'currentSnapshotCount',
    :'current_started_sandboxes' => :'currentStartedSandboxes',
    :'cpu' => :'cpu',
    :'memory_gi_b' => :'memoryGiB',
    :'disk_gi_b' => :'diskGiB'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 424

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 83

def self.openapi_types
  {
    :'current_cpu_load_average' => :'Float',
    :'current_cpu_usage_percentage' => :'Float',
    :'current_memory_usage_percentage' => :'Float',
    :'current_disk_usage_percentage' => :'Float',
    :'current_allocated_cpu' => :'Float',
    :'current_allocated_memory_gi_b' => :'Float',
    :'current_allocated_disk_gi_b' => :'Float',
    :'current_snapshot_count' => :'Float',
    :'current_started_sandboxes' => :'Float',
    :'cpu' => :'Float',
    :'memory_gi_b' => :'Float',
    :'disk_gi_b' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 392

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      current_cpu_load_average == o.current_cpu_load_average &&
      current_cpu_usage_percentage == o.current_cpu_usage_percentage &&
      current_memory_usage_percentage == o.current_memory_usage_percentage &&
      current_disk_usage_percentage == o.current_disk_usage_percentage &&
      current_allocated_cpu == o.current_allocated_cpu &&
      current_allocated_memory_gi_b == o.current_allocated_memory_gi_b &&
      current_allocated_disk_gi_b == o.current_allocated_disk_gi_b &&
      current_snapshot_count == o.current_snapshot_count &&
      current_started_sandboxes == o.current_started_sandboxes &&
      cpu == o.cpu &&
      memory_gi_b == o.memory_gi_b &&
      disk_gi_b == o.disk_gi_b
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 519

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


411
412
413
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 411

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



417
418
419
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 417

def hash
  [current_cpu_load_average, current_cpu_usage_percentage, current_memory_usage_percentage, current_disk_usage_percentage, current_allocated_cpu, current_allocated_memory_gi_b, current_allocated_disk_gi_b, current_snapshot_count, current_started_sandboxes, cpu, memory_gi_b, disk_gi_b].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 197

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @current_cpu_load_average.nil?
    invalid_properties.push('invalid value for "current_cpu_load_average", current_cpu_load_average cannot be nil.')
  end

  if @current_cpu_usage_percentage.nil?
    invalid_properties.push('invalid value for "current_cpu_usage_percentage", current_cpu_usage_percentage cannot be nil.')
  end

  if @current_memory_usage_percentage.nil?
    invalid_properties.push('invalid value for "current_memory_usage_percentage", current_memory_usage_percentage cannot be nil.')
  end

  if @current_disk_usage_percentage.nil?
    invalid_properties.push('invalid value for "current_disk_usage_percentage", current_disk_usage_percentage cannot be nil.')
  end

  if @current_allocated_cpu.nil?
    invalid_properties.push('invalid value for "current_allocated_cpu", current_allocated_cpu cannot be nil.')
  end

  if @current_allocated_memory_gi_b.nil?
    invalid_properties.push('invalid value for "current_allocated_memory_gi_b", current_allocated_memory_gi_b cannot be nil.')
  end

  if @current_allocated_disk_gi_b.nil?
    invalid_properties.push('invalid value for "current_allocated_disk_gi_b", current_allocated_disk_gi_b cannot be nil.')
  end

  if @current_snapshot_count.nil?
    invalid_properties.push('invalid value for "current_snapshot_count", current_snapshot_count cannot be nil.')
  end

  if @current_started_sandboxes.nil?
    invalid_properties.push('invalid value for "current_started_sandboxes", current_started_sandboxes cannot be nil.')
  end

  if @cpu.nil?
    invalid_properties.push('invalid value for "cpu", cpu cannot be nil.')
  end

  if @memory_gi_b.nil?
    invalid_properties.push('invalid value for "memory_gi_b", memory_gi_b cannot be nil.')
  end

  if @disk_gi_b.nil?
    invalid_properties.push('invalid value for "disk_gi_b", disk_gi_b cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



495
496
497
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 495

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



501
502
503
504
505
506
507
508
509
510
511
512
513
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 501

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



489
490
491
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 489

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/daytona_api_client/models/runner_health_metrics.rb', line 253

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @current_cpu_load_average.nil?
  return false if @current_cpu_usage_percentage.nil?
  return false if @current_memory_usage_percentage.nil?
  return false if @current_disk_usage_percentage.nil?
  return false if @current_allocated_cpu.nil?
  return false if @current_allocated_memory_gi_b.nil?
  return false if @current_allocated_disk_gi_b.nil?
  return false if @current_snapshot_count.nil?
  return false if @current_started_sandboxes.nil?
  return false if @cpu.nil?
  return false if @memory_gi_b.nil?
  return false if @disk_gi_b.nil?
  true
end