Class: DaytonaApiClient::SandboxListItem

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/sandbox_list_item.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SandboxListItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 205

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::SandboxListItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::SandboxListItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  else
    self.organization_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end

  if attributes.key?(:'runner_id')
    self.runner_id = attributes[:'runner_id']
  end

  if attributes.key?(:'sandbox_class')
    self.sandbox_class = attributes[:'sandbox_class']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'desired_state')
    self.desired_state = attributes[:'desired_state']
  end

  if attributes.key?(:'snapshot')
    self.snapshot = attributes[:'snapshot']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  else
    self.user = nil
  end

  if attributes.key?(:'error_reason')
    self.error_reason = attributes[:'error_reason']
  end

  if attributes.key?(:'recoverable')
    self.recoverable = attributes[:'recoverable']
  end

  if attributes.key?(:'public')
    self.public = attributes[:'public']
  else
    self.public = nil
  end

  if attributes.key?(:'cpu')
    self.cpu = attributes[:'cpu']
  else
    self.cpu = nil
  end

  if attributes.key?(:'gpu')
    self.gpu = attributes[:'gpu']
  else
    self.gpu = nil
  end

  if attributes.key?(:'memory')
    self.memory = attributes[:'memory']
  else
    self.memory = nil
  end

  if attributes.key?(:'disk')
    self.disk = attributes[:'disk']
  else
    self.disk = nil
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Hash)
      self.labels = value
    end
  else
    self.labels = nil
  end

  if attributes.key?(:'backup_state')
    self.backup_state = attributes[:'backup_state']
  end

  if attributes.key?(:'auto_stop_interval')
    self.auto_stop_interval = attributes[:'auto_stop_interval']
  end

  if attributes.key?(:'auto_archive_interval')
    self.auto_archive_interval = attributes[:'auto_archive_interval']
  end

  if attributes.key?(:'auto_delete_interval')
    self.auto_delete_interval = attributes[:'auto_delete_interval']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'last_activity_at')
    self.last_activity_at = attributes[:'last_activity_at']
  end

  if attributes.key?(:'daemon_version')
    self.daemon_version = attributes[:'daemon_version']
  end

  if attributes.key?(:'toolbox_proxy_url')
    self.toolbox_proxy_url = attributes[:'toolbox_proxy_url']
  else
    self.toolbox_proxy_url = nil
  end
end

Instance Attribute Details

#auto_archive_intervalObject

Auto-archive interval in minutes



79
80
81
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 79

def auto_archive_interval
  @auto_archive_interval
end

#auto_delete_intervalObject

Auto-delete interval in minutes (negative value means disabled, 0 means delete immediately upon stopping)



82
83
84
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 82

def auto_delete_interval
  @auto_delete_interval
end

#auto_stop_intervalObject

Auto-stop interval in minutes (0 means disabled)



76
77
78
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 76

def auto_stop_interval
  @auto_stop_interval
end

#backup_stateObject

The state of the backup



73
74
75
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 73

def backup_state
  @backup_state
end

#cpuObject

The CPU quota for the sandbox



58
59
60
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 58

def cpu
  @cpu
end

#created_atObject

The creation timestamp of the sandbox



85
86
87
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 85

def created_at
  @created_at
end

#daemon_versionObject

The version of the daemon running in the sandbox



94
95
96
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 94

def daemon_version
  @daemon_version
end

#desired_stateObject

The desired state of the sandbox



40
41
42
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 40

def desired_state
  @desired_state
end

#diskObject

The disk quota for the sandbox



67
68
69
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 67

def disk
  @disk
end

#error_reasonObject

The error reason of the sandbox



49
50
51
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 49

def error_reason
  @error_reason
end

#gpuObject

The GPU quota for the sandbox



61
62
63
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 61

def gpu
  @gpu
end

#idObject

The ID of the sandbox



19
20
21
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 19

def id
  @id
end

#labelsObject

Labels for the sandbox



70
71
72
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 70

def labels
  @labels
end

#last_activity_atObject

The last activity timestamp of the sandbox



91
92
93
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 91

def last_activity_at
  @last_activity_at
end

#memoryObject

The memory quota for the sandbox



64
65
66
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 64

def memory
  @memory
end

#nameObject

The name of the sandbox



25
26
27
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 25

def name
  @name
end

#organization_idObject

The organization ID of the sandbox



22
23
24
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 22

def organization_id
  @organization_id
end

#publicObject

Whether the sandbox http preview is public



55
56
57
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 55

def public
  @public
end

#recoverableObject

Whether the sandbox error is recoverable.



52
53
54
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 52

def recoverable
  @recoverable
end

#runner_idObject

The runner ID of the sandbox



31
32
33
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 31

def runner_id
  @runner_id
end

#sandbox_classObject

The class of the sandbox



34
35
36
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 34

def sandbox_class
  @sandbox_class
end

#snapshotObject

The snapshot used for the sandbox



43
44
45
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 43

def snapshot
  @snapshot
end

#stateObject

The state of the sandbox



37
38
39
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 37

def state
  @state
end

#targetObject

The target environment for the sandbox



28
29
30
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 28

def target
  @target
end

#toolbox_proxy_urlObject

The toolbox proxy URL for the sandbox



97
98
99
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 97

def toolbox_proxy_url
  @toolbox_proxy_url
end

#updated_atObject

The last update timestamp of the sandbox



88
89
90
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 88

def updated_at
  @updated_at
end

#userObject

The user associated with the project



46
47
48
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 46

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



155
156
157
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 155

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



160
161
162
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 160

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 122

def self.attribute_map
  {
    :'id' => :'id',
    :'organization_id' => :'organizationId',
    :'name' => :'name',
    :'target' => :'target',
    :'runner_id' => :'runnerId',
    :'sandbox_class' => :'sandboxClass',
    :'state' => :'state',
    :'desired_state' => :'desiredState',
    :'snapshot' => :'snapshot',
    :'user' => :'user',
    :'error_reason' => :'errorReason',
    :'recoverable' => :'recoverable',
    :'public' => :'public',
    :'cpu' => :'cpu',
    :'gpu' => :'gpu',
    :'memory' => :'memory',
    :'disk' => :'disk',
    :'labels' => :'labels',
    :'backup_state' => :'backupState',
    :'auto_stop_interval' => :'autoStopInterval',
    :'auto_archive_interval' => :'autoArchiveInterval',
    :'auto_delete_interval' => :'autoDeleteInterval',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'last_activity_at' => :'lastActivityAt',
    :'daemon_version' => :'daemonVersion',
    :'toolbox_proxy_url' => :'toolboxProxyUrl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 622

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



198
199
200
201
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 198

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 165

def self.openapi_types
  {
    :'id' => :'String',
    :'organization_id' => :'String',
    :'name' => :'String',
    :'target' => :'String',
    :'runner_id' => :'String',
    :'sandbox_class' => :'String',
    :'state' => :'SandboxState',
    :'desired_state' => :'SandboxDesiredState',
    :'snapshot' => :'String',
    :'user' => :'String',
    :'error_reason' => :'String',
    :'recoverable' => :'Boolean',
    :'public' => :'Boolean',
    :'cpu' => :'Float',
    :'gpu' => :'Float',
    :'memory' => :'Float',
    :'disk' => :'Float',
    :'labels' => :'Hash<String, String>',
    :'backup_state' => :'String',
    :'auto_stop_interval' => :'Float',
    :'auto_archive_interval' => :'Float',
    :'auto_delete_interval' => :'Float',
    :'created_at' => :'String',
    :'updated_at' => :'String',
    :'last_activity_at' => :'String',
    :'daemon_version' => :'String',
    :'toolbox_proxy_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 575

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      organization_id == o.organization_id &&
      name == o.name &&
      target == o.target &&
      runner_id == o.runner_id &&
      sandbox_class == o.sandbox_class &&
      state == o.state &&
      desired_state == o.desired_state &&
      snapshot == o.snapshot &&
      user == o.user &&
      error_reason == o.error_reason &&
      recoverable == o.recoverable &&
      public == o.public &&
      cpu == o.cpu &&
      gpu == o.gpu &&
      memory == o.memory &&
      disk == o.disk &&
      labels == o.labels &&
      backup_state == o.backup_state &&
      auto_stop_interval == o.auto_stop_interval &&
      auto_archive_interval == o.auto_archive_interval &&
      auto_delete_interval == o.auto_delete_interval &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      last_activity_at == o.last_activity_at &&
      daemon_version == o.daemon_version &&
      toolbox_proxy_url == o.toolbox_proxy_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


609
610
611
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 609

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



615
616
617
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 615

def hash
  [id, organization_id, name, target, runner_id, sandbox_class, state, desired_state, snapshot, user, error_reason, recoverable, public, cpu, gpu, memory, disk, labels, backup_state, auto_stop_interval, auto_archive_interval, auto_delete_interval, created_at, updated_at, last_activity_at, daemon_version, toolbox_proxy_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 356

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @organization_id.nil?
    invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  if @user.nil?
    invalid_properties.push('invalid value for "user", user cannot be nil.')
  end

  if @public.nil?
    invalid_properties.push('invalid value for "public", public cannot be nil.')
  end

  if @cpu.nil?
    invalid_properties.push('invalid value for "cpu", cpu cannot be nil.')
  end

  if @gpu.nil?
    invalid_properties.push('invalid value for "gpu", gpu cannot be nil.')
  end

  if @memory.nil?
    invalid_properties.push('invalid value for "memory", memory cannot be nil.')
  end

  if @disk.nil?
    invalid_properties.push('invalid value for "disk", disk cannot be nil.')
  end

  if @labels.nil?
    invalid_properties.push('invalid value for "labels", labels cannot be nil.')
  end

  if @toolbox_proxy_url.nil?
    invalid_properties.push('invalid value for "toolbox_proxy_url", toolbox_proxy_url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 644

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'lib/daytona_api_client/models/sandbox_list_item.rb', line 412

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @organization_id.nil?
  return false if @name.nil?
  return false if @target.nil?
  sandbox_class_validator = EnumAttributeValidator.new('String', ["linux-vm", "container", "android", "unknown_default_open_api"])
  return false unless sandbox_class_validator.valid?(@sandbox_class)
  return false if @user.nil?
  return false if @public.nil?
  return false if @cpu.nil?
  return false if @gpu.nil?
  return false if @memory.nil?
  return false if @disk.nil?
  return false if @labels.nil?
  backup_state_validator = EnumAttributeValidator.new('String', ["None", "Pending", "InProgress", "Completed", "Error", "unknown_default_open_api"])
  return false unless backup_state_validator.valid?(@backup_state)
  return false if @toolbox_proxy_url.nil?
  true
end