Class: DaytonaApiClient::SnapshotDto

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_api_client/models/snapshot_dto.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SnapshotDto

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 163

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::SnapshotDto` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::SnapshotDto`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'general')
    self.general = attributes[:'general']
  else
    self.general = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'image_name')
    self.image_name = attributes[:'image_name']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  else
    self.size = nil
  end

  if attributes.key?(:'entrypoint')
    if (value = attributes[:'entrypoint']).is_a?(Array)
      self.entrypoint = value
    end
  else
    self.entrypoint = nil
  end

  if attributes.key?(:'cpu')
    self.cpu = attributes[:'cpu']
  else
    self.cpu = nil
  end

  if attributes.key?(:'gpu')
    self.gpu = attributes[:'gpu']
  else
    self.gpu = nil
  end

  if attributes.key?(:'mem')
    self.mem = attributes[:'mem']
  else
    self.mem = nil
  end

  if attributes.key?(:'disk')
    self.disk = attributes[:'disk']
  else
    self.disk = nil
  end

  if attributes.key?(:'error_reason')
    self.error_reason = attributes[:'error_reason']
  else
    self.error_reason = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'last_used_at')
    self.last_used_at = attributes[:'last_used_at']
  else
    self.last_used_at = nil
  end

  if attributes.key?(:'build_info')
    self.build_info = attributes[:'build_info']
  end

  if attributes.key?(:'region_ids')
    if (value = attributes[:'region_ids']).is_a?(Array)
      self.region_ids = value
    end
  end

  if attributes.key?(:'initial_runner_id')
    self.initial_runner_id = attributes[:'initial_runner_id']
  end

  if attributes.key?(:'ref')
    self.ref = attributes[:'ref']
  end

  if attributes.key?(:'sandbox_class')
    self.sandbox_class = attributes[:'sandbox_class']
  end
end

Instance Attribute Details

#build_infoObject

Build information for the snapshot



51
52
53
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 51

def build_info
  @build_info
end

#cpuObject

Returns the value of attribute cpu.



34
35
36
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 34

def cpu
  @cpu
end

#created_atObject

Returns the value of attribute created_at.



44
45
46
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 44

def created_at
  @created_at
end

#diskObject

Returns the value of attribute disk.



40
41
42
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 40

def disk
  @disk
end

#entrypointObject

Returns the value of attribute entrypoint.



32
33
34
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 32

def entrypoint
  @entrypoint
end

#error_reasonObject

Returns the value of attribute error_reason.



42
43
44
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 42

def error_reason
  @error_reason
end

#generalObject

Returns the value of attribute general.



22
23
24
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 22

def general
  @general
end

#gpuObject

Returns the value of attribute gpu.



36
37
38
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 36

def gpu
  @gpu
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 18

def id
  @id
end

#image_nameObject

Returns the value of attribute image_name.



26
27
28
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 26

def image_name
  @image_name
end

#initial_runner_idObject

The initial runner ID of the snapshot



57
58
59
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 57

def initial_runner_id
  @initial_runner_id
end

#last_used_atObject

Returns the value of attribute last_used_at.



48
49
50
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 48

def last_used_at
  @last_used_at
end

#memObject

Returns the value of attribute mem.



38
39
40
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 38

def mem
  @mem
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 24

def name
  @name
end

#organization_idObject

Returns the value of attribute organization_id.



20
21
22
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 20

def organization_id
  @organization_id
end

#refObject

The snapshot reference



60
61
62
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 60

def ref
  @ref
end

#region_idsObject

IDs of regions where the snapshot is available



54
55
56
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 54

def region_ids
  @region_ids
end

#sandbox_classObject

The sandbox class of the snapshot



63
64
65
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 63

def sandbox_class
  @sandbox_class
end

#sizeObject

Returns the value of attribute size.



30
31
32
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 30

def size
  @size
end

#stateObject

Returns the value of attribute state.



28
29
30
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 28

def state
  @state
end

#updated_atObject

Returns the value of attribute updated_at.



46
47
48
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 46

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



115
116
117
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 115

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



120
121
122
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 120

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 88

def self.attribute_map
  {
    :'id' => :'id',
    :'organization_id' => :'organizationId',
    :'general' => :'general',
    :'name' => :'name',
    :'image_name' => :'imageName',
    :'state' => :'state',
    :'size' => :'size',
    :'entrypoint' => :'entrypoint',
    :'cpu' => :'cpu',
    :'gpu' => :'gpu',
    :'mem' => :'mem',
    :'disk' => :'disk',
    :'error_reason' => :'errorReason',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'last_used_at' => :'lastUsedAt',
    :'build_info' => :'buildInfo',
    :'region_ids' => :'regionIds',
    :'initial_runner_id' => :'initialRunnerId',
    :'ref' => :'ref',
    :'sandbox_class' => :'sandboxClass'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 514

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



152
153
154
155
156
157
158
159
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 152

def self.openapi_nullable
  Set.new([
    :'size',
    :'entrypoint',
    :'error_reason',
    :'last_used_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 125

def self.openapi_types
  {
    :'id' => :'String',
    :'organization_id' => :'String',
    :'general' => :'Boolean',
    :'name' => :'String',
    :'image_name' => :'String',
    :'state' => :'SnapshotState',
    :'size' => :'Float',
    :'entrypoint' => :'Array<String>',
    :'cpu' => :'Float',
    :'gpu' => :'Float',
    :'mem' => :'Float',
    :'disk' => :'Float',
    :'error_reason' => :'String',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'last_used_at' => :'Time',
    :'build_info' => :'BuildInfo',
    :'region_ids' => :'Array<String>',
    :'initial_runner_id' => :'String',
    :'ref' => :'String',
    :'sandbox_class' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 473

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      organization_id == o.organization_id &&
      general == o.general &&
      name == o.name &&
      image_name == o.image_name &&
      state == o.state &&
      size == o.size &&
      entrypoint == o.entrypoint &&
      cpu == o.cpu &&
      gpu == o.gpu &&
      mem == o.mem &&
      disk == o.disk &&
      error_reason == o.error_reason &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      last_used_at == o.last_used_at &&
      build_info == o.build_info &&
      region_ids == o.region_ids &&
      initial_runner_id == o.initial_runner_id &&
      ref == o.ref &&
      sandbox_class == o.sandbox_class
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


501
502
503
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 501

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



507
508
509
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 507

def hash
  [id, organization_id, general, name, image_name, state, size, entrypoint, cpu, gpu, mem, disk, error_reason, created_at, updated_at, last_used_at, build_info, region_ids, initial_runner_id, ref, sandbox_class].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 296

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @general.nil?
    invalid_properties.push('invalid value for "general", general cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @cpu.nil?
    invalid_properties.push('invalid value for "cpu", cpu cannot be nil.')
  end

  if @gpu.nil?
    invalid_properties.push('invalid value for "gpu", gpu cannot be nil.')
  end

  if @mem.nil?
    invalid_properties.push('invalid value for "mem", mem cannot be nil.')
  end

  if @disk.nil?
    invalid_properties.push('invalid value for "disk", disk cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



536
537
538
539
540
541
542
543
544
545
546
547
548
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 536

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/daytona_api_client/models/snapshot_dto.rb', line 344

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @general.nil?
  return false if @name.nil?
  return false if @state.nil?
  return false if @cpu.nil?
  return false if @gpu.nil?
  return false if @mem.nil?
  return false if @disk.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  sandbox_class_validator = EnumAttributeValidator.new('String', ["linux-vm", "container", "android", "unknown_default_open_api"])
  return false unless sandbox_class_validator.valid?(@sandbox_class)
  true
end