Class: DaytonaApiClient::TraceSpan

Inherits:
Object
  • Object
show all
Defined in:
lib/daytona_api_client/models/trace_span.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TraceSpan

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/daytona_api_client/models/trace_span.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::TraceSpan` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::TraceSpan`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'trace_id')
    self.trace_id = attributes[:'trace_id']
  else
    self.trace_id = nil
  end

  if attributes.key?(:'span_id')
    self.span_id = attributes[:'span_id']
  else
    self.span_id = nil
  end

  if attributes.key?(:'parent_span_id')
    self.parent_span_id = attributes[:'parent_span_id']
  end

  if attributes.key?(:'span_name')
    self.span_name = attributes[:'span_name']
  else
    self.span_name = nil
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  else
    self.timestamp = nil
  end

  if attributes.key?(:'duration_ns')
    self.duration_ns = attributes[:'duration_ns']
  else
    self.duration_ns = nil
  end

  if attributes.key?(:'span_attributes')
    if (value = attributes[:'span_attributes']).is_a?(Hash)
      self.span_attributes = value
    end
  else
    self.span_attributes = nil
  end

  if attributes.key?(:'status_code')
    self.status_code = attributes[:'status_code']
  end

  if attributes.key?(:'status_message')
    self.status_message = attributes[:'status_message']
  end
end

Instance Attribute Details

#duration_nsObject

Span duration in nanoseconds



34
35
36
# File 'lib/daytona_api_client/models/trace_span.rb', line 34

def duration_ns
  @duration_ns
end

#parent_span_idObject

Parent span identifier



25
26
27
# File 'lib/daytona_api_client/models/trace_span.rb', line 25

def parent_span_id
  @parent_span_id
end

#span_attributesObject

Span attributes



37
38
39
# File 'lib/daytona_api_client/models/trace_span.rb', line 37

def span_attributes
  @span_attributes
end

#span_idObject

Span identifier



22
23
24
# File 'lib/daytona_api_client/models/trace_span.rb', line 22

def span_id
  @span_id
end

#span_nameObject

Span name



28
29
30
# File 'lib/daytona_api_client/models/trace_span.rb', line 28

def span_name
  @span_name
end

#status_codeObject

Status code of the span



40
41
42
# File 'lib/daytona_api_client/models/trace_span.rb', line 40

def status_code
  @status_code
end

#status_messageObject

Status message



43
44
45
# File 'lib/daytona_api_client/models/trace_span.rb', line 43

def status_message
  @status_message
end

#timestampObject

Span start timestamp



31
32
33
# File 'lib/daytona_api_client/models/trace_span.rb', line 31

def timestamp
  @timestamp
end

#trace_idObject

Trace identifier



19
20
21
# File 'lib/daytona_api_client/models/trace_span.rb', line 19

def trace_id
  @trace_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/daytona_api_client/models/trace_span.rb', line 318

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = DaytonaApiClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/daytona_api_client/models/trace_span.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/daytona_api_client/models/trace_span.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/daytona_api_client/models/trace_span.rb', line 46

def self.attribute_map
  {
    :'trace_id' => :'traceId',
    :'span_id' => :'spanId',
    :'parent_span_id' => :'parentSpanId',
    :'span_name' => :'spanName',
    :'timestamp' => :'timestamp',
    :'duration_ns' => :'durationNs',
    :'span_attributes' => :'spanAttributes',
    :'status_code' => :'statusCode',
    :'status_message' => :'statusMessage'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/daytona_api_client/models/trace_span.rb', line 294

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/daytona_api_client/models/trace_span.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/daytona_api_client/models/trace_span.rb', line 71

def self.openapi_types
  {
    :'trace_id' => :'String',
    :'span_id' => :'String',
    :'parent_span_id' => :'String',
    :'span_name' => :'String',
    :'timestamp' => :'String',
    :'duration_ns' => :'Float',
    :'span_attributes' => :'Hash<String, String>',
    :'status_code' => :'String',
    :'status_message' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/daytona_api_client/models/trace_span.rb', line 265

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      trace_id == o.trace_id &&
      span_id == o.span_id &&
      parent_span_id == o.parent_span_id &&
      span_name == o.span_name &&
      timestamp == o.timestamp &&
      duration_ns == o.duration_ns &&
      span_attributes == o.span_attributes &&
      status_code == o.status_code &&
      status_message == o.status_message
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/daytona_api_client/models/trace_span.rb', line 389

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


281
282
283
# File 'lib/daytona_api_client/models/trace_span.rb', line 281

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



287
288
289
# File 'lib/daytona_api_client/models/trace_span.rb', line 287

def hash
  [trace_id, span_id, parent_span_id, span_name, timestamp, duration_ns, span_attributes, status_code, status_message].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/daytona_api_client/models/trace_span.rb', line 160

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @trace_id.nil?
    invalid_properties.push('invalid value for "trace_id", trace_id cannot be nil.')
  end

  if @span_id.nil?
    invalid_properties.push('invalid value for "span_id", span_id cannot be nil.')
  end

  if @span_name.nil?
    invalid_properties.push('invalid value for "span_name", span_name cannot be nil.')
  end

  if @timestamp.nil?
    invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.')
  end

  if @duration_ns.nil?
    invalid_properties.push('invalid value for "duration_ns", duration_ns cannot be nil.')
  end

  if @span_attributes.nil?
    invalid_properties.push('invalid value for "span_attributes", span_attributes cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



365
366
367
# File 'lib/daytona_api_client/models/trace_span.rb', line 365

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/daytona_api_client/models/trace_span.rb', line 371

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



359
360
361
# File 'lib/daytona_api_client/models/trace_span.rb', line 359

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
200
201
# File 'lib/daytona_api_client/models/trace_span.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @trace_id.nil?
  return false if @span_id.nil?
  return false if @span_name.nil?
  return false if @timestamp.nil?
  return false if @duration_ns.nil?
  return false if @span_attributes.nil?
  true
end