Class: DaytonaApiClient::Workspace

Inherits:
Object
  • Object
show all
Defined in:
lib/daytona_api_client/models/workspace.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Workspace

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/daytona_api_client/models/workspace.rb', line 250

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaApiClient::Workspace` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaApiClient::Workspace`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  else
    self.organization_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'snapshot')
    self.snapshot = attributes[:'snapshot']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  else
    self.user = nil
  end

  if attributes.key?(:'env')
    if (value = attributes[:'env']).is_a?(Hash)
      self.env = value
    end
  else
    self.env = nil
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Hash)
      self.labels = value
    end
  else
    self.labels = nil
  end

  if attributes.key?(:'public')
    self.public = attributes[:'public']
  else
    self.public = nil
  end

  if attributes.key?(:'network_block_all')
    self.network_block_all = attributes[:'network_block_all']
  else
    self.network_block_all = nil
  end

  if attributes.key?(:'network_allow_list')
    self.network_allow_list = attributes[:'network_allow_list']
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end

  if attributes.key?(:'cpu')
    self.cpu = attributes[:'cpu']
  else
    self.cpu = nil
  end

  if attributes.key?(:'gpu')
    self.gpu = attributes[:'gpu']
  else
    self.gpu = nil
  end

  if attributes.key?(:'memory')
    self.memory = attributes[:'memory']
  else
    self.memory = nil
  end

  if attributes.key?(:'disk')
    self.disk = attributes[:'disk']
  else
    self.disk = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'desired_state')
    self.desired_state = attributes[:'desired_state']
  end

  if attributes.key?(:'error_reason')
    self.error_reason = attributes[:'error_reason']
  end

  if attributes.key?(:'recoverable')
    self.recoverable = attributes[:'recoverable']
  end

  if attributes.key?(:'backup_state')
    self.backup_state = attributes[:'backup_state']
  end

  if attributes.key?(:'backup_created_at')
    self.backup_created_at = attributes[:'backup_created_at']
  end

  if attributes.key?(:'auto_stop_interval')
    self.auto_stop_interval = attributes[:'auto_stop_interval']
  end

  if attributes.key?(:'auto_archive_interval')
    self.auto_archive_interval = attributes[:'auto_archive_interval']
  end

  if attributes.key?(:'auto_delete_interval')
    self.auto_delete_interval = attributes[:'auto_delete_interval']
  end

  if attributes.key?(:'volumes')
    if (value = attributes[:'volumes']).is_a?(Array)
      self.volumes = value
    end
  end

  if attributes.key?(:'build_info')
    self.build_info = attributes[:'build_info']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'_class')
    self._class = attributes[:'_class']
  end

  if attributes.key?(:'daemon_version')
    self.daemon_version = attributes[:'daemon_version']
  end

  if attributes.key?(:'runner_id')
    self.runner_id = attributes[:'runner_id']
  end

  if attributes.key?(:'toolbox_proxy_url')
    self.toolbox_proxy_url = attributes[:'toolbox_proxy_url']
  else
    self.toolbox_proxy_url = nil
  end

  if attributes.key?(:'image')
    self.image = attributes[:'image']
  end

  if attributes.key?(:'snapshot_state')
    self.snapshot_state = attributes[:'snapshot_state']
  end

  if attributes.key?(:'snapshot_created_at')
    self.snapshot_created_at = attributes[:'snapshot_created_at']
  end

  if attributes.key?(:'info')
    self.info = attributes[:'info']
  end
end

Instance Attribute Details

#_classObject

The class of the sandbox



103
104
105
# File 'lib/daytona_api_client/models/workspace.rb', line 103

def _class
  @_class
end

#auto_archive_intervalObject

Auto-archive interval in minutes



85
86
87
# File 'lib/daytona_api_client/models/workspace.rb', line 85

def auto_archive_interval
  @auto_archive_interval
end

#auto_delete_intervalObject

Auto-delete interval in minutes (negative value means disabled, 0 means delete immediately upon stopping)



88
89
90
# File 'lib/daytona_api_client/models/workspace.rb', line 88

def auto_delete_interval
  @auto_delete_interval
end

#auto_stop_intervalObject

Auto-stop interval in minutes (0 means disabled)



82
83
84
# File 'lib/daytona_api_client/models/workspace.rb', line 82

def auto_stop_interval
  @auto_stop_interval
end

#backup_created_atObject

The creation timestamp of the last backup



79
80
81
# File 'lib/daytona_api_client/models/workspace.rb', line 79

def backup_created_at
  @backup_created_at
end

#backup_stateObject

The state of the backup



76
77
78
# File 'lib/daytona_api_client/models/workspace.rb', line 76

def backup_state
  @backup_state
end

#build_infoObject

Build information for the sandbox



94
95
96
# File 'lib/daytona_api_client/models/workspace.rb', line 94

def build_info
  @build_info
end

#cpuObject

The CPU quota for the sandbox



52
53
54
# File 'lib/daytona_api_client/models/workspace.rb', line 52

def cpu
  @cpu
end

#created_atObject

The creation timestamp of the sandbox



97
98
99
# File 'lib/daytona_api_client/models/workspace.rb', line 97

def created_at
  @created_at
end

#daemon_versionObject

The version of the daemon running in the sandbox



106
107
108
# File 'lib/daytona_api_client/models/workspace.rb', line 106

def daemon_version
  @daemon_version
end

#desired_stateObject

The desired state of the sandbox



67
68
69
# File 'lib/daytona_api_client/models/workspace.rb', line 67

def desired_state
  @desired_state
end

#diskObject

The disk quota for the sandbox



61
62
63
# File 'lib/daytona_api_client/models/workspace.rb', line 61

def disk
  @disk
end

#envObject

Environment variables for the sandbox



34
35
36
# File 'lib/daytona_api_client/models/workspace.rb', line 34

def env
  @env
end

#error_reasonObject

The error reason of the sandbox



70
71
72
# File 'lib/daytona_api_client/models/workspace.rb', line 70

def error_reason
  @error_reason
end

#gpuObject

The GPU quota for the sandbox



55
56
57
# File 'lib/daytona_api_client/models/workspace.rb', line 55

def gpu
  @gpu
end

#idObject

The ID of the sandbox



19
20
21
# File 'lib/daytona_api_client/models/workspace.rb', line 19

def id
  @id
end

#imageObject

The image used for the workspace



115
116
117
# File 'lib/daytona_api_client/models/workspace.rb', line 115

def image
  @image
end

#infoObject

Additional information about the sandbox



124
125
126
# File 'lib/daytona_api_client/models/workspace.rb', line 124

def info
  @info
end

#labelsObject

Labels for the sandbox



37
38
39
# File 'lib/daytona_api_client/models/workspace.rb', line 37

def labels
  @labels
end

#memoryObject

The memory quota for the sandbox



58
59
60
# File 'lib/daytona_api_client/models/workspace.rb', line 58

def memory
  @memory
end

#nameObject

The name of the sandbox



25
26
27
# File 'lib/daytona_api_client/models/workspace.rb', line 25

def name
  @name
end

#network_allow_listObject

Comma-separated list of allowed CIDR network addresses for the sandbox



46
47
48
# File 'lib/daytona_api_client/models/workspace.rb', line 46

def network_allow_list
  @network_allow_list
end

#network_block_allObject

Whether to block all network access for the sandbox



43
44
45
# File 'lib/daytona_api_client/models/workspace.rb', line 43

def network_block_all
  @network_block_all
end

#organization_idObject

The organization ID of the sandbox



22
23
24
# File 'lib/daytona_api_client/models/workspace.rb', line 22

def organization_id
  @organization_id
end

#publicObject

Whether the sandbox http preview is public



40
41
42
# File 'lib/daytona_api_client/models/workspace.rb', line 40

def public
  @public
end

#recoverableObject

Whether the sandbox error is recoverable.



73
74
75
# File 'lib/daytona_api_client/models/workspace.rb', line 73

def recoverable
  @recoverable
end

#runner_idObject

The runner ID of the sandbox



109
110
111
# File 'lib/daytona_api_client/models/workspace.rb', line 109

def runner_id
  @runner_id
end

#snapshotObject

The snapshot used for the sandbox



28
29
30
# File 'lib/daytona_api_client/models/workspace.rb', line 28

def snapshot
  @snapshot
end

#snapshot_created_atObject

The creation timestamp of the last snapshot



121
122
123
# File 'lib/daytona_api_client/models/workspace.rb', line 121

def snapshot_created_at
  @snapshot_created_at
end

#snapshot_stateObject

The state of the snapshot



118
119
120
# File 'lib/daytona_api_client/models/workspace.rb', line 118

def snapshot_state
  @snapshot_state
end

#stateObject

The state of the sandbox



64
65
66
# File 'lib/daytona_api_client/models/workspace.rb', line 64

def state
  @state
end

#targetObject

The target environment for the sandbox



49
50
51
# File 'lib/daytona_api_client/models/workspace.rb', line 49

def target
  @target
end

#toolbox_proxy_urlObject

The toolbox proxy URL for the sandbox



112
113
114
# File 'lib/daytona_api_client/models/workspace.rb', line 112

def toolbox_proxy_url
  @toolbox_proxy_url
end

#updated_atObject

The last update timestamp of the sandbox



100
101
102
# File 'lib/daytona_api_client/models/workspace.rb', line 100

def updated_at
  @updated_at
end

#userObject

The user associated with the project



31
32
33
# File 'lib/daytona_api_client/models/workspace.rb', line 31

def user
  @user
end

#volumesObject

Array of volumes attached to the sandbox



91
92
93
# File 'lib/daytona_api_client/models/workspace.rb', line 91

def volumes
  @volumes
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/daytona_api_client/models/workspace.rb', line 786

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = DaytonaApiClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



191
192
193
# File 'lib/daytona_api_client/models/workspace.rb', line 191

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



196
197
198
# File 'lib/daytona_api_client/models/workspace.rb', line 196

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/daytona_api_client/models/workspace.rb', line 149

def self.attribute_map
  {
    :'id' => :'id',
    :'organization_id' => :'organizationId',
    :'name' => :'name',
    :'snapshot' => :'snapshot',
    :'user' => :'user',
    :'env' => :'env',
    :'labels' => :'labels',
    :'public' => :'public',
    :'network_block_all' => :'networkBlockAll',
    :'network_allow_list' => :'networkAllowList',
    :'target' => :'target',
    :'cpu' => :'cpu',
    :'gpu' => :'gpu',
    :'memory' => :'memory',
    :'disk' => :'disk',
    :'state' => :'state',
    :'desired_state' => :'desiredState',
    :'error_reason' => :'errorReason',
    :'recoverable' => :'recoverable',
    :'backup_state' => :'backupState',
    :'backup_created_at' => :'backupCreatedAt',
    :'auto_stop_interval' => :'autoStopInterval',
    :'auto_archive_interval' => :'autoArchiveInterval',
    :'auto_delete_interval' => :'autoDeleteInterval',
    :'volumes' => :'volumes',
    :'build_info' => :'buildInfo',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'_class' => :'class',
    :'daemon_version' => :'daemonVersion',
    :'runner_id' => :'runnerId',
    :'toolbox_proxy_url' => :'toolboxProxyUrl',
    :'image' => :'image',
    :'snapshot_state' => :'snapshotState',
    :'snapshot_created_at' => :'snapshotCreatedAt',
    :'info' => :'info'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
# File 'lib/daytona_api_client/models/workspace.rb', line 762

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



243
244
245
246
# File 'lib/daytona_api_client/models/workspace.rb', line 243

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/daytona_api_client/models/workspace.rb', line 201

def self.openapi_types
  {
    :'id' => :'String',
    :'organization_id' => :'String',
    :'name' => :'String',
    :'snapshot' => :'String',
    :'user' => :'String',
    :'env' => :'Hash<String, String>',
    :'labels' => :'Hash<String, String>',
    :'public' => :'Boolean',
    :'network_block_all' => :'Boolean',
    :'network_allow_list' => :'String',
    :'target' => :'String',
    :'cpu' => :'Float',
    :'gpu' => :'Float',
    :'memory' => :'Float',
    :'disk' => :'Float',
    :'state' => :'SandboxState',
    :'desired_state' => :'SandboxDesiredState',
    :'error_reason' => :'String',
    :'recoverable' => :'Boolean',
    :'backup_state' => :'String',
    :'backup_created_at' => :'String',
    :'auto_stop_interval' => :'Float',
    :'auto_archive_interval' => :'Float',
    :'auto_delete_interval' => :'Float',
    :'volumes' => :'Array<SandboxVolume>',
    :'build_info' => :'BuildInfo',
    :'created_at' => :'String',
    :'updated_at' => :'String',
    :'_class' => :'String',
    :'daemon_version' => :'String',
    :'runner_id' => :'String',
    :'toolbox_proxy_url' => :'String',
    :'image' => :'String',
    :'snapshot_state' => :'String',
    :'snapshot_created_at' => :'String',
    :'info' => :'SandboxInfo'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
# File 'lib/daytona_api_client/models/workspace.rb', line 706

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      organization_id == o.organization_id &&
      name == o.name &&
      snapshot == o.snapshot &&
      user == o.user &&
      env == o.env &&
      labels == o.labels &&
      public == o.public &&
      network_block_all == o.network_block_all &&
      network_allow_list == o.network_allow_list &&
      target == o.target &&
      cpu == o.cpu &&
      gpu == o.gpu &&
      memory == o.memory &&
      disk == o.disk &&
      state == o.state &&
      desired_state == o.desired_state &&
      error_reason == o.error_reason &&
      recoverable == o.recoverable &&
      backup_state == o.backup_state &&
      backup_created_at == o.backup_created_at &&
      auto_stop_interval == o.auto_stop_interval &&
      auto_archive_interval == o.auto_archive_interval &&
      auto_delete_interval == o.auto_delete_interval &&
      volumes == o.volumes &&
      build_info == o.build_info &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      _class == o._class &&
      daemon_version == o.daemon_version &&
      runner_id == o.runner_id &&
      toolbox_proxy_url == o.toolbox_proxy_url &&
      image == o.image &&
      snapshot_state == o.snapshot_state &&
      snapshot_created_at == o.snapshot_created_at &&
      info == o.info
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



857
858
859
860
861
862
863
864
865
866
867
868
869
# File 'lib/daytona_api_client/models/workspace.rb', line 857

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


749
750
751
# File 'lib/daytona_api_client/models/workspace.rb', line 749

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



755
756
757
# File 'lib/daytona_api_client/models/workspace.rb', line 755

def hash
  [id, organization_id, name, snapshot, user, env, labels, public, network_block_all, network_allow_list, target, cpu, gpu, memory, disk, state, desired_state, error_reason, recoverable, backup_state, backup_created_at, auto_stop_interval, auto_archive_interval, auto_delete_interval, volumes, build_info, created_at, updated_at, _class, daemon_version, runner_id, toolbox_proxy_url, image, snapshot_state, snapshot_created_at, info].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/daytona_api_client/models/workspace.rb', line 445

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @organization_id.nil?
    invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @user.nil?
    invalid_properties.push('invalid value for "user", user cannot be nil.')
  end

  if @env.nil?
    invalid_properties.push('invalid value for "env", env cannot be nil.')
  end

  if @labels.nil?
    invalid_properties.push('invalid value for "labels", labels cannot be nil.')
  end

  if @public.nil?
    invalid_properties.push('invalid value for "public", public cannot be nil.')
  end

  if @network_block_all.nil?
    invalid_properties.push('invalid value for "network_block_all", network_block_all cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  if @cpu.nil?
    invalid_properties.push('invalid value for "cpu", cpu cannot be nil.')
  end

  if @gpu.nil?
    invalid_properties.push('invalid value for "gpu", gpu cannot be nil.')
  end

  if @memory.nil?
    invalid_properties.push('invalid value for "memory", memory cannot be nil.')
  end

  if @disk.nil?
    invalid_properties.push('invalid value for "disk", disk cannot be nil.')
  end

  if @toolbox_proxy_url.nil?
    invalid_properties.push('invalid value for "toolbox_proxy_url", toolbox_proxy_url cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



833
834
835
# File 'lib/daytona_api_client/models/workspace.rb', line 833

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



839
840
841
842
843
844
845
846
847
848
849
850
851
# File 'lib/daytona_api_client/models/workspace.rb', line 839

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



827
828
829
# File 'lib/daytona_api_client/models/workspace.rb', line 827

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/daytona_api_client/models/workspace.rb', line 509

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @organization_id.nil?
  return false if @name.nil?
  return false if @user.nil?
  return false if @env.nil?
  return false if @labels.nil?
  return false if @public.nil?
  return false if @network_block_all.nil?
  return false if @target.nil?
  return false if @cpu.nil?
  return false if @gpu.nil?
  return false if @memory.nil?
  return false if @disk.nil?
  backup_state_validator = EnumAttributeValidator.new('String', ["None", "Pending", "InProgress", "Completed", "Error"])
  return false unless backup_state_validator.valid?(@backup_state)
  _class_validator = EnumAttributeValidator.new('String', ["small", "medium", "large"])
  return false unless _class_validator.valid?(@_class)
  return false if @toolbox_proxy_url.nil?
  snapshot_state_validator = EnumAttributeValidator.new('String', ["None", "Pending", "InProgress", "Completed", "Error"])
  return false unless snapshot_state_validator.valid?(@snapshot_state)
  true
end